-------------------------------------------------------------------------------
--
-- Simple VGA raster display
--
-- Stephen A. Edwards
-- sedwards@cs.columbia.edu
--
-------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity de2_vga_raster is
  
  port (
    clk   : in std_logic;                    -- Should be 25.125 MHz
    reset : in std_logic;

    read       : in  std_logic;
    write      : in  std_logic;
    chipselect : in  std_logic;
    address    : in  std_logic_vector(18 downto 0);
    readdata   : out std_logic_vector(18 downto 0);
    writedata  : in  std_logic_vector(15 downto 0);
	 write_inf  : in  std_logic_vector(15 downto 0);
	 address_inf: in  std_logic_vector(18 downto 0);

    VGA_CLK,                         -- Clock
    VGA_HS,                          -- H_SYNC
    VGA_VS,                          -- V_SYNC
    VGA_BLANK,                       -- BLANK
    VGA_SYNC : out std_logic;        -- SYNC
    VGA_R,                           -- Red[9:0]
    VGA_G,                           -- Green[9:0]
    VGA_B : out std_logic_vector(9 downto 0) -- Blue[9:0]
    );

end de2_vga_raster;

architecture rtl of de2_vga_raster is
  
  -- Video parameters
  
  constant HTOTAL       : integer := 800;
  constant HSYNC        : integer := 96;
  constant HBACK_PORCH  : integer := 48;
  constant HACTIVE      : integer := 640;
  constant HFRONT_PORCH : integer := 16;
  
  constant VTOTAL       : integer := 525;
  constant VSYNC        : integer := 2;
  constant VBACK_PORCH  : integer := 33;
  constant VACTIVE      : integer := 480;
  constant VFRONT_PORCH : integer := 10;

  signal Cirlce_HSTART  : integer := 200;
  signal Cirlce_VSTART  : integer := 200;
  signal Cirlce_VACTIVE : integer := 24;
  
  constant RECTANGLE_HSTART : integer := 0;
  constant RECTANGLE_HEND   : integer := 639;
  constant RECTANGLE_VSTART : integer := 0;
  constant RECTANGLE_VEND   : integer := 479;
  
  constant tube_HSTART    : integer := 178;
  constant tube_HEND      : integer := 242;
  constant tube_VSTART    : integer := 384;
  constant tube_VEND      : integer := 448;
  constant score_VSTART   : integer := 375;
  constant score_VEND     : integer := 415;
  constant score_H1START  : integer := 522;
  constant score_H1END    : integer := 554;
  constant score_H2START  : integer := 554;
  constant score_H2END    : integer := 585;
  constant score_H3START  : integer := 585;
  constant score_H3END    : integer := 617;
  
  constant choose_cen_v     : integer := 335;
  constant choose_cen_h     : integer := 38 ;
  
  constant tube_first_HSTART    : integer := 103;
  constant tube_first_HEND      : integer := 167;
  constant tube_first_VSTART    : integer := 384;
  constant tube_first_VEND      : integer := 448;
  
  constant tube_second_HSTART    : integer := 488;
  constant tube_second_HEND      : integer := 552;
  constant tube_second_VSTART    : integer := 384;
  constant tube_second_VEND      : integer := 448;
  

  -- Signals for the video controller
  type ram_type is array(15 downto 0) of
            std_logic_vector(15 downto 0);
  signal RAM : ram_type;
  type ram_inf_type is array(256 downto 0) of
            std_logic_vector(15 downto 0);
  signal RAM_inf : ram_inf_type;
  signal ram_address, display_address : unsigned(8 downto 0);
  signal counter : unsigned(20 downto 0);

  signal Hcount : unsigned(9 downto 0);  -- Horizontal position (0-800)
  signal Vcount : unsigned(9 downto 0);  -- Vertical position (0-524)
  signal circle_hs : unsigned(7 downto 0);
  signal circle_vs : unsigned(15 downto 0);
  signal EndOfLine, EndOfField : std_logic;
  signal vga_hblank, vga_hsync,
         vga_vblank, vga_vsync : std_logic;  -- Sync. signals
  signal VGA_R_buffer : std_logic_vector(2 downto 0);
  signal VGA_G_buffer : std_logic_vector(2 downto 0);
  signal VGA_B_buffer : std_logic_vector(1 downto 0);
  signal VGA_R_buffer_next : std_logic_vector(2 downto 0);
  signal VGA_G_buffer_next : std_logic_vector(2 downto 0);
  signal VGA_B_buffer_next : std_logic_vector(1 downto 0);
  signal circle_h, circle_v, circle : std_logic;  -- circle area
  signal VGA_buffer   : unsigned(15 downto 0);
  signal read_address : unsigned(18 downto 0);
  signal rectangle_h, rectangle_v, rectangle : std_logic;  -- rectangle area
  signal clk25 : std_logic := '0';
  signal clk_half: std_logic :='0';
  signal flag : std_logic :='0';
  signal ram_inf_address : unsigned(8 downto 0);
  signal shoot_h, shoot_v, shoot,arrow,launch,arrow_first,arrow_second : unsigned(15 downto 0);  -- circle area
  signal shoot_h_2, shoot_v_2, shoot_2,arrow_2 : unsigned(15 downto 0);  -- circle area
  signal numberd0, numberd1, numberd2: unsigned(15 downto 0);
  
  signal shoot_ball_type, shoot_ball_type_2: unsigned(15 downto 0);  -- circle area
  signal shoot_cen_h , shoot_cen_v, arrow_n,arrow_n_first,arrow_n_second , launch_n, ball_select_n, ball_select_a, ball_type_n, ball_select_n_2: integer;
  signal shoot_cen_h_2 , shoot_cen_v_2, arrow_n_2,number0_type,number1_type,number2_type : integer;
  signal number0_select , number1_select, number2_select : integer;
  signal sprite_shoot_V, sprite_shoot_H, sprite_shoot_HV : std_logic;
  signal sprite_shoot_V_2, sprite_shoot_H_2, sprite_shoot_HV_2 : std_logic;
  signal sprite_E_V, sprite_E_H, sprite_E_HV : std_logic;
  signal tube_V, tube_H, tube_HV,score_sprite1_HV,score_sprite2_HV,score_sprite3_HV : std_logic; 
  signal tube_first_V, tube_first_H, tube_first_HV: std_logic; 
  signal tube_second_V, tube_second_H, tube_second_HV: std_logic; 
  signal score_H1,score_H2,score_H3,score_V : std_logic;
  signal ball_select  : integer :=0;
   type ball is array(0 to 1023) of std_logic_vector(2 downto 0);
	type number is array(0 to 1279) of std_logic_vector(2 downto 0);
	type shoot_type is array(180 downto 0) of unsigned(7 downto 0);
  signal ball_type : shoot_type;
  signal tube_sprite_control : std_logic;
   type tube_type is array(0 to 4095) of std_logic_vector(0 downto 0);
  signal tube_flag : std_logic_vector(0 downto 0);
  signal sprite_choose_HV : std_logic;
  signal option : unsigned(15 downto 0);
  
--  Vstart 365+


--constant n0_B : number:=("001", "001", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "001", "001", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "001", "001", "001", "001", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "001", "001", "001", "001", "001", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "001", "001", "010", "010", "010", "010", "010", "010", "001", "001", "001", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "010", "010", "011", "011", "010", "010", "010", "010", "010", "011", "011", "010", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "001", "000", "000", "000", "000", "000", "001", "001", "001", "010", "010", "010", "001", "010", "010", "011", "100", "100", "101", "100", "100", "011", "010", "001", "010", "010", "010", "001", "001", "000", "001", "000", "000", "000", "000", "000", "001", "001", "000", "000", "001", "001", "000", "000", "000", "000", "001", "010", "010", "010", "011", "100", "101", "101", "110", "111", "111", "111", "111", "111", "111", "110", "110", "101", "100", "010", "010", "011", "001", "001", "001", "001", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "001", "010", "010", "010", "010", "100", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "100", "010", "011", "010", "001", "001", "000", "000", "000", "000", "001", "000", "001", "000", "000", "000", "000", "001", "010", "010", "011", "100", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "010", "011", "010", "001", "001", "000", "001", "001", "000", "001", "001", "000", "000", "000", "001", "010", "010", "010", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "010", "010", "001", "001", "000", "001", "001", "001", "001", "000", "000", "000", "001", "010", "010", "010", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "010", "011", "001", "000", "001", "000", "001", "001", "000", "000", "001", "001", "010", "010", "110", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "010", "010", "000", "000", "000", "000", "001", "000", "000", "001", "010", "010", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "011", "010", "000", "000", "000", "000", "000", "000", "001", "010", "001", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "010", "000", "000", "000", "001", "000", "000", "001", "011", "001", "110", "111", "111", "111", "111", "110", "111", "111", "111", "111", "101", "011", "100", "100", "011", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "010", "000", "000", "001", "000", "000", "000", "001", "010", "011", "111", "111", "111", "111", "110", "111", "111", "111", "111", "101", "011", "111", "111", "111", "111", "101", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "010", "000", "001", "000", "000", "000", "000", "001", "010", "011", "110", "111", "111", "110", "111", "111", "111", "111", "110", "011", "111", "111", "111", "111", "111", "111", "100", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "010", "000", "000", "000", "000", "000", "000", "001", "001", "100", "110", "111", "111", "111", "111", "111", "111", "111", "101", "100", "111", "111", "111", "111", "111", "111", "110", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "010", "000", "000", "000", "000", "000", "000", "001", "010", "100", "111", "111", "111", "111", "111", "111", "111", "111", "110", "100", "111", "111", "111", "111", "111", "111", "110", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "011", "010", "001", "000", "000", "000", "000", "000", "010", "011", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "110", "111", "111", "111", "111", "111", "100", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "011", "010", "001", "000", "000", "000", "000", "000", "001", "011", "010", "101", "111", "111", "111", "111", "111", "111", "111", "111", "110", "011", "101", "110", "111", "111", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "010", "010", "001", "001", "001", "000", "000", "001", "001", "010", "010", "011", "110", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "011", "011", "011", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "010", "011", "001", "000", "001", "001", "000", "000", "001", "000", "001", "010", "011", "100", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "010", "010", "001", "001", "000", "001", "001", "000", "000", "001", "000", "000", "001", "011", "010", "011", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "010", "011", "010", "000", "001", "000", "001", "001", "000", "000", "001", "000", "000", "000", "001", "010", "010", "011", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "010", "011", "010", "001", "001", "001", "001", "000", "000", "000", "001", "001", "000", "000", "000", "000", "001", "010", "011", "010", "011", "101", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "011", "010", "011", "010", "001", "001", "001", "001", "001", "000", "000", "001", "001", "000", "000", "001", "001", "000", "001", "001", "010", "011", "010", "010", "010", "100", "101", "110", "111", "111", "111", "111", "111", "111", "111", "110", "110", "100", "011", "010", "010", "010", "001", "001", "000", "000", "000", "001", "001", "000", "000", "001", "001", "000", "000", "001", "001", "000", "000", "001", "001", "001", "001", "010", "011", "011", "010", "011", "011", "011", "100", "100", "100", "011", "011", "011", "010", "011", "011", "010", "001", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "001", "001", "001", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "001", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "001", "001", "001", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "000", "000", "000" );  
--constant n0_G : number:=("100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "010", "001", "001", "001", "010", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "010", "001", "001", "001", "001", "001", "010", "001", "001", "001", "001", "001", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "010", "001", "001", "010", "010", "011", "011", "011", "011", "011", "011", "011", "010", "010", "010", "001", "001", "010", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "010", "001", "010", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "001", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "001", "001", "011", "011", "010", "010", "011", "011", "011", "011", "011", "010", "010", "011", "010", "010", "010", "010", "010", "010", "010", "010", "001", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "010", "001", "010", "100", "011", "010", "011", "010", "011", "011", "011", "011", "011", "011", "011", "010", "011", "010", "010", "010", "010", "010", "010", "010", "010", "001", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "010", "001", "011", "110", "110", "110", "011", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "010", "001", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "010", "001", "100", "110", "110", "110", "110", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "011", "001", "010", "100", "100", "100", "100", "011", "100", "100", "100", "100", "011", "001", "011", "110", "110", "110", "111", "101", "011", "011", "011", "011", "011", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "010", "001", "100", "100", "100", "100", "100", "100", "100", "100", "100", "010", "001", "110", "111", "110", "111", "110", "011", "010", "011", "011", "100", "011", "011", "011", "011", "100", "100", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "010", "001", "100", "100", "100", "100", "100", "100", "100", "100", "100", "000", "100", "110", "110", "111", "101", "011", "010", "011", "011", "011", "010", "001", "001", "010", "001", "001", "100", "100", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "001", "100", "100", "100", "100", "100", "100", "100", "100", "010", "001", "100", "111", "110", "100", "010", "010", "011", "011", "011", "010", "001", "110", "111", "111", "111", "011", "001", "100", "100", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "001", "100", "100", "100", "100", "100", "100", "100", "100", "001", "001", "011", "100", "011", "010", "011", "010", "011", "011", "011", "001", "110", "111", "111", "111", "111", "111", "010", "010", "100", "011", "011", "011", "010", "010", "010", "010", "010", "010", "010", "001", "100", "100", "100", "100", "100", "100", "100", "100", "001", "010", "010", "010", "010", "010", "011", "010", "010", "011", "010", "010", "111", "111", "111", "111", "111", "111", "100", "001", "100", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "001", "100", "100", "100", "100", "100", "100", "100", "100", "001", "001", "010", "010", "010", "010", "010", "010", "011", "011", "010", "010", "111", "111", "111", "111", "111", "111", "100", "001", "100", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "001", "100", "100", "100", "100", "100", "100", "100", "100", "011", "001", "010", "010", "010", "010", "010", "010", "010", "011", "011", "000", "100", "111", "111", "111", "111", "111", "010", "010", "011", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "001", "100", "100", "100", "100", "100", "100", "100", "100", "100", "001", "010", "010", "010", "010", "010", "010", "010", "010", "011", "011", "000", "011", "101", "110", "110", "011", "001", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "001", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "001", "010", "010", "010", "010", "010", "010", "011", "011", "011", "011", "010", "001", "001", "001", "010", "011", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "001", "001", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "010", "001", "010", "010", "010", "011", "010", "011", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "010", "001", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "010", "001", "010", "011", "010", "011", "010", "011", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "000", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "010", "001", "010", "011", "010", "010", "011", "010", "011", "011", "011", "011", "011", "011", "011", "011", "010", "011", "010", "010", "010", "010", "001", "001", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "001", "000", "010", "011", "010", "011", "010", "010", "010", "010", "010", "011", "011", "010", "011", "010", "010", "011", "010", "001", "010", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "001", "001", "001", "010", "010", "010", "010", "011", "011", "011", "011", "011", "010", "010", "001", "000", "001", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "010", "001", "001", "001", "001", "001", "001", "001", "001", "001", "001", "001", "010", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100" ); 
--constant n0_R : number:=("110", "110", "101", "101", "101", "110", "110", "110", "110", "110", "110", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "100", "011", "010", "010", "010", "010", "100", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "110", "110", "101", "100", "011", "010", "010", "010", "010", "010", "010", "010", "010", "010", "001", "010", "100", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "110", "110", "110", "110", "101", "101", "101", "100", "010", "010", "010", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "011", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "100", "010", "001", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "001", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "100", "010", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "001", "100", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "011", "001", "011", "100", "100", "011", "011", "011", "100", "011", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "011", "001", "100", "110", "111", "111", "100", "011", "100", "011", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "101", "011", "001", "100", "111", "111", "111", "111", "100", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "010", "011", "010", "011", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "001", "011", "111", "111", "111", "111", "110", "100", "100", "100", "100", "100", "101", "101", "101", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "010", "011", "011", "010", "101", "110", "110", "110", "110", "110", "110", "110", "110", "011", "010", "110", "111", "111", "111", "110", "100", "011", "100", "100", "101", "100", "011", "011", "100", "101", "101", "100", "100", "100", "100", "011", "011", "011", "011", "011", "010", "010", "010", "010", "101", "110", "110", "110", "110", "110", "110", "110", "101", "001", "100", "111", "111", "111", "110", "011", "011", "100", "100", "100", "010", "001", "010", "010", "001", "010", "100", "101", "100", "100", "100", "100", "011", "011", "011", "011", "011", "010", "011", "010", "110", "110", "110", "110", "110", "110", "110", "101", "011", "010", "101", "111", "110", "100", "011", "011", "011", "011", "100", "010", "001", "110", "111", "111", "111", "011", "001", "101", "100", "100", "100", "100", "011", "011", "011", "011", "010", "010", "010", "010", "110", "110", "110", "110", "110", "110", "110", "101", "010", "010", "100", "100", "011", "010", "011", "011", "011", "100", "011", "001", "111", "111", "111", "111", "111", "111", "010", "010", "100", "100", "100", "100", "011", "011", "011", "011", "010", "011", "011", "010", "110", "110", "110", "110", "110", "110", "110", "101", "010", "010", "011", "010", "010", "011", "011", "011", "011", "100", "010", "010", "111", "111", "111", "111", "111", "111", "101", "001", "101", "100", "100", "100", "011", "011", "011", "011", "011", "010", "011", "010", "110", "110", "110", "110", "110", "110", "110", "101", "010", "010", "011", "010", "011", "011", "011", "011", "100", "100", "010", "010", "111", "111", "111", "111", "111", "111", "101", "010", "101", "100", "100", "100", "011", "011", "011", "011", "011", "010", "010", "010", "101", "110", "110", "110", "110", "110", "101", "101", "100", "001", "011", "010", "010", "011", "011", "011", "100", "100", "011", "001", "100", "111", "111", "111", "111", "111", "010", "011", "100", "100", "100", "011", "011", "011", "011", "010", "010", "011", "011", "010", "101", "110", "110", "110", "110", "110", "101", "101", "101", "010", "010", "011", "010", "011", "011", "011", "011", "011", "100", "011", "000", "011", "101", "110", "110", "011", "001", "100", "100", "100", "100", "011", "011", "011", "011", "011", "010", "011", "010", "100", "110", "110", "110", "110", "110", "110", "110", "101", "101", "100", "010", "011", "011", "011", "011", "011", "011", "011", "011", "100", "011", "010", "001", "001", "001", "010", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "101", "101", "110", "110", "110", "110", "110", "110", "101", "110", "101", "011", "010", "011", "010", "011", "011", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "011", "001", "011", "011", "010", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "001", "100", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "011", "001", "010", "011", "011", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "001", "100", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "100", "010", "001", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "001", "010", "100", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "100", "010", "001", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "001", "010", "100", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "100", "011", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "011", "101", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "110", "101", "101", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110" );  
-----------------------------------------------------------------------------------------------------------
--constant n1_B : number:=("001", "001", "001", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "001", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "001", "001", "001", "001", "001", "001", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "001", "000", "000", "001", "001", "000", "000", "000", "000", "001", "001", "000", "000", "001", "001", "010", "010", "010", "010", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "001", "000", "000", "000", "000", "001", "001", "001", "001", "000", "000", "001", "001", "000", "000", "000", "000", "001", "001", "001", "010", "011", "011", "011", "100", "100", "011", "010", "001", "001", "000", "000", "000", "000", "000", "000", "001", "001", "001", "001", "001", "000", "000", "000", "000", "000", "001", "001", "001", "000", "000", "001", "000", "000", "000", "000", "000", "001", "010", "100", "101", "101", "110", "110", "110", "110", "101", "100", "011", "001", "001", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "001", "001", "001", "010", "011", "100", "110", "111", "111", "111", "111", "111", "111", "111", "110", "100", "010", "000", "001", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "001", "001", "010", "100", "101", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "010", "000", "001", "001", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "001", "010", "010", "011", "100", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "011", "001", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "000", "000", "000", "000", "001", "000", "000", "000", "001", "010", "011", "100", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "011", "010", "001", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "001", "000", "000", "001", "000", "001", "010", "010", "100", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "100", "010", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "001", "010", "011", "011", "101", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "011", "010", "001", "001", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "001", "010", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "100", "010", "001", "001", "001", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "001", "001", "000", "001", "010", "010", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "011", "001", "001", "001", "001", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "010", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "011", "010", "001", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "001", "001", "000", "001", "010", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "100", "100", "100", "100", "100", "100", "100", "101", "101", "101", "101", "101", "101", "101", "100", "011", "010", "001", "010", "010", "101", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "101", "100", "010", "001", "010", "010", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "010", "000", "001", "010", "100", "110", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "010", "000", "001", "010", "010", "011", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "100", "010", "000", "000", "000", "001", "010", "100", "100", "110", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "101", "101", "011", "010", "000", "000", "000", "000", "001", "010", "010", "011", "011", "100", "101", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "100", "011", "010", "010", "001", "000", "000", "000", "000", "000", "000", "000", "001", "010", "011", "011", "100", "100", "101", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "101", "101", "101", "101", "100", "100", "011", "010", "001", "001", "001", "000", "001", "000", "001", "000", "000", "000", "001", "001", "001", "010", "010", "010", "010", "010", "011", "011", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "001", "001", "001", "001", "001", "001", "001", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "001", "000", "001", "001", "001", "001", "001", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "001", "001", "001", "000", "001", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "001", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "001", "001", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "000", "000", "000", "001", "000", "000", "000", "000", "001", "001", "001", "001", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "001", "001", "001", "000", "000", "000", "000", "000", "000", "001", "001", "001", "000", "000", "000", "001", "001", "000", "000", "000", "001", "001", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000" );
--constant n1_G : number:=("100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "100", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "100", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "101", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "101", "101", "101", "101", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "101", "101", "101", "100", "011", "011", "100", "100", "100", "100", "100", "101", "100", "101", "101", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "100", "110", "110", "110", "111", "110", "100", "011", "011", "100", "100", "100", "101", "100", "101", "101", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "100", "111", "110", "110", "110", "110", "110", "100", "011", "100", "100", "100", "100", "100", "101", "101", "101", "101", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "110", "110", "110", "110", "110", "110", "101", "011", "011", "100", "100", "100", "100", "100", "101", "101", "101", "101", "101", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "100", "100", "100", "011", "011", "110", "110", "110", "110", "110", "101", "011", "011", "100", "100", "100", "100", "100", "100", "100", "101", "101", "101", "101", "101", "101", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "010", "011", "100", "100", "100", "011", "011", "101", "110", "111", "110", "100", "011", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "010", "011", "010", "010", "010", "100", "100", "100", "011", "010", "011", "100", "100", "011", "010", "011", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "010", "011", "010", "010", "010", "100", "100", "100", "100", "011", "010", "010", "010", "010", "011", "011", "011", "011", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "010", "011", "010", "010", "011", "100", "100", "100", "100", "100", "100", "011", "010", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "010", "010", "010", "011", "011", "011", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "011", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100"  );
--constant n1_R : number:=("110", "110", "110", "110", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "100", "100", "100", "100", "100", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "100", "100", "011", "011", "011", "011", "011", "011", "011", "100", "100", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "100", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "100", "100", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "100", "100", "100", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "100", "100", "100", "100", "100", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "100", "011", "011", "010", "011", "011", "011", "011", "011", "011", "011", "011", "100", "011", "100", "100", "100", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "100", "101", "101", "101", "100", "010", "011", "011", "011", "011", "011", "011", "100", "011", "100", "100", "100", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "100", "101", "111", "110", "110", "110", "101", "011", "011", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "100", "100", "111", "110", "110", "110", "110", "110", "011", "011", "011", "011", "011", "011", "011", "100", "100", "100", "100", "100", "101", "101", "110", "110", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "110", "110", "110", "101", "101", "100", "111", "110", "110", "110", "110", "110", "101", "011", "011", "011", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "011", "100", "101", "101", "110", "101", "100", "100", "111", "110", "110", "110", "110", "101", "011", "011", "011", "011", "011", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "010", "010", "010", "010", "011", "100", "101", "110", "101", "100", "100", "101", "110", "110", "101", "011", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "010", "011", "101", "110", "101", "100", "011", "011", "100", "011", "010", "010", "010", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "010", "011", "101", "110", "110", "110", "100", "011", "010", "010", "010", "010", "010", "010", "010", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "010", "011", "011", "101", "110", "110", "110", "101", "101", "100", "011", "011", "011", "011", "010", "010", "010", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "010", "011", "011", "100", "110", "110", "110", "110", "110", "110", "110", "101", "100", "100", "100", "011", "011", "011", "011", "011", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "011", "011", "011", "100", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "100", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110"  );
-----------------------------------------
--constant n2_B : number:=("000","001","001","001","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","001","000","000","000","000","001","001","000","000","000","001","001","000","000","001","001","000","001","001","001","000","000","000","000","000","000","000","000","000","001","001","001","001","000","000","000","000","000","000","000","001","000","000","001","000","000","000","001","000","000","000","000","000","000","000","001","001","001","001","000","000","000","000","000","001","000","000","000","001","001","001","001","001","001","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","001","001","001","000","000","001","001","001","000","000","000","000","000","000","000","001","001","001","001","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","001","001","000","000","000","001","000","001","001","000","000","001","001","001","000","000","000","000","000","001","001","001","001","000","000","000","000","000","000","000","000","000","001","001","000","001","001","000","000","000","000","000","000","001","001","001","001","001","001","000","000","000","000","001","000","000","000","000","001","001","001","000","000","000","001","001","001","001","001","010","001","000","000","010","001","000","000","000","000","000","000","001","001","001","001","001","001","001","001","000","000","000","000","001","001","000","000","000","001","001","000","000","001","010","010","001","010","010","010","010","010","001","000","001","001","001","000","000","000","001","001","001","000","000","000","000","000","000","001","001","001","000","000","001","001","000","000","000","001","001","000","001","001","001","010","010","001","010","010","010","010","010","001","000","001","001","000","000","000","001","001","000","000","001","001","001","000","000","000","001","001","000","001","001","001","000","001","001","001","000","001","001","001","001","001","001","010","010","010","010","010","010","001","000","001","000","000","000","001","001","000","010","010","001","001","001","001","001","000","000","001","001","000","000","000","001","001","001","000","000","001","000","001","001","001","001","010","010","010","010","010","010","000","000","001","001","000","001","000","000","010","010","010","010","001","001","001","001","001","000","000","001","001","000","000","001","001","010","000","000","001","000","001","001","001","010","010","010","010","010","010","001","000","001","001","001","001","001","000","010","010","010","010","001","001","001","010","001","001","000","000","001","001","000","000","001","001","010","000","000","001","001","001","001","001","010","010","010","010","010","010","000","001","001","001","001","001","000","010","010","010","010","010","010","001","010","010","001","001","001","000","001","001","001","001","001","001","001","000","001","001","001","001","001","001","010","010","010","010","010","001","000","010","001","001","010","000","001","011","010","010","010","010","001","010","010","001","001","001","001","000","001","001","001","001","001","001","000","000","001","001","001","001","001","010","010","010","010","010","011","010","000","001","010","001","000","001","011","011","011","010","010","010","010","010","001","001","001","001","001","000","001","000","000","000","000","001","000","000","001","001","001","001","001","010","010","010","010","010","011","011","010","000","000","001","010","011","011","011","011","011","010","010","010","001","001","001","001","001","001","000","001","000","000","000","000","001","001","000","001","001","001","010","010","010","010","010","010","010","011","011","011","011","011","011","011","011","011","010","010","010","010","010","010","010","001","001","001","001","001","000","001","001","000","000","000","000","010","000","001","001","001","001","001","010","010","010","010","010","011","011","011","010","011","011","011","011","011","011","010","010","001","001","010","010","001","001","001","001","001","000","001","001","000","000","000","001","001","000","000","001","001","001","001","001","001","010","010","010","011","011","010","010","011","011","011","011","011","010","001","000","001","000","010","010","001","001","001","001","001","000","001","001","000","000","000","000","001","001","000","000","001","001","010","010","010","010","010","010","011","010","011","011","011","011","011","011","010","000","000","010","010","000","010","010","001","001","001","001","000","000","001","001","001","000","000","000","000","001","001","000","001","001","001","010","010","010","010","010","010","010","011","011","011","011","010","010","000","001","001","001","010","000","001","010","001","001","001","001","000","000","001","001","000","001","000","000","000","000","001","000","000","000","001","010","010","010","010","010","010","010","010","010","010","010","001","000","001","001","001","001","001","000","001","001","001","001","001","001","000","000","001","001","001","001","000","000","000","000","001","001","001","000","000","000","001","001","001","010","010","010","010","010","001","000","000","010","001","001","001","001","001","000","001","001","001","001","001","001","000","001","001","001","001","001","000","000","000","000","000","001","001","001","001","000","000","000","000","000","001","000","000","000","000","001","001","001","001","001","001","001","001","000","001","001","001","001","001","000","000","001","001","001","000","000","000","000","000","000","000","001","001","001","001","001","001","001","001","001","001","001","001","001","001","001","001","000","001","001","001","001","001","000","000","001","001","001","001","000","000","001","001","000","001","000","000","001","001","001","000","000","000","000","000","001","001","001","001","001","001","001","001","001","001","000","000","000","000","001","001","001","001","000","000","000","001","001","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","001","001","001","001","001","001","001","001","001","000","001","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","001","001","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","001","000","000","001","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","001","000","000","001","001","001","001","001","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","001");
--constant n2_G : number:=("100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","100","100","100","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","010","001","001","001","001","011","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","011","001","000","000","000","000","000","000","000","001","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","010","001","001","001","001","000","001","001","001","001","001","001","100","100","100","100","100","100","100","100","100","100","100","011","011","011","100","100","100","100","100","100","100","100","100","100","100","100","011","010","001","010","100","011","001","000","000","000","001","001","001","000","010","100","100","100","100","100","100","100","011","010","001","000","000","000","010","011","100","100","100","100","100","100","100","100","100","100","010","001","011","011","100","011","001","000","001","000","001","001","001","001","001","011","100","100","100","100","100","011","001","000","001","000","000","001","000","001","011","100","100","100","100","100","100","100","100","100","001","010","100","100","011","010","001","001","001","001","001","001","001","001","001","100","100","100","100","100","010","000","001","001","000","000","000","000","001","001","001","100","100","100","100","100","100","100","100","010","001","011","100","100","011","010","001","001","001","001","001","001","001","001","001","011","100","100","100","010","000","001","001","000","001","000","000","000","000","001","000","010","100","100","100","100","100","100","011","001","010","100","100","100","010","001","001","001","001","001","001","001","001","001","011","100","100","100","010","000","001","001","001","001","000","001","000","000","000","000","000","001","100","100","100","100","100","100","011","000","010","100","100","011","001","001","001","001","001","001","001","001","000","011","100","100","100","011","000","001","001","001","001","000","001","000","000","000","000","000","000","000","100","100","100","100","100","011","010","000","001","010","011","010","001","001","001","001","001","001","001","001","001","100","100","011","011","000","001","001","001","001","001","001","000","001","000","000","000","000","000","000","100","100","100","100","100","011","000","000","001","001","001","001","001","001","001","001","001","001","001","001","001","011","011","010","000","001","010","001","001","001","001","001","001","000","001","000","000","000","000","000","100","100","100","100","100","011","001","000","001","000","000","000","000","001","001","001","001","001","001","001","001","000","000","001","001","010","010","001","001","001","001","001","001","001","001","000","000","000","000","000","100","100","100","100","100","100","010","000","001","000","000","000","001","000","001","001","001","001","001","001","001","010","010","010","010","010","001","001","001","001","001","001","000","001","001","000","000","000","000","000","100","100","100","100","100","011","100","001","000","000","000","000","000","001","001","001","001","001","001","001","001","010","010","010","010","010","001","001","001","001","000","001","001","001","000","000","000","000","001","000","100","100","100","100","100","100","100","010","000","001","000","000","000","000","001","001","001","001","001","001","001","001","001","001","001","001","001","001","000","001","001","000","001","001","000","000","000","000","001","000","100","100","100","100","100","100","100","011","001","000","000","000","000","000","001","001","001","001","001","001","001","001","001","001","001","001","001","000","010","011","011","000","001","000","001","000","000","000","001","001","100","100","100","100","100","100","100","100","011","000","001","000","000","000","001","001","001","001","001","001","001","001","001","001","001","001","000","010","011","100","100","001","001","000","001","000","000","000","000","001","100","100","100","100","100","100","100","100","100","010","000","000","001","001","001","001","001","001","001","001","001","001","001","001","001","000","011","100","100","100","011","001","001","000","000","000","000","000","000","010","100","100","100","100","100","100","100","100","100","100","011","001","000","001","001","001","001","001","001","001","001","001","001","000","001","011","100","100","100","100","011","000","001","000","000","000","000","001","000","011","100","100","100","100","100","100","100","100","011","100","100","011","010","001","001","000","000","000","000","000","000","001","010","011","100","100","100","100","100","100","011","001","001","000","000","000","000","000","001","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","011","010","010","010","010","011","011","100","100","100","100","100","100","100","100","100","001","001","001","000","000","001","000","010","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","011","011","100","100","100","100","100","100","100","100","100","100","100","100","010","000","001","001","001","000","001","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","001","000","001","000","001","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","011","011","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100");
--constant n2_R : number:=("110","110","110","110","110","101","101","101","101","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","101","100","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","110","110","110","110","101","101","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","110","111","111","111","111","111","111","110","101","110","110","110","110","110","110","110","110","110","110","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","110","101","101","110","111","111","111","111","111","111","111","111","111","101","110","110","110","110","110","110","110","110","110","110","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","100","111","110","110","111","111","111","111","111","111","111","111","111","101","110","110","110","110","110","110","101","101","101","111","111","111","111","101","101","110","110","110","110","110","110","110","110","110","110","100","110","110","110","111","111","111","111","111","111","111","111","111","110","101","110","110","110","110","110","110","101","111","111","111","111","111","111","111","110","101","111","110","110","110","110","110","110","110","101","101","110","110","110","111","111","111","111","111","111","111","111","111","110","101","110","110","110","110","110","101","111","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","111","100","101","110","110","110","111","111","111","111","111","111","111","111","111","101","110","110","110","110","110","101","111","111","111","111","111","111","111","111","111","111","110","101","111","110","110","110","110","110","111","101","110","111","111","111","111","111","111","111","111","111","111","111","101","110","110","110","110","110","101","111","111","111","111","111","111","111","111","111","111","111","111","101","111","110","110","110","110","110","110","110","110","111","111","111","111","111","111","111","111","111","111","110","101","111","110","110","111","101","110","111","111","111","111","111","111","111","111","111","111","111","111","110","111","110","110","110","110","110","101","110","111","111","111","111","111","111","111","111","111","111","111","111","101","110","111","110","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","110","111","110","110","110","110","110","101","101","111","111","111","111","111","111","111","111","111","111","111","111","111","101","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","111","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","111","111","111","111","111","111","111","111","101","111","110","110","110","110","110","110","110","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","110","110","110","111","111","111","111","111","111","111","101","111","110","110","110","110","110","110","110","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","110","111","110","101","111","111","111","111","111","111","111","101","110","110","110","110","110","110","110","110","110","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","110","110","110","110","101","111","111","111","111","111","111","110","110","111","110","110","110","110","110","110","110","111","110","101","110","111","111","111","111","111","111","111","111","111","111","111","111","110","100","110","110","110","110","110","101","111","111","111","111","111","111","101","110","111","110","110","110","110","110","110","110","110","111","110","101","101","110","111","111","111","111","111","111","111","111","110","101","101","110","110","110","110","110","110","101","111","111","111","111","111","111","101","111","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","110","110","110","110","101","101","101","110","110","110","110","110","110","110","110","101","111","111","111","111","111","110","101","111","110","110","110","110","110","110","110","110","110","110","110","110","110","110","111","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","111","111","111","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","110","110","101","110","110","101","101","110","101","101","111","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","111","110","111","111","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101");
---------------------------------------
--constant n3_B : number:=("001","001","000","000","000","001","001","000","000","000","000","001","001","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","000","000","000","001","001","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","001","001","001","001","001","001","000","000","001","001","000","000","000","000","000","000","001","001","000","000","000","001","000","000","000","000","000","000","001","000","000","000","000","000","001","001","001","000","000","000","001","001","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","001","001","001","000","000","000","000","001","001","001","000","001","000","000","001","000","000","000","000","000","000","001","001","000","000","000","001","000","000","000","000","000","001","001","001","000","000","001","001","001","001","001","001","000","000","000","000","000","000","001","001","001","001","000","000","000","000","001","000","000","000","001","001","000","000","001","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","001","000","000","000","000","000","000","001","001","001","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","000","000","000","000","000","001","001","000","000","000","000","001","001","000","000","000","000","000","000","000","000","001","001","001","001","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","001","000","000","000","000","001","001","000","000","001","001","001","001","000","001","000","000","001","001","000","001","001","000","000","000","000","000","000","001","001","000","001","000","000","001","001","000","001","000","000","000","000","000","000","000","001","000","000","000","001","001","001","000","000","001","000","000","000","001","000","001","001","001","000","000","001","000","000","001","001","001","000","000","001","001","000","000","000","001","000","000","000","000","001","000","000","000","000","001","001","001","001","000","000","001","000","000","000","001","000","000","000","000","001","010","010","001","000","000","000","000","000","000","001","001","000","000","000","001","000","000","000","000","001","001","000","000","000","001","001","001","001","000","000","000","000","000","001","001","001","000","000","001","010","001","001","010","000","000","000","000","000","001","001","000","000","000","000","000","001","000","000","001","001","001","000","000","001","001","001","001","000","000","000","001","000","000","000","000","000","000","001","010","001","001","001","010","001","000","001","000","000","001","001","000","000","000","000","000","001","000","000","000","001","001","000","000","001","001","000","001","000","000","000","000","000","000","000","000","000","000","001","001","001","001","010","010","010","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","001","000","000","000","001","000","001","000","001","001","001","010","010","011","000","000","000","000","010","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","001","000","000","000","001","001","001","001","001","001","010","010","010","010","010","001","001","001","001","001","001","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","001","001","001","001","010","010","010","010","010","010","010","010","001","001","001","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","001","001","001","000","000","010","010","001","010","001","001","001","001","001","000","000","000","000","000","001","000","000","000","000","001","001","000","000","000","000","000","001","000","000","000","001","001","000","000","000","001","010","000","000","000","001","001","001","001","001","001","001","001","000","000","000","000","000","000","001","000","000","000","000","000","001","001","000","000","000","000","001","000","000","000","000","001","001","001","000","001","001","000","000","000","000","010","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","001","001","000","001","001","000","000","000","000","000","000","001","000","000","000","001","001","001","001","000","001","001","000","000","001","001","001","001","001","001","001","000","000","000","000","000","001","000","000","000","000","000","000","001","001","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","001","001","000","000","000","010","001","001","001","000","000","000","000","000","001","001","000","000","000","001","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","000","001","010","001","001","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","001","001","000","001","000","000","001","001","001","000","000","001","000","000","000","000","000","001","000","001","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","001","001","001","001","000","000","000","000","001","001","000","000","000","000","000","000","001","001","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","001","001","001","001","000","000","000","000","001","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","000","000","000","001","001","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","000","000","000","001","001","000","000","000","000","001","001","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000");
--constant n3_G : number:=("100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","110","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","110","110","111","110","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","100","110","111","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","100","110","111","100","100","100","100","100","100","101","100","100","100","100","100","100","100","111","111","111","111","111","111","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","101","100","100","110","111","101","100","100","011","110","111","111","110","100","100","100","100","100","101","111","111","111","111","111","111","110","100","100","100","100","100","100","100","100","100","100","100","100","011","110","110","100","101","111","111","110","100","011","110","111","111","111","111","100","100","100","100","100","110","111","111","111","111","111","111","111","100","100","100","100","100","100","100","100","100","100","100","100","011","101","111","111","111","111","111","111","110","111","111","111","111","111","111","101","100","100","100","100","110","111","111","111","111","111","111","111","101","100","100","100","100","100","100","100","100","100","100","100","011","101","111","111","111","111","111","111","111","111","111","111","111","111","111","110","100","100","100","100","111","111","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","011","100","101","111","111","111","111","111","111","111","111","110","100","100","100","100","100","100","100","100","100","100","100","100","100","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","110","111","111","111","111","111","111","111","111","111","110","100","100","100","100","100","100","100","100","100","100","100","100","100","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","111","111","111","111","101","100","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","111","111","111","111","111","111","111","101","100","100","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","111","111","111","111","111","110","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","111","111","110","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","111","111","111","110","100","100","100","100","100","111","111","111","111","111","111","111","111","111","111","111","111","111","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","101","100","100","100","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","110","111","111","111","111","111","111","111","111","111","110","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","111","111","111","110","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","110","110","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100");
--constant n3_R : number:=("110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","111","111","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","111","111","111","111","101","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","110","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","111","101","110","111","111","101","110","110","110","110","101","101","101","110","110","110","110","110","101","110","111","111","111","111","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","101","111","110","101","111","111","101","110","110","110","101","101","111","110","110","110","110","110","110","101","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","111","101","101","111","111","110","101","110","101","111","111","111","111","101","110","110","110","101","110","111","111","111","111","111","111","111","101","110","110","110","110","110","110","110","110","110","110","110","101","111","111","101","110","111","111","111","101","101","111","111","111","111","111","101","110","110","110","101","111","111","111","111","111","111","111","111","101","110","110","110","110","110","110","110","110","110","110","110","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","110","110","101","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","110","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","110","101","101","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","110","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","101","110","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","110","110","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","111","111","111","111","111","111","111","111","111","111","101","110","110","110","110","110","110","110","110","110","110","110","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","111","111","111","111","111","111","111","111","101","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","111","111","111","111","111","111","111","110","101","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","111","111","111","111","111","111","101","101","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","111","111","111","111","101","110","110","101","101","111","111","111","111","111","111","111","111","111","111","111","111","111","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","101","110","110","110","110","101","110","111","111","111","111","111","111","111","111","111","111","111","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","101","111","111","111","111","111","111","111","111","111","111","111","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","101","110","111","111","111","111","111","111","111","111","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","111","111","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110");
---------------------------------------
--constant n4_B : number:=("001","001","001","000","000","000","000","000","000","000","001","001","001","001","001","001","000","000","000","000","000","000","000","000","001","001","000","000","000","001","001","000","001","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","001","001","000","000","001","001","000","000","000","000","000","001","001","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","000","000","000","001","001","001","000","000","000","001","001","001","001","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","001","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","001","001","001","001","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","001","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","001","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","001","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","001","001","001","001","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","001","001","000","000","000","000","000","000","000","000","001","001","001","001","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","001","000","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","001","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","001","001","001","001","001","001","000","001","000","000","000","000","000","001","001","001","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","000","001","001","001","001","001","001","000","000","000","000","000","000","000","001","001","001","001","001","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","001","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","001","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","001","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","001","000","000","000","001","001","000","001","001","000","000","000","001","001","001","001","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","001","001","001","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","001","001","000","001","000","000","001","001","000","000","000","001","001","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","000","000","000","000","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","001");
--constant n4_G : number:=("100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","100","011","011","011","100","100","101","101","100","100","100","100","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","100","100","101","110","110","101","101","101","100","100","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","110","111","111","111","111","111","111","111","110","101","100","100","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","110","111","111","111","111","111","111","111","111","111","111","111","110","100","100","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","101","101","101","110","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","101","100","100","110","111","111","111","111","111","111","111","111","111","111","111","111","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","110","101","100","101","110","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","101","101","100","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","110","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","101","110","110","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","100","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","100","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","110","111","111","111","111","111","111","111","110","101","101","101","111","111","111","111","111","111","100","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","110","110","110","101","101","100","100","101","100","100","101","111","111","111","111","111","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","100","100","100","100","101","100","100","100","100","101","100","111","111","111","111","111","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","111","111","111","111","110","100","100","100","100","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","111","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","100","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","100","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","100","101","101","101","111","111","111","111","111","111","110","110","110","110","110","110","101","100","100","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","100","101","111","111","111","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","110","111","110","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100");
--constant n4_R : number:=("110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","111","110","110","110","110","110","110","110","111","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","101","101","110","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","101","100","010","010","010","011","100","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","100","011","010","010","011","011","011","011","010","010","011","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","100","011","011","011","011","011","011","011","011","100","011","011","011","011","100","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","011","011","100","100","011","011","011","011","011","011","011","011","100","100","100","011","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","011","100","101","100","011","100","011","011","011","011","011","011","011","011","011","100","011","011","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","011","100","101","101","101","100","100","011","011","011","011","011","011","011","011","011","011","100","010","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","011","100","101","101","101","101","100","100","100","011","011","011","011","011","011","011","011","011","100","011","100","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","010","100","101","100","100","100","100","011","011","011","011","011","011","100","100","100","100","100","100","100","011","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","010","011","101","100","100","100","011","011","011","011","011","011","100","100","100","100","100","100","100","100","011","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","011","011","100","100","100","011","011","011","011","011","100","011","100","100","100","100","100","100","100","100","011","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","011","011","100","100","011","011","100","100","100","011","011","011","011","100","100","100","100","100","100","011","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","010","011","011","011","011","011","011","011","011","101","100","011","011","100","100","100","100","100","011","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","100","011","011","011","011","100","101","101","101","101","101","010","100","100","100","100","100","011","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","101","101","101","101","101","100","010","100","100","100","100","011","010","100","101","101","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","100","100","011","011","010","010","100","100","100","100","100","011","011","011","011","011","011","011","100","100","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","010","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","100","011","011","011","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","011","011","100","011","100","011","100","100","100","100","100","100","100","100","011","011","011","011","011","011","011","011","101","110","110","110","110","110","110","110","110","110","110","110","101","101","110","110","110","101","010","100","100","011","100","100","100","100","100","011","100","011","011","011","011","011","011","011","011","011","011","011","101","110","110","110","110","110","110","110","110","110","110","110","101","101","110","110","110","101","010","100","100","011","011","100","011","011","011","011","011","011","011","011","011","011","011","011","011","011","011","011","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","011","100","100","011","011","011","011","011","011","011","011","011","011","011","011","011","011","011","011","011","011","101","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","101","101","100","010","011","010","010","011","011","011","011","011","011","011","011","011","011","011","011","010","010","011","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","100","011","010","100","011","011","010","011","011","011","011","011","011","011","100","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","011","100","100","011","011","100","101","101","101","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","011","100","011","100","101","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","101","101","101","101","101","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101");
---------------------------------------
--constant n5_B : number:=("000","000","000","001","001","001","000","000","000","000","000","000","001","000","000","000","000","000","000","001","001","001","001","000","000","000","001","001","001","000","000","000","000","000","000","001","000","001","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","001","000","000","001","001","000","000","000","000","000","000","001","000","001","000","000","000","000","001","001","001","000","000","000","000","000","000","001","000","000","000","001","001","001","000","001","000","000","000","000","000","000","000","000","000","001","000","000","000","000","001","000","000","001","001","000","000","001","001","001","001","000","000","000","000","000","001","001","001","001","001","001","010","001","001","000","000","000","000","001","000","001","000","001","001","010","010","010","010","010","001","001","000","001","001","000","000","001","001","001","000","000","000","000","000","001","001","010","010","011","011","011","011","010","001","001","000","000","000","001","001","000","001","001","011","011","011","011","011","011","010","001","000","001","001","000","000","001","001","001","000","000","000","000","010","010","010","010","010","011","011","011","010","010","010","010","010","001","000","001","001","001","001","011","010","100","101","101","100","011","011","001","001","000","001","001","001","001","001","001","000","000","000","010","011","011","100","101","110","110","111","111","111","110","101","011","011","010","001","001","001","010","010","010","101","111","111","111","111","110","011","011","010","001","001","000","000","000","001","001","001","001","001","010","010","100","110","111","111","111","111","111","111","111","111","111","011","010","001","001","001","010","010","101","111","111","111","111","111","111","110","011","011","010","000","000","000","000","000","000","001","010","010","010","100","100","011","100","110","111","111","111","111","111","111","111","101","010","010","001","001","011","010","110","111","111","111","111","111","111","111","110","011","010","001","000","000","000","001","000","001","010","010","100","011","010","010","100","101","111","111","111","111","111","111","111","110","011","011","001","001","011","011","110","111","111","111","111","111","111","111","111","100","010","001","000","001","000","001","000","010","011","011","011","010","001","010","101","110","111","111","111","111","111","111","111","111","011","011","001","001","011","011","111","111","111","111","111","111","111","111","111","100","010","001","001","001","001","000","001","010","011","100","010","001","001","011","110","111","111","111","111","111","111","111","111","111","011","100","001","001","011","011","111","111","111","111","111","111","111","111","111","100","010","000","000","000","000","000","001","010","011","100","010","001","011","100","111","111","111","111","111","111","111","111","111","111","100","011","001","001","011","100","111","111","111","111","111","111","111","111","111","101","010","001","000","000","000","000","001","010","011","101","010","010","100","110","111","111","111","111","111","111","111","111","111","111","101","100","010","010","011","110","111","111","111","111","111","111","111","111","111","101","011","001","000","000","000","001","010","010","101","110","101","101","110","111","111","111","111","111","111","111","111","111","111","111","110","011","100","011","100","111","111","111","111","111","111","111","111","111","111","100","010","000","000","000","000","001","010","010","101","111","110","110","111","111","111","111","111","110","110","110","111","111","111","111","111","101","011","011","110","111","111","111","111","111","111","111","111","111","111","100","010","000","000","000","000","001","010","010","101","111","111","111","111","111","111","111","100","011","100","011","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","011","010","000","000","000","000","001","010","010","101","111","111","111","111","111","111","101","011","100","011","011","100","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","011","010","000","001","001","000","001","001","010","100","111","111","111","111","111","111","100","011","010","010","011","011","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","011","010","000","000","001","000","001","001","011","100","111","111","111","111","111","111","011","011","001","001","010","011","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","011","011","001","000","000","000","000","000","001","011","100","111","111","111","111","111","111","011","010","001","000","010","011","100","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","011","011","001","000","000","000","000","000","001","010","011","110","111","111","111","111","110","011","010","001","000","001","011","010","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","100","011","010","001","000","000","000","000","000","000","001","011","100","111","111","111","111","101","011","010","000","001","001","010","010","101","111","111","111","111","111","111","111","111","111","111","111","111","111","100","011","010","001","001","000","001","000","000","000","000","001","010","011","100","110","111","110","011","011","001","000","000","001","001","011","011","111","111","111","111","111","111","111","111","111","111","111","111","100","011","011","001","001","000","000","001","001","000","000","000","000","001","010","011","011","011","011","010","010","001","000","000","001","000","010","011","100","111","111","111","111","111","111","111","111","111","111","100","011","010","010","001","000","000","000","001","001","000","000","001","000","000","001","010","011","011","011","010","001","000","000","000","000","000","001","011","011","011","110","111","111","111","110","110","110","101","011","011","011","001","001","001","000","000","000","001","001","000","001","001","001","000","000","000","001","001","001","001","001","000","000","000","000","000","001","001","010","011","010","011","100","100","011","010","010","010","011","010","010","001","000","000","001","000","000","001","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","010","010","011","011","011","011","011","010","010","001","001","000","000","000","000","001","001","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","001","001","001","010","001","001","001","001","001","001","001","000","000","000","001","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","001","001","000","000","000","001","000","000","000","000","001","000","001","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","001","001","000","001","001","001","000","000","001","001","000","000","000","000","001","000","000","000","001","001","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","001","001","001","000","000","001","001","000","000","000","000","000","000","000","000","001","001","000","000","000","001","001","001","000","000","000","000","000","000");
--constant n5_G : number:=("100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","100","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","011","100","011","011","011","100","011","100","100","100","100","100","100","100","100","100","100","010","001","001","010","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","010","010","001","001","001","001","010","010","011","100","100","100","100","100","100","100","011","001","001","010","010","001","001","011","100","100","100","100","100","100","100","100","100","100","100","100","100","011","001","001","010","010","011","011","011","011","011","010","001","010","100","100","100","100","100","011","001","010","011","011","011","011","010","001","010","100","100","100","100","100","100","100","100","100","100","100","010","001","010","011","011","011","011","011","011","011","011","100","011","001","011","100","100","100","100","010","010","011","011","011","011","010","011","010","001","011","100","100","100","100","100","100","100","100","100","011","001","011","100","100","100","011","011","011","011","011","011","011","100","011","010","100","100","100","100","001","011","011","011","011","011","011","011","011","010","001","100","100","100","100","100","100","100","100","011","001","011","011","100","100","100","011","011","011","100","011","100","100","100","011","001","011","100","100","011","001","011","011","011","011","011","011","011","011","010","001","100","100","100","100","100","100","100","100","010","001","100","100","100","100","100","011","011","011","100","100","100","100","100","100","001","011","100","100","011","001","011","011","011","011","011","011","010","011","011","001","100","100","100","100","100","100","100","011","001","011","011","100","100","100","011","011","011","011","100","100","100","100","100","100","001","011","100","100","011","001","100","011","011","011","011","011","011","011","011","001","100","100","100","100","100","100","100","011","001","011","100","100","100","011","100","011","011","011","100","100","100","100","100","100","001","011","100","100","010","001","100","011","011","011","011","011","011","011","011","010","100","100","100","100","100","100","100","010","010","011","011","100","011","011","011","011","011","100","100","100","100","100","101","100","010","010","100","100","001","011","100","011","011","011","011","011","011","011","011","001","100","100","100","100","100","100","011","001","010","011","011","011","011","011","011","011","100","100","100","100","100","100","101","101","011","001","011","011","001","011","011","100","011","011","011","011","011","011","011","001","100","100","100","100","100","100","100","001","001","011","011","011","011","011","011","100","100","011","010","011","101","100","100","101","101","011","001","001","011","100","100","011","011","011","011","011","011","011","011","001","100","100","100","100","100","100","100","001","001","011","011","011","011","011","011","011","010","001","010","001","011","101","100","101","101","101","100","100","100","100","100","100","011","011","011","011","011","011","010","001","100","100","100","100","100","100","100","010","001","011","011","011","011","011","100","010","001","011","011","011","001","100","100","101","101","101","100","100","100","100","100","100","011","011","011","011","010","011","010","001","100","100","100","100","100","100","100","011","001","010","010","011","011","011","011","001","011","100","100","100","001","100","100","100","100","101","100","100","100","100","100","011","011","011","011","011","011","011","010","010","100","100","100","100","100","100","100","011","001","011","011","011","011","011","011","001","100","011","100","100","010","011","101","100","100","100","100","100","100","100","100","011","011","011","011","011","011","011","001","011","100","100","100","100","100","100","100","100","001","010","010","010","011","011","011","001","011","100","100","100","011","010","100","100","100","100","100","100","100","100","100","011","011","011","011","011","011","010","010","100","100","100","100","100","100","100","100","100","001","010","011","011","011","011","010","001","011","100","100","100","100","001","011","100","100","100","100","100","100","100","011","011","011","011","011","011","010","001","011","100","100","100","100","100","100","100","100","100","010","001","011","010","010","011","010","010","100","100","100","100","100","010","010","100","100","100","100","100","100","011","011","011","011","011","011","011","001","010","100","100","100","100","100","100","100","100","100","100","100","010","001","010","011","011","001","011","100","100","100","100","100","100","001","011","100","100","100","011","011","011","011","011","011","011","011","010","001","100","100","100","100","100","100","100","100","100","100","100","100","011","010","010","001","001","010","011","100","100","100","100","100","100","010","001","011","011","011","011","011","011","011","011","011","011","001","010","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","011","011","100","100","100","100","100","100","100","100","100","010","001","011","011","011","011","011","011","011","010","001","010","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","100","011","001","001","010","010","010","001","001","010","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","011","011","011","011","011","011","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100");
--constant n5_R : number:=("110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","100","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","100","100","100","100","100","100","101","110","110","110","110","110","110","110","110","110","100","100","101","101","100","100","101","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","100","101","110","110","110","110","111","110","101","100","101","110","110","110","110","110","110","100","101","110","110","110","110","110","100","101","110","110","110","110","110","110","110","110","110","110","110","101","100","101","110","110","110","111","110","110","111","110","111","110","100","110","110","110","110","110","101","101","111","110","110","110","110","110","110","100","110","110","110","110","110","110","110","110","110","110","101","100","110","111","110","110","110","110","110","110","110","111","111","111","110","100","110","110","110","110","100","110","111","110","110","110","110","110","110","110","100","110","110","110","110","110","110","110","110","110","100","110","110","110","110","110","110","110","110","110","110","111","111","111","110","100","110","110","110","110","100","111","110","110","110","110","110","110","110","110","100","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","110","110","110","110","110","111","111","111","111","100","110","110","110","110","100","111","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","100","110","110","110","110","110","110","110","111","110","110","110","111","111","111","111","100","110","110","110","110","100","111","111","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","100","110","110","110","110","110","111","111","110","110","110","111","111","111","111","111","100","110","110","110","101","100","111","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","101","101","110","110","110","110","110","111","110","110","111","110","111","111","111","111","111","101","101","110","110","100","110","111","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","100","101","110","110","110","110","110","110","110","110","111","111","111","111","111","111","111","110","100","110","110","100","110","110","111","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","100","101","110","110","110","110","110","110","111","110","101","101","110","111","111","111","111","111","110","100","100","110","111","111","110","110","110","110","110","110","110","110","100","110","110","110","110","110","110","110","100","101","110","110","110","110","110","111","110","101","100","101","100","110","111","111","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","100","110","110","110","110","110","110","110","100","100","110","110","110","110","110","111","101","100","110","110","110","100","111","111","111","111","111","111","111","111","111","111","110","110","110","110","111","110","110","110","100","110","110","110","110","110","110","110","101","100","110","110","110","110","110","110","100","101","110","110","110","100","111","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","110","110","110","100","110","110","110","110","111","110","100","110","110","110","110","100","110","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","100","110","110","110","110","110","101","110","110","110","100","110","110","110","110","110","110","100","110","110","110","110","101","100","111","111","111","110","111","110","110","110","110","110","110","110","110","110","110","101","100","110","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","100","110","110","110","110","110","100","110","111","111","111","111","110","110","110","110","110","110","110","110","110","110","100","110","110","110","110","110","110","110","110","110","110","101","100","110","110","110","111","101","101","110","110","110","110","110","101","101","111","111","111","110","110","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","101","110","110","110","110","110","101","100","101","110","110","100","110","110","110","110","110","110","110","100","110","111","111","110","110","110","110","110","110","110","110","110","101","100","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","100","100","101","110","110","110","110","110","110","110","101","100","111","111","110","110","110","110","110","110","110","110","100","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","110","111","110","110","110","110","110","101","100","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","100","101","101","101","100","100","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110");
----------------------------------------
--constant n6_B : number:=("001","001","000","001","001","001","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","001","000","000","000","001","001","000","000","001","001","000","000","000","000","000","000","000","000","000","001","001","001","001","000","000","000","000","000","001","001","001","000","000","001","001","000","000","000","000","000","001","001","001","001","000","000","000","000","001","001","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","001","001","001","001","001","001","001","000","000","000","001","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","001","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","001","001","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","001","001","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","001","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","001","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","001","001","000","001","001","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","001","001","000","000","001","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","001","001","000","001","000","000","000","000","000","000","000","000","000","001","001","000","000","001","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","001","001","000","000","000","000","000","001","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","001","001","001","000","000","000","001","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","001","001","000","000","000","001","001","001","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","001","001","001","001","001","001","001","001","000","000","001","001","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","001","001","000","000","000","001","001","000","000","001","001","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","001","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","001","001","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","001","001","000","000","000","000","001","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","001","001","001","000","000","001","001","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","001");
--constant n6_G : number:=("100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","101","100","100","100","100","100","100","100","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","101","101","101","101","101","110","110","110","110","110","110","110","101","101","101","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","101","100","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","101","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","100","101","100","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","101","101","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","100","100","101","110","111","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","100","100","100","100","100","100","100","100","101","101","110","101","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","101","100","100","100","100","100","100","101","100","101","101","100","100","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","101","100","100","100","100","100","100","101","101","101","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","101","101","100","100","100","110","111","111","111","111","111","111","111","101","101","110","111","111","111","111","101","101","101","101","110","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","110","101","100","100","101","110","111","111","111","111","111","110","101","101","110","111","111","111","111","101","101","100","100","101","100","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","110","110","101","100","101","111","111","111","111","111","111","101","101","110","111","111","111","111","110","101","101","100","100","101","101","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","110","111","110","110","111","111","111","111","111","111","101","101","101","111","111","111","111","111","110","101","100","100","100","101","101","111","111","111","111","111","111","101","101","100","100","100","100","100","100","101","101","111","111","111","111","111","111","111","111","110","101","101","101","111","111","111","111","111","110","100","100","100","100","101","110","111","111","111","111","111","111","101","101","100","100","100","100","100","100","101","101","110","111","111","111","111","111","111","111","101","101","101","101","111","111","111","111","111","111","101","101","100","101","110","111","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","101","101","111","111","111","111","111","111","110","101","101","101","101","111","111","111","111","111","111","111","110","110","111","111","111","111","111","111","111","111","110","101","100","100","100","100","100","100","100","100","100","101","101","110","111","111","111","111","101","101","100","101","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","100","100","100","101","101","101","110","110","101","101","100","100","100","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","101","101","100","100","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","101","110","111","111","111","111","111","111","111","111","110","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","101","101","101","101","110","101","101","101","101","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100");
--constant n6_R : number:=("101","110","110","110","110","110","110","101","101","110","110","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","101","101","101","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","101","101","101","100","100","011","011","011","100","100","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","100","100","011","011","100","100","100","100","100","100","100","011","011","100","100","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","100","011","011","100","100","100","100","100","100","100","100","100","100","100","101","100","100","011","100","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","101","100","100","100","101","101","110","110","110","110","101","110","110","110","110","110","110","110","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","100","100","101","110","110","110","110","101","110","110","110","110","110","110","110","101","100","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","110","110","110","110","110","110","110","110","110","110","101","100","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","110","110","110","110","110","110","110","110","110","101","100","100","101","101","100","100","100","100","100","100","100","100","100","100","101","100","100","101","100","100","100","100","100","100","100","100","100","100","100","100","101","110","110","110","110","110","110","110","110","101","100","100","101","101","101","101","100","100","100","100","100","100","100","101","101","101","101","101","101","100","100","100","100","100","100","100","100","100","100","100","101","101","110","110","110","110","110","110","101","101","100","101","101","100","101","101","100","100","100","101","101","100","100","101","101","101","101","101","101","101","101","101","101","100","100","100","100","100","100","100","100","101","110","110","110","110","110","110","101","100","100","101","101","101","100","101","101","100","100","100","100","101","101","101","101","101","101","101","101","101","101","101","101","101","100","100","100","100","100","100","100","101","110","110","110","110","110","110","100","100","101","101","110","101","101","101","101","100","100","101","100","101","100","100","100","101","101","101","101","101","100","100","100","100","101","101","100","100","100","101","100","101","110","110","110","110","110","101","100","100","110","101","101","101","101","101","100","100","100","100","101","100","011","010","100","101","101","101","100","011","011","011","011","100","101","100","100","100","100","101","100","101","110","110","110","101","110","101","011","101","101","101","101","101","101","101","100","100","100","100","100","011","010","011","101","101","101","101","011","100","101","101","101","011","101","101","100","100","101","101","100","101","110","110","110","110","110","101","011","100","101","101","101","101","101","100","101","101","100","100","011","011","011","101","101","101","101","101","100","101","101","101","101","100","101","100","100","100","100","101","100","101","110","110","110","110","110","101","011","011","101","101","101","101","101","100","101","101","100","011","100","011","101","101","101","101","101","100","100","101","110","101","100","011","100","101","100","101","100","101","100","101","110","110","110","110","110","101","100","011","100","101","101","101","100","100","100","101","100","011","100","011","110","101","101","101","101","100","100","101","101","101","100","100","100","100","100","100","100","100","011","101","110","110","110","110","110","101","101","100","100","101","101","100","100","100","100","101","011","100","100","100","101","101","101","101","101","101","011","011","011","100","100","101","100","100","100","100","100","100","100","101","110","110","110","110","110","110","101","100","100","100","100","100","100","100","101","100","100","100","100","100","101","101","101","101","101","101","101","100","100","101","101","101","100","101","100","100","101","011","101","101","110","110","110","110","110","110","110","101","100","100","100","100","100","100","100","011","101","101","101","100","101","101","101","101","101","101","101","101","101","101","101","101","101","101","100","100","100","100","101","110","110","110","110","110","110","110","110","110","101","101","100","011","100","100","011","100","101","101","101","100","100","101","100","101","101","101","101","101","101","101","101","100","101","101","100","101","100","101","101","110","110","110","110","110","110","110","110","110","101","101","101","101","101","101","101","101","110","110","101","100","100","101","101","100","100","101","100","101","101","101","101","101","100","100","100","100","100","101","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","101","110","110","110","110","110","101","100","100","101","101","100","101","100","101","101","101","101","101","100","100","100","100","101","110","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","101","101","100","100","101","101","101","101","101","101","100","100","100","011","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","100","011","100","100","100","100","100","011","011","100","101","101","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","101","101","101","101","101","101","101","101","101","110","110","110","110","110","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110");
-----------------------------------------
--constant n7_B : number:=("001","001","001","001","001","001","000","000","000","001","000","001","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","000","000","000","000","000","000","000","000","001","001","001","001","001","001","001","001","001","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","001","001","000","000","000","000","000","000","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","001","001","010","001","000","000","001","001","000","000","000","000","001","000","000","000","000","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","001","010","001","001","010","010","001","001","010","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","010","000","010","011","100","100","100","010","001","001","001","000","001","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","010","001","001","011","011","100","011","101","100","001","010","010","000","001","001","001","010","001","001","001","001","001","000","001","000","001","001","001","001","000","000","000","000","000","000","000","000","001","001","001","001","001","011","001","010","011","100","101","101","011","010","010","001","001","001","010","001","001","001","001","001","001","000","001","001","001","001","001","001","001","000","000","000","000","000","000","000","000","001","010","000","001","011","001","010","011","100","101","101","100","001","010","001","001","010","010","100","101","100","001","010","001","000","000","000","001","001","001","001","001","000","000","001","000","000","000","000","000","001","010","000","010","011","001","010","100","100","101","101","100","010","010","001","001","001","011","110","110","110","011","010","001","000","000","001","001","000","000","000","000","000","000","000","000","000","000","001","000","010","010","001","010","011","010","010","100","101","110","110","101","010","010","001","010","001","101","111","111","110","100","001","010","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","010","001","001","011","011","011","011","101","110","110","110","101","010","010","001","010","001","110","111","111","110","101","010","010","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","010","000","010","100","100","101","101","101","110","110","110","100","010","010","001","010","010","110","111","111","110","101","010","010","000","001","001","001","001","001","000","000","000","000","000","000","000","000","001","001","010","001","010","100","101","101","110","110","110","110","110","011","010","001","010","010","011","110","111","111","111","101","001","010","001","001","001","001","001","001","001","001","000","000","000","000","000","000","000","001","010","001","010","100","101","101","110","110","110","110","110","010","010","001","010","010","100","110","111","111","111","101","010","011","010","010","010","010","010","010","001","001","001","001","000","000","000","000","000","001","001","000","010","100","101","101","101","110","110","110","110","010","011","010","010","010","101","111","111","111","111","110","011","010","001","001","001","001","001","001","001","001","010","001","000","000","001","000","000","000","001","001","010","100","101","101","110","110","110","110","110","011","010","011","011","010","101","111","111","111","111","111","110","100","100","101","101","101","100","100","011","010","001","001","000","000","001","001","000","000","001","010","001","100","101","110","110","110","110","110","110","101","100","100","100","100","110","111","111","111","111","111","111","110","110","110","110","110","110","101","101","100","001","001","000","001","000","001","000","000","001","010","001","100","101","110","110","110","110","110","110","110","110","110","111","111","111","111","111","111","111","111","110","110","110","110","110","110","101","101","101","100","010","010","000","000","000","001","001","000","001","010","001","100","101","101","110","110","110","110","110","110","110","111","111","111","111","111","111","111","111","111","110","111","111","110","110","101","101","101","101","100","010","010","001","000","000","000","000","000","001","010","001","011","101","101","110","110","110","110","110","110","110","111","111","111","110","111","111","111","110","111","111","110","110","110","110","101","101","101","101","100","001","010","001","000","000","000","000","000","001","001","001","010","101","101","101","110","101","110","110","110","111","110","111","111","111","111","111","111","110","111","110","110","110","101","101","101","101","101","100","010","001","010","001","000","000","000","000","000","001","001","001","001","011","100","101","101","101","110","110","110","110","110","110","110","111","110","111","111","111","110","110","101","100","100","100","011","011","010","001","001","010","001","000","000","000","000","000","000","000","000","001","001","010","011","100","100","101","101","110","110","101","100","100","100","110","110","111","111","111","110","100","010","010","010","010","010","010","010","010","010","001","001","000","000","000","000","000","000","000","000","001","010","001","001","011","100","100","100","100","011","001","001","010","011","100","110","110","110","110","100","010","011","010","010","010","010","010","001","001","001","000","000","001","000","000","000","000","001","001","000","001","001","010","010","001","001","010","010","010","010","010","010","010","010","011","101","101","110","101","011","010","010","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","001","001","001","000","000","001","001","010","010","010","010","010","001","001","001","001","010","010","101","101","101","101","010","010","001","000","000","000","000","000","000","000","000","000","000","001","000","000","001","000","001","001","001","000","000","000","000","001","001","001","000","000","000","000","000","001","010","001","011","100","100","100","001","010","001","000","001","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","001","000","000","000","000","000","000","001","001","000","000","000","000","001","001","010","000","001","001","001","001","010","001","001","000","001","000","000","001","001","000","000","000","000","001","001","001","001","000","000","000","000","000","000","000","001","000","000","001","000","000","000","000","001","001","001","010","010","010","010","001","001","001","001","001","001","000","000","001","001","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","001","000","000","000","000","000","000","000","000","001","000","000","001","001","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","001","000","000","001","000","001","001","000","000","000","000","000","000","000","000","000","001","001","001");
--constant n7_G : number:=("100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","010","000","000","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","001","000","000","000","000","001","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","001","001","001","001","000","000","000","010","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","001","001","100","011","010","000","000","000","000","011","100","011","100","100","100","011","011","011","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","010","000","011","100","100","011","001","000","000","000","001","011","100","100","100","010","000","000","000","010","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","001","001","011","100","100","011","000","000","000","000","000","100","100","100","011","000","001","001","001","000","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","000","010","011","100","011","010","000","000","000","001","000","100","100","100","010","000","001","000","001","000","001","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","100","010","000","010","011","100","011","001","000","000","000","001","000","100","100","100","000","001","001","000","001","001","000","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","001","000","001","010","010","001","000","000","000","000","000","000","100","100","011","000","001","001","001","000","001","000","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","000","000","000","000","000","000","000","000","000","000","001","001","100","100","010","000","010","001","001","001","001","000","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","000","000","000","000","000","000","000","000","000","001","000","001","100","100","010","001","010","001","001","001","001","000","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","001","000","000","000","000","000","000","000","000","001","000","010","100","100","001","001","010","001","001","001","001","000","011","100","100","011","011","011","100","100","100","100","100","100","100","100","100","100","100","100","001","000","000","000","000","000","000","000","000","001","000","011","100","011","001","001","010","010","001","001","001","000","001","001","000","000","000","000","000","001","010","100","100","100","100","100","100","100","100","100","010","000","000","000","000","000","000","000","000","001","000","000","010","010","000","010","010","010","001","001","001","001","000","001","001","000","000","000","000","000","000","001","100","100","100","100","100","100","100","100","010","000","000","000","000","000","000","000","000","001","001","000","000","001","001","010","010","010","001","001","001","001","001","000","000","000","000","000","000","000","001","000","100","100","100","100","100","100","100","100","011","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","001","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","100","100","100","100","100","100","100","100","100","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","011","100","100","100","100","100","100","100","100","001","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","100","100","100","100","100","100","100","100","100","010","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","001","100","100","100","100","100","100","100","100","100","011","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","001","000","000","000","000","000","000","001","100","100","100","100","100","100","100","100","100","100","100","001","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","010","011","100","100","100","100","100","100","100","100","100","100","100","100","100","001","000","000","000","000","000","000","000","000","001","010","000","000","000","000","000","000","000","000","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","010","000","000","000","000","001","010","011","100","100","001","000","001","000","000","000","000","001","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","010","000","000","000","000","000","000","010","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","000","000","000","000","000","000","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","000","000","000","000","010","100","100","100","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","100","100","100","100","100","100","100","100","100","100","011","011","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100");
--constant n7_R : number:=("110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","101","011","011","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","101","100","100","101","101","011","100","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","011","100","101","110","110","101","100","100","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","100","100","110","110","111","110","110","110","100","101","110","110","110","110","110","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","110","101","110","111","110","110","110","100","101","110","110","110","110","110","100","100","100","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","100","100","110","101","110","111","110","110","110","101","100","110","110","110","110","100","101","110","110","100","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","011","101","110","110","110","110","110","110","110","101","100","110","110","110","101","101","110","110","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","011","101","110","110","110","110","110","111","110","110","100","110","110","110","100","110","111","111","111","110","100","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","100","100","101","110","111","110","110","110","111","111","101","100","110","110","110","100","111","111","111","111","110","100","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","011","100","110","110","110","110","110","111","111","111","101","100","110","110","101","100","111","111","111","111","110","100","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","011","100","110","110","110","110","111","111","111","111","101","101","110","110","100","101","111","111","111","111","110","100","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","011","100","110","110","110","110","111","111","111","111","100","101","110","110","100","101","111","111","111","111","110","100","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","101","110","110","011","100","110","110","110","110","111","111","111","110","100","110","110","110","100","110","111","111","111","111","110","100","100","100","100","100","100","100","100","100","101","110","110","110","110","110","110","110","110","110","100","100","110","110","110","111","111","111","111","111","101","100","101","101","100","110","111","111","111","111","111","110","110","110","110","110","110","110","110","101","100","101","110","110","110","110","110","110","110","110","101","100","101","110","110","110","111","111","111","111","110","101","101","101","101","111","111","111","111","111","111","111","111","111","111","111","111","111","110","110","101","100","110","110","110","110","110","110","110","110","110","011","101","110","110","110","111","111","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","110","101","100","111","110","110","110","110","110","110","110","110","011","101","110","110","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","110","101","100","110","110","110","110","110","110","110","110","110","100","101","110","110","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","110","110","110","101","100","110","110","110","110","110","110","110","110","110","101","100","110","110","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","101","100","101","110","110","110","110","110","110","110","110","110","110","100","101","110","110","111","111","111","111","111","111","110","111","111","111","111","111","111","111","111","110","101","101","101","101","101","101","100","100","100","110","110","110","110","110","110","110","101","110","110","110","101","100","101","110","110","110","110","110","110","110","101","101","101","110","111","111","111","111","110","100","100","100","100","100","100","100","101","101","110","110","110","110","110","110","110","110","110","110","101","110","110","100","100","101","101","101","101","101","100","011","100","101","100","101","111","111","111","110","101","100","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","110","101","100","100","100","100","100","101","101","110","110","100","100","111","110","111","110","101","100","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","101","100","110","110","110","110","100","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","011","101","110","110","101","011","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","100","100","100","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110");
-----------------------------------------
--constant n8_B : number:=("000","000","001","001","001","001","000","000","000","000","000","000","000","001","001","001","000","001","001","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","000","000","000","000","001","001","000","000","001","001","001","001","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","000","000","000","000","001","001","001","001","001","000","000","001","001","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","000","000","000","000","000","000","000","000","001","001","001","001","001","001","000","000","000","000","000","001","001","001","001","001","001","001","001","001","001","000","000","000","000","000","000","001","001","001","001","000","000","000","000","000","000","000","000","000","001","010","010","011","011","010","010","001","000","000","000","001","001","010","010","010","011","011","010","010","001","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","001","001","010","011","100","101","101","101","011","010","001","001","001","001","010","011","100","101","101","101","100","011","010","001","001","000","000","000","001","001","001","001","000","000","001","001","000","000","000","001","001","010","100","110","111","111","111","111","111","101","011","010","010","010","100","110","111","111","111","111","111","110","101","011","010","001","001","001","001","001","000","001","000","000","001","001","001","001","000","001","010","011","110","111","111","111","111","111","111","111","101","011","011","101","110","111","111","111","111","111","111","111","111","110","011","010","001","001","000","000","000","000","000","000","001","001","001","001","000","001","011","101","111","111","111","111","111","111","111","111","110","101","101","110","111","111","111","111","111","111","111","111","111","111","101","011","001","001","000","000","000","000","000","000","001","001","001","001","000","001","011","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","100","010","001","000","000","000","000","000","000","000","001","001","001","000","010","100","111","111","111","110","101","110","111","111","111","111","111","111","111","111","110","110","111","111","111","111","111","111","111","111","110","011","001","000","000","000","000","000","000","001","000","000","001","001","010","101","111","111","110","100","011","100","110","111","111","111","111","111","111","110","100","100","101","111","111","111","111","111","111","111","110","011","001","001","000","000","000","001","001","001","000","000","001","001","011","110","111","111","110","010","001","010","100","110","111","111","111","111","111","100","010","010","011","101","111","111","111","111","111","111","111","100","010","001","000","000","000","000","000","000","000","000","001","001","011","110","111","111","101","010","001","001","011","110","111","111","111","111","110","011","001","001","010","100","110","111","111","111","111","111","111","100","010","001","000","000","000","000","000","000","000","001","001","001","011","110","111","111","110","010","001","010","011","110","111","111","111","111","110","010","001","000","001","010","101","111","111","111","111","111","111","101","010","001","001","000","000","000","000","000","000","001","001","001","011","110","111","111","110","011","010","010","011","110","111","111","111","111","110","011","001","000","001","010","101","111","111","111","111","111","110","101","010","001","001","000","000","000","000","000","000","000","001","001","010","101","111","111","111","101","011","011","100","111","111","111","111","111","110","011","001","001","001","010","101","110","111","111","111","111","111","101","010","001","001","000","000","000","000","000","000","000","000","001","010","101","111","111","111","111","101","101","110","111","111","111","111","111","111","100","010","010","010","011","110","111","111","111","111","111","111","101","010","001","000","000","000","000","000","000","000","000","000","000","010","100","110","111","111","111","111","111","111","111","111","111","111","111","111","110","100","011","011","101","111","111","111","111","111","111","111","100","010","001","000","000","000","001","001","000","000","000","000","000","001","011","101","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","101","111","111","111","111","111","111","111","110","100","010","001","000","001","001","001","001","000","000","000","000","000","001","010","011","110","111","111","111","111","111","111","111","110","110","111","111","111","111","111","111","111","111","111","111","111","111","111","110","011","001","001","000","001","001","001","001","000","000","000","000","000","001","001","010","100","110","111","111","111","111","111","110","100","100","110","111","111","111","111","111","111","111","111","111","111","111","110","100","010","001","001","000","001","001","001","001","000","000","000","000","000","000","000","001","010","100","101","110","110","101","100","011","010","010","101","111","111","111","111","111","111","111","111","111","111","111","101","011","001","001","000","000","001","001","000","000","000","000","000","000","000","000","000","000","001","010","011","011","011","011","010","001","001","001","011","101","111","111","111","111","111","111","111","111","111","110","100","010","001","001","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","001","001","010","001","001","001","001","001","001","010","011","101","111","111","111","111","111","111","110","101","100","010","001","001","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","001","001","001","001","001","001","001","001","001","001","011","100","101","101","110","101","101","100","011","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","001","001","001","001","001","010","010","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","001","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","001","001","001","001","001","001","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","001","001","001","001","000","000","000","000","000","000","001","000","000","000","000","001","001","001","001","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","001","001","001","001","001","000","000","000","001","000","001","001","000","000","000","001","001","001");
--constant n8_G : number:=("100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","101","101","101","101","100","100","100","100","100","100","100","101","101","101","101","101","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","110","111","111","111","110","101","100","100","100","100","100","101","110","110","111","110","110","101","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","110","111","111","111","111","111","111","110","101","101","100","101","110","111","111","111","111","111","111","111","110","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","111","111","111","111","111","101","101","110","111","111","111","111","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","110","111","111","111","111","111","111","111","111","111","110","110","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","100","100","100","100","100","100","100","100","100","100","100","100","100","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","100","100","100","100","100","100","100","100","100","101","110","111","111","111","110","101","110","111","111","111","111","111","111","111","111","110","110","111","111","111","111","111","111","111","111","111","110","100","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","101","100","101","110","111","111","111","111","111","111","110","101","100","101","110","111","111","111","111","111","111","111","110","101","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","101","101","101","101","111","111","111","111","111","111","101","100","100","100","101","111","111","111","111","111","111","111","110","101","101","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","101","101","101","101","111","111","111","111","111","111","101","100","100","100","101","110","111","111","111","111","111","111","111","101","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","101","101","101","101","111","111","111","111","111","111","101","100","100","100","100","110","111","111","111","111","111","111","111","101","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","111","101","101","110","111","111","111","111","111","111","101","100","100","100","101","110","111","111","111","111","111","111","111","101","100","100","100","100","100","100","100","100","100","100","100","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","100","100","101","111","111","111","111","111","111","111","110","101","100","100","100","100","100","100","100","100","100","100","100","100","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","101","110","111","111","111","111","111","111","111","110","100","100","100","100","100","100","100","100","100","100","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","100","100","100","100","100","100","100","100","100","100","100","100","100","100","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","110","111","111","111","111","111","111","111","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","110","111","111","111","111","110","101","100","101","111","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","110","110","101","101","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","110","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","110","111","111","111","111","111","111","111","111","110","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","101","110","110","111","111","111","110","110","101","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100");
--constant n8_R : number:=("110","110","110","110","110","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","101","101","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","101","101","101","101","101","110","110","110","110","110","101","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","100","100","100","100","100","101","110","110","110","101","101","101","101","100","100","100","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","100","100","100","100","100","101","101","110","101","101","100","100","100","101","101","101","100","100","100","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","100","101","110","110","101","101","101","101","100","100","100","100","100","101","101","101","101","101","101","101","100","100","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","101","110","110","110","101","101","101","101","101","011","011","101","101","101","101","101","101","101","100","101","100","100","100","101","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","101","111","110","110","110","101","101","101","101","101","100","100","101","101","101","101","101","101","101","101","101","101","101","101","100","101","110","110","110","110","110","110","110","110","110","110","110","110","101","100","101","110","110","110","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","100","101","110","110","110","110","110","110","110","110","110","110","110","101","101","100","101","101","101","101","100","100","101","101","101","101","101","101","101","101","101","100","101","101","101","101","101","101","101","101","101","101","101","110","110","110","110","110","110","110","110","110","110","101","101","100","100","100","100","100","011","100","101","101","101","101","101","101","101","101","100","100","100","101","101","101","101","101","101","101","101","101","101","110","110","110","110","110","110","110","110","110","101","101","100","100","100","100","100","100","100","100","100","101","101","101","101","101","101","100","100","100","100","100","101","101","101","101","101","101","101","101","100","110","110","110","110","110","110","110","110","110","101","100","100","100","100","100","100","100","101","100","100","101","101","110","101","101","101","100","101","101","101","100","100","101","101","101","101","101","101","101","100","101","110","110","110","110","110","110","110","110","101","100","100","100","101","101","101","100","101","100","100","101","101","110","110","101","101","100","101","110","101","100","100","101","101","101","101","101","101","101","100","101","110","110","110","110","110","110","110","110","101","100","100","100","101","101","101","100","100","100","100","101","101","110","110","101","101","101","101","110","101","100","100","101","101","101","101","101","101","101","100","101","110","110","110","110","110","110","110","110","101","101","100","100","100","101","101","100","011","011","100","101","101","101","101","110","101","100","101","110","101","100","100","101","101","101","101","101","101","101","100","101","110","110","110","110","110","110","110","110","110","101","100","100","100","101","101","101","100","100","101","101","101","101","101","110","101","100","100","101","100","100","101","101","101","101","101","101","101","101","100","101","110","110","110","110","110","110","110","110","110","110","101","100","100","101","100","101","101","101","101","101","101","101","101","110","110","101","011","011","100","100","101","101","101","101","100","100","101","101","100","101","110","110","110","110","110","110","110","110","110","110","101","100","101","101","100","101","101","101","101","101","101","101","101","101","101","101","101","100","101","101","101","101","100","100","100","100","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","101","101","100","101","101","101","101","101","101","100","100","100","101","101","101","101","101","101","101","101","101","101","101","100","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","101","101","100","101","101","101","101","101","101","100","011","100","101","101","101","101","101","101","101","101","101","100","101","101","101","100","101","101","110","110","110","110","110","110","110","110","101","110","110","110","110","101","100","100","100","100","100","101","100","100","100","100","100","101","101","101","101","101","101","101","101","100","101","101","101","100","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","100","100","011","100","100","101","101","101","100","101","101","101","100","100","101","101","101","101","101","101","100","100","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","101","101","101","101","110","110","110","101","101","100","101","101","100","100","101","101","101","101","100","100","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","100","100","100","100","101","101","101","100","100","100","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","101","101","101","101","101","101","101","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110");
-----------------------------------------
--constant n9_B : number:=("000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","001","000","000","001","001","000","000","000","000","000","000","000","000","000","000","001","001","001","001","000","000","001","000","001","000","000","001","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","001","000","000","001","000","000","000","000","001","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","001","000","001","000","001","000","000","000","000","001","000","000","001","001","001","001","000","000","000","000","001","001","001","001","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","001","001","000","000","001","001","000","000","000","000","000","000","001","001","001","001","000","000","001","000","001","001","001","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","001","000","001","001","000","000","000","000","000","000","000","001","000","000","000","000","000","001","000","001","001","001","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","001","000","000","000","000","001","001","001","001","001","000","000","000","000","000","001","001","000","000","001","000","001","000","000","000","001","000","000","000","000","001","000","000","000","000","000","000","000","000","000","001","001","000","000","000","001","001","001","001","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","001","001","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","001","000","000","000","000","000","000","000","001","000","000","000","000","001","001","001","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","001","001","001","001","000","000","001","000","000","000","000","000","000","000","000","001","001","000","000","000","001","001","001","000","001","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","001","001","000","001","000","000","000","000","000","000","000","001","000","000","000","001","001","000","000","001","001","001","000","000","001","000","000","001","000","000","001","001","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","001","001","001","000","000","000","000","000","001","000","001","001","001","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","001","001","001","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","001","000","000","001","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","001","001","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","001","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","001","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","001","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","001","000","001","001","000","000","001","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","001","000","001","000","001","001","001","000","000","001","000","000","000","000","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","001","001","001","000","000","000","000","001","001","001","000","000","000","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","001","001","000","000","000","000","001","001","001","001","001","001","001","000","001","001","001","001","001","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","001","000","001","000","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","000","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","001","001","000","000","001","000","000","000","001","001","000","000","000","000","000","000","000","000","000","000","001","001","001","001","001","001","000","000","000","000","000","000","000","000","000","000","000","000","000","000");
--constant n9_G : number:=("100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","010","010","011","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","011","011","100","100","011","011","011","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","011","101","101","101","101","101","101","101","100","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","011","100","101","101","101","101","101","101","101","101","101","100","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","100","100","100","101","101","101","101","101","101","101","101","101","011","100","100","100","100","100","100","100","011","011","011","011","011","100","100","100","100","100","100","100","100","100","100","100","100","100","011","100","100","100","100","101","101","101","101","101","101","101","101","101","100","011","100","100","100","100","100","011","011","101","101","101","101","011","011","100","100","100","100","100","100","100","100","100","100","011","011","100","100","100","101","101","100","100","101","101","101","101","101","110","100","011","100","100","100","100","011","011","101","101","101","100","101","100","011","100","100","100","100","100","100","100","100","100","100","011","100","100","100","101","101","011","011","011","011","101","101","110","101","110","101","011","100","100","100","100","011","100","101","101","101","101","100","101","011","100","100","100","100","100","100","100","100","100","011","011","100","100","100","101","100","011","100","100","011","100","110","110","110","110","101","011","100","100","100","100","011","101","101","101","101","101","100","101","011","100","100","100","100","100","100","100","100","100","010","011","101","100","101","101","011","100","100","100","011","100","110","110","110","110","101","011","100","100","100","100","011","101","101","101","101","101","100","101","100","100","100","100","100","100","100","100","100","100","010","011","101","101","101","100","011","100","100","100","011","101","110","110","110","110","101","011","100","100","100","011","100","101","101","101","101","101","101","101","100","100","100","100","100","100","100","100","100","100","010","011","101","100","101","101","011","100","100","100","011","101","110","110","110","110","101","011","100","100","011","011","101","101","101","101","101","101","101","101","011","100","100","100","100","100","100","100","100","100","011","011","101","101","101","101","100","011","100","011","100","110","110","110","110","110","110","100","011","011","011","100","101","101","101","101","101","101","100","101","011","100","100","100","100","100","100","100","100","100","100","011","101","101","101","101","100","011","011","011","101","110","110","110","110","110","110","110","101","100","101","110","101","101","101","101","101","101","101","100","011","100","100","100","100","100","100","100","100","100","100","011","100","101","101","101","101","101","101","101","101","101","110","110","110","110","110","110","110","110","110","101","101","101","101","101","101","101","101","011","011","100","100","100","100","100","100","100","100","100","100","011","011","101","101","101","101","101","101","101","101","101","101","110","110","110","110","110","110","101","101","101","101","101","101","101","101","101","100","011","100","100","100","100","100","100","100","100","100","100","100","100","011","100","101","101","101","101","101","101","101","101","101","110","110","110","110","110","110","101","101","101","101","101","101","101","101","101","011","011","100","100","100","100","100","100","100","100","100","100","100","100","011","011","100","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","011","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","100","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","100","100","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","011","100","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","101","100","011","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","011","011","100","100","101","101","101","101","101","101","101","101","101","101","100","011","011","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","011","011","011","011","011","011","100","100","100","100","011","011","011","011","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100","100");
--constant n9_R : number:=("110","110","110","110","110","110","110","110","101","110","110","110","110","110","101","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","111","111","111","111","111","111","111","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","111","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","111","110","111","111","111","111","111","111","111","111","111","111","101","110","110","110","110","110","110","110","110","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","111","111","111","111","111","111","111","111","111","111","110","101","110","110","110","110","110","101","110","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","110","101","110","110","110","110","111","111","110","110","111","111","111","111","111","111","110","101","110","110","110","110","110","101","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","101","111","110","110","111","111","101","101","110","101","111","111","111","111","111","111","101","110","110","110","110","101","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","110","111","110","111","111","110","101","110","110","101","110","111","111","111","111","111","101","110","110","110","110","101","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","101","110","111","111","111","111","101","110","110","110","101","110","111","111","111","111","111","101","110","110","110","110","101","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","101","110","111","111","111","111","101","110","110","110","101","111","111","111","111","111","111","101","110","110","110","101","110","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","101","110","111","111","111","111","101","110","110","110","101","111","111","111","111","111","111","101","110","110","110","101","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","101","110","111","111","111","111","110","110","110","101","110","111","111","111","111","111","111","110","101","101","101","111","111","111","111","111","111","111","111","111","101","110","110","110","110","110","110","110","110","110","110","101","111","111","111","111","111","110","101","110","111","111","111","111","111","111","111","111","111","110","111","111","111","111","111","111","111","111","111","111","101","110","110","110","110","110","110","110","110","110","110","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","110","110","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","110","110","110","110","110","110","110","110","110","110","110","110","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","110","111","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","110","110","110","110","110","110","110","110","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110");
-------------------------------------------
	
constant ball_B : ball:=("111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "011", "011", "011", "011", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "011", "100", "100", "011", "101", "100", "100", "100", "100", "100", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "100", "100", "100", "100", "101", "010", "011", "010", "010", "010", "011", "010", "010", "100", "100", "100", "100", "100", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "011", "100", "100", "100", "011", "011", "010", "011", "010", "010", "010", "011", "010", "010", "010", "011", "101", "100", "100", "100", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "011", "100", "111", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "010", "101", "100", "100", "100", "100", "111", "111", "111", "111", "111", "111", "111", "011", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "011", "011", "010", "010", "010", "010", "100", "101", "100", "011", "100", "100", "111", "111", "111", "111", "111", "111", "100", "100", "100", "011", "010", "010", "011", "011", "011", "011", "011", "010", "011", "011", "011", "011", "011", "011", "010", "010", "010", "101", "100", "100", "100", "100", "111", "111", "111", "111", "111", "011", "100", "100", "011", "011", "011", "011", "011", "010", "011", "011", "011", "010", "011", "011", "011", "011", "010", "011", "010", "100", "100", "100", "100", "110", "100", "100", "100", "111", "111", "111", "111", "100", "011", "010", "011", "011", "011", "011", "010", "010", "011", "011", "011", "011", "011", "010", "011", "010", "011", "010", "100", "100", "101", "101", "101", "100", "101", "100", "100", "111", "111", "111", "100", "100", "100", "011", "011", "011", "010", "010", "010", "010", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "100", "101", "101", "101", "101", "100", "100", "100", "100", "100", "111", "111", "011", "100", "100", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "011", "100", "011", "011", "011", "010", "100", "100", "101", "101", "110", "101", "101", "100", "101", "100", "100", "111", "111", "011", "100", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "010", "010", "011", "010", "010", "010", "100", "100", "011", "011", "100", "101", "101", "100", "101", "100", "100", "111", "100", "100", "100", "011", "010", "011", "010", "010", "010", "010", "011", "010", "010", "010", "010", "010", "010", "010", "010", "010", "100", "100", "011", "010", "001", "101", "101", "100", "101", "100", "100", "100", "011", "100", "100", "011", "011", "010", "010", "011", "010", "010", "010", "010", "010", "010", "010", "010", "011", "011", "011", "010", "100", "100", "101", "101", "110", "101", "101", "100", "100", "101", "100", "011", "100", "100", "011", "011", "011", "011", "010", "010", "010", "011", "010", "010", "011", "010", "010", "011", "010", "011", "011", "010", "100", "100", "101", "101", "101", "101", "101", "100", "011", "101", "100", "011", "100", "100", "011", "011", "011", "011", "010", "010", "010", "010", "010", "010", "010", "010", "010", "010", "011", "011", "011", "010", "100", "100", "101", "101", "101", "101", "101", "101", "011", "101", "100", "011", "011", "100", "100", "011", "010", "010", "010", "010", "010", "011", "010", "010", "010", "010", "010", "010", "011", "011", "011", "010", "100", "100", "110", "110", "101", "101", "101", "101", "011", "110", "101", "100", "011", "100", "101", "011", "010", "011", "010", "010", "010", "010", "010", "010", "010", "011", "010", "010", "010", "010", "011", "010", "100", "011", "011", "010", "010", "101", "101", "100", "100", "101", "100", "100", "111", "100", "100", "011", "010", "011", "011", "011", "010", "010", "011", "010", "010", "011", "010", "010", "011", "010", "010", "010", "100", "100", "100", "100", "100", "101", "101", "100", "111", "110", "100", "111", "111", "011", "100", "011", "011", "010", "011", "011", "010", "010", "011", "010", "010", "010", "010", "010", "011", "011", "011", "010", "100", "100", "101", "101", "110", "101", "100", "100", "111", "101", "100", "111", "111", "100", "100", "100", "011", "011", "011", "010", "010", "011", "010", "010", "011", "011", "011", "011", "011", "011", "011", "010", "010", "100", "101", "101", "101", "110", "100", "100", "110", "101", "100", "111", "111", "111", "100", "100", "011", "011", "011", "010", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "010", "010", "010", "100", "101", "101", "100", "101", "100", "101", "110", "101", "111", "111", "111", "111", "011", "011", "100", "011", "011", "011", "011", "010", "011", "011", "010", "011", "010", "010", "011", "011", "011", "011", "010", "010", "100", "100", "100", "100", "111", "111", "101", "100", "111", "111", "111", "111", "111", "100", "100", "100", "011", "011", "011", "011", "011", "011", "010", "011", "011", "010", "010", "010", "011", "011", "010", "010", "011", "010", "111", "111", "111", "110", "101", "111", "111", "111", "111", "111", "111", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "010", "011", "011", "011", "010", "011", "010", "010", "101", "111", "111", "110", "101", "100", "111", "111", "111", "111", "111", "111", "111", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "010", "010", "011", "010", "010", "111", "111", "110", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "100", "100", "100", "100", "011", "011", "001", "010", "010", "010", "010", "011", "010", "010", "011", "011", "111", "111", "110", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "100", "100", "101", "101", "101", "010", "010", "010", "010", "010", "010", "010", "010", "110", "111", "110", "101", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "011", "011", "100", "101", "101", "101", "011", "011", "101", "110", "110", "101", "101", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "100", "100", "100", "100", "100", "100", "101", "101", "101", "100", "100", "100", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "011", "100", "100", "100", "011", "100", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111" 
);
------------------------------------------------------------------------------------------------------
constant ball_G : ball:=("111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "100", "011", "100", "100", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "100", "011", "100", "100", "100", "101", "100", "101", "100", "100", "100", "100", "100", "100", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "100", "100", "100", "100", "101", "111", "111", "111", "111", "110", "110", "011", "011", "101", "100", "100", "100", "100", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "100", "100", "100", "100", "011", "011", "111", "110", "101", "100", "101", "110", "101", "011", "011", "011", "100", "100", "100", "100", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "100", "100", "111", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "101", "100", "100", "100", "100", "111", "111", "111", "111", "111", "111", "111", "011", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "011", "011", "010", "010", "010", "101", "101", "101", "100", "100", "011", "111", "111", "111", "111", "111", "111", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "011", "010", "010", "101", "101", "101", "100", "100", "111", "111", "111", "111", "111", "011", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "011", "011", "101", "110", "110", "101", "110", "100", "100", "100", "111", "111", "111", "111", "100", "100", "011", "011", "011", "011", "011", "101", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "101", "101", "110", "110", "110", "101", "101", "100", "100", "111", "111", "111", "100", "100", "100", "011", "011", "011", "011", "100", "111", "101", "011", "011", "011", "011", "011", "011", "011", "011", "010", "011", "101", "110", "110", "110", "110", "110", "101", "100", "100", "100", "111", "111", "100", "100", "100", "011", "011", "011", "011", "101", "111", "111", "101", "011", "011", "011", "011", "011", "011", "011", "011", "100", "101", "111", "110", "110", "110", "110", "100", "101", "100", "100", "111", "111", "100", "100", "011", "011", "011", "011", "011", "101", "111", "111", "111", "111", "111", "111", "111", "100", "011", "011", "011", "101", "101", "100", "100", "100", "111", "110", "110", "101", "101", "100", "111", "011", "100", "100", "011", "011", "011", "011", "100", "111", "111", "111", "111", "111", "111", "111", "110", "011", "011", "011", "011", "101", "100", "011", "011", "010", "111", "110", "101", "101", "101", "100", "100", "100", "100", "100", "011", "011", "011", "101", "111", "111", "111", "111", "111", "111", "111", "111", "101", "011", "011", "010", "011", "101", "101", "111", "111", "110", "111", "111", "110", "100", "101", "100", "100", "011", "100", "100", "011", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "011", "011", "010", "011", "101", "110", "111", "111", "111", "111", "111", "101", "100", "101", "100", "100", "011", "100", "101", "011", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "011", "011", "011", "011", "101", "110", "111", "111", "111", "111", "110", "101", "100", "101", "100", "100", "100", "100", "100", "011", "011", "011", "101", "111", "111", "111", "111", "111", "111", "111", "111", "100", "011", "011", "011", "010", "101", "101", "111", "111", "111", "111", "110", "110", "100", "110", "100", "011", "011", "100", "100", "011", "011", "011", "011", "101", "111", "111", "111", "111", "111", "111", "111", "101", "011", "011", "011", "010", "101", "100", "011", "010", "010", "111", "110", "101", "101", "101", "100", "100", "111", "100", "100", "011", "011", "011", "011", "011", "110", "111", "111", "111", "111", "111", "111", "111", "100", "011", "011", "011", "101", "101", "100", "100", "101", "111", "111", "101", "111", "110", "100", "111", "111", "100", "100", "011", "011", "011", "011", "011", "101", "111", "111", "101", "100", "100", "100", "100", "011", "011", "011", "011", "100", "101", "110", "111", "111", "110", "110", "101", "111", "101", "100", "111", "111", "100", "100", "100", "011", "011", "011", "011", "100", "111", "101", "011", "011", "011", "011", "011", "011", "011", "011", "010", "011", "101", "110", "111", "110", "111", "110", "101", "110", "101", "100", "111", "111", "111", "100", "100", "011", "011", "011", "011", "011", "101", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "101", "110", "110", "110", "110", "101", "110", "110", "101", "111", "111", "111", "111", "011", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "101", "101", "101", "101", "111", "110", "101", "100", "111", "111", "111", "111", "111", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "010", "011", "010", "010", "011", "110", "111", "111", "110", "101", "111", "111", "111", "111", "111", "111", "011", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "011", "100", "111", "111", "110", "101", "100", "111", "111", "111", "111", "111", "111", "111", "011", "100", "100", "100", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "011", "111", "111", "110", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "100", "100", "101", "100", "011", "011", "110", "101", "100", "011", "100", "110", "101", "011", "011", "011", "111", "111", "110", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "100", "100", "100", "100", "101", "111", "111", "110", "110", "110", "110", "100", "011", "110", "111", "110", "101", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "100", "100", "100", "101", "101", "110", "110", "111", "110", "110", "110", "110", "110", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "100", "100", "100", "100", "101", "100", "101", "101", "101", "101", "100", "100", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "100", "100", "100", "100", "100", "100", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111" 
);
---------------------------------------------------------------------------------------------------------
constant ball_R : ball:=("111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "110", "110", "101", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "101", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "110", "101", "101", "100", "100", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "101", "100", "100", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "101", "101", "011", "110", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "101", "100", "101", "110", "111", "110", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "101", "100", "110", "110", "111", "111", "110", "110", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "101", "110", "110", "111", "111", "111", "111", "111", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "100", "110", "101", "100", "100", "101", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "101", "100", "101", "101", "100", "011", "010", "111", "111", "110", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "101", "100", "110", "110", "111", "111", "111", "111", "111", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "101", "100", "101", "110", "111", "111", "111", "111", "111", "110", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "101", "100", "101", "110", "111", "111", "111", "111", "111", "110", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "101", "100", "110", "101", "111", "111", "111", "111", "111", "110", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "101", "100", "101", "100", "011", "011", "010", "111", "111", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "100", "101", "101", "100", "101", "101", "111", "111", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "101", "100", "101", "110", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "101", "100", "100", "110", "111", "111", "111", "111", "110", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "101", "101", "100", "101", "110", "111", "111", "110", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "101", "101", "100", "011", "101", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "101", "101", "100", "100", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "101", "101", "101", "100", "100", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "110", "111", "110", "110", "110", "101", "101", "101", "100", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "110", "110", "110", "110", "101", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111" 
);

constant star_B : ball:=("111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "001", "000", "000", "000", "001", "001", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "001", "001", "000", "001", "010", "010", "001", "001", "001", "001", "001", "000", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "000", "001", "001", "110", "010", "010", "001", "001", "010", "010", "001", "010", "001", "001", "001", "000", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "001", "001", "001", "001", "010", "100", "110", "010", "010", "011", "010", "010", "010", "010", "001", "010", "010", "001", "001", "001", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "001", "001", "001", "010", "010", "110", "101", "100", "100", "011", "011", "011", "011", "011", "010", "010", "010", "010", "001", "010", "001", "001", "111", "111", "111", "111", "111", "111", "111", "111", "111", "001", "001", "001", "110", "110", "011", "110", "100", "100", "100", "101", "101", "100", "100", "100", "100", "011", "011", "010", "010", "010", "001", "001", "001", "111", "111", "111", "111", "111", "111", "110", "010", "001", "001", "001", "111", "111", "100", "101", "101", "100", "100", "011", "100", "101", "101", "101", "100", "100", "100", "011", "011", "010", "010", "001", "001", "011", "111", "111", "111", "111", "111", "111", "001", "001", "010", "010", "011", "010", "100", "101", "110", "100", "100", "011", "011", "100", "110", "101", "101", "101", "101", "100", "011", "011", "110", "110", "111", "001", "111", "111", "111", "111", "111", "000", "001", "010", "010", "010", "100", "100", "101", "100", "101", "101", "100", "100", "011", "011", "101", "111", "111", "110", "110", "101", "101", "100", "100", "100", "011", "101", "000", "111", "111", "111", "111", "001", "001", "010", "011", "011", "100", "100", "110", "101", "110", "110", "101", "101", "100", "011", "011", "100", "011", "011", "100", "011", "011", "011", "011", "011", "101", "001", "001", "111", "111", "111", "001", "000", "010", "010", "011", "011", "100", "101", "110", "101", "110", "110", "101", "101", "100", "100", "100", "100", "011", "011", "100", "011", "011", "011", "011", "100", "100", "010", "001", "001", "111", "111", "001", "010", "001", "010", "011", "100", "101", "101", "110", "101", "110", "110", "101", "101", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "110", "011", "010", "010", "000", "111", "111", "001", "001", "010", "011", "100", "100", "110", "101", "101", "101", "110", "110", "110", "110", "101", "100", "100", "100", "011", "100", "011", "011", "011", "011", "100", "100", "100", "011", "001", "001", "111", "010", "001", "001", "010", "011", "110", "100", "100", "101", "110", "110", "110", "100", "101", "011", "010", "010", "101", "100", "100", "100", "011", "011", "011", "011", "110", "101", "101", "011", "010", "001", "011", "001", "001", "001", "110", "101", "101", "101", "110", "110", "110", "110", "110", "100", "100", "011", "011", "011", "101", "100", "011", "100", "011", "011", "011", "100", "101", "100", "101", "101", "011", "001", "001", "000", "111", "101", "100", "110", "101", "101", "110", "110", "110", "110", "110", "101", "101", "101", "101", "100", "100", "100", "011", "011", "011", "011", "100", "111", "101", "100", "101", "101", "100", "001", "001", "001", "110", "101", "101", "101", "101", "101", "101", "110", "101", "101", "110", "101", "101", "101", "101", "100", "100", "100", "100", "011", "011", "011", "011", "111", "101", "100", "101", "110", "100", "010", "000", "000", "001", "110", "100", "100", "100", "100", "100", "101", "100", "101", "101", "101", "100", "100", "100", "100", "100", "011", "011", "100", "100", "011", "011", "101", "100", "101", "110", "111", "100", "010", "000", "010", "001", "001", "010", "100", "101", "100", "011", "100", "100", "101", "101", "101", "111", "100", "010", "010", "100", "100", "011", "011", "011", "011", "011", "011", "111", "100", "110", "110", "100", "010", "010", "111", "001", "001", "010", "011", "011", "100", "101", "100", "011", "100", "100", "101", "101", "101", "100", "100", "100", "100", "011", "011", "011", "011", "011", "011", "100", "110", "110", "110", "101", "001", "111", "111", "001", "001", "001", "010", "011", "100", "101", "110", "101", "100", "100", "100", "100", "100", "100", "011", "011", "100", "100", "011", "011", "011", "011", "011", "011", "110", "111", "110", "100", "001", "111", "111", "001", "001", "001", "010", "011", "011", "100", "101", "111", "100", "100", "100", "100", "100", "100", "100", "011", "100", "011", "011", "011", "011", "011", "011", "011", "100", "111", "110", "011", "001", "111", "111", "111", "001", "001", "010", "011", "011", "011", "101", "110", "101", "100", "100", "100", "011", "100", "011", "011", "011", "011", "011", "100", "011", "011", "100", "011", "011", "110", "101", "010", "111", "111", "111", "111", "001", "001", "001", "010", "011", "011", "100", "101", "101", "100", "100", "100", "011", "011", "011", "100", "110", "110", "101", "101", "100", "100", "011", "011", "011", "100", "100", "001", "111", "111", "111", "111", "111", "001", "001", "010", "010", "011", "100", "100", "100", "100", "100", "011", "011", "011", "100", "110", "110", "101", "101", "101", "100", "101", "111", "111", "110", "101", "010", "111", "111", "111", "111", "111", "111", "001", "000", "010", "010", "010", "011", "100", "101", "100", "011", "011", "010", "100", "111", "110", "101", "101", "101", "101", "110", "111", "111", "111", "101", "011", "001", "111", "111", "111", "111", "111", "111", "111", "000", "001", "001", "011", "010", "100", "111", "100", "100", "011", "100", "110", "101", "101", "101", "110", "101", "110", "111", "111", "111", "101", "100", "010", "111", "111", "111", "111", "111", "111", "111", "111", "111", "000", "001", "001", "001", "011", "110", "100", "011", "100", "111", "111", "110", "110", "110", "111", "110", "111", "111", "111", "101", "011", "001", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "000", "001", "001", "010", "010", "011", "100", "110", "110", "110", "111", "111", "111", "111", "111", "111", "110", "101", "011", "001", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "001", "010", "001", "111", "010", "011", "100", "100", "110", "101", "110", "110", "101", "100", "011", "001", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "001", "000", "010", "001", "010", "010", "011", "010", "011", "010", "010", "001", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "010", "001", "001", "001", "001", "001", "001", "010", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111"  );
------------------------------------------------------------------------------------------------------
constant star_G : ball:=("111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "111", "110", "111", "110", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "110", "111", "111", "110", "110", "111", "110", "110", "111", "111", "110", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "110", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "110", "110", "111", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "111", "110", "110", "110", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "110", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "110", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "110", "100", "011", "011", "111", "111", "111", "111", "110", "111", "110", "110", "111", "111", "111", "111", "111", "110", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "100", "100", "100", "100", "111", "111", "111", "111", "110", "110", "110", "110", "111", "111", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "110", "110", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "110", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "101", "010", "010", "110", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "110", "111", "110", "110", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "111", "111", "111", "111", "110", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "110", "111", "111", "111", "111", "110", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "110", "110", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "110", "110", "110", "110", "110", "110", "110", "110", "111", "110", "111", "111", "111", "111", "111", "111", "110", "111", "110", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111"  );
---------------------------------------------------------------------------------------------------------
constant star_R : ball:=("111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "110", "100", "011", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "100", "100", "101", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "101", "011", "011", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111"  );

----------------------------------------------------------------------------------------------------------
constant turtle_B : ball:=("111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "100", "011", "100", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "100", "111", "111", "111", "110", "100", "011", "010", "011", "101", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "010", "000", "011", "111", "111", "111", "111", "100", "001", "001", "010", "100", "110", "100", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "001", "010", "011", "100", "110", "111", "111", "110", "100", "000", "000", "000", "000", "100", "101", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "010", "011", "011", "010", "010", "101", "111", "111", "110", "110", "011", "000", "000", "010", "101", "101", "011", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "011", "011", "101", "101", "011", "010", "101", "111", "111", "110", "101", "100", "010", "100", "101", "101", "100", "011", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "010", "011", "011", "100", "100", "011", "001", "011", "111", "111", "110", "100", "101", "101", "101", "100", "011", "011", "011", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "010", "001", "010", "010", "010", "010", "010", "001", "001", "101", "111", "110", "100", "101", "100", "011", "011", "011", "011", "100", "100", "100", "110", "111", "111", "111", "111", "111", "111", "111", "111", "100", "000", "010", "011", "010", "010", "010", "001", "001", "010", "100", "111", "110", "101", "101", "101", "011", "010", "100", "101", "100", "100", "011", "110", "111", "111", "111", "111", "111", "111", "111", "111", "011", "001", "010", "010", "010", "001", "001", "000", "001", "010", "010", "111", "111", "101", "101", "110", "100", "000", "000", "011", "100", "100", "100", "101", "111", "111", "111", "111", "111", "111", "111", "110", "010", "001", "001", "001", "001", "001", "001", "010", "001", "000", "000", "101", "111", "101", "100", "101", "101", "001", "000", "000", "011", "100", "100", "100", "111", "111", "111", "111", "111", "111", "111", "101", "001", "001", "010", "010", "010", "010", "010", "010", "010", "001", "001", "011", "111", "110", "100", "100", "110", "010", "000", "001", "010", "101", "100", "100", "110", "111", "111", "111", "111", "111", "111", "101", "001", "001", "001", "010", "010", "010", "010", "010", "010", "010", "010", "000", "101", "111", "101", "100", "101", "100", "000", "000", "011", "100", "100", "100", "101", "111", "111", "111", "111", "111", "111", "110", "001", "010", "001", "010", "010", "010", "010", "010", "010", "010", "001", "000", "011", "111", "110", "100", "101", "101", "000", "001", "011", "100", "100", "100", "110", "111", "111", "111", "111", "110", "111", "111", "010", "010", "001", "001", "001", "010", "010", "010", "001", "001", "001", "001", "010", "110", "110", "101", "101", "101", "011", "011", "011", "011", "100", "011", "110", "111", "111", "111", "111", "111", "111", "111", "011", "000", "001", "010", "001", "001", "001", "001", "001", "001", "010", "010", "001", "100", "110", "101", "101", "110", "101", "011", "011", "011", "100", "100", "111", "111", "111", "111", "111", "111", "111", "111", "110", "001", "000", "001", "010", "010", "010", "010", "010", "001", "001", "001", "000", "011", "110", "101", "101", "101", "101", "011", "011", "100", "100", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "000", "001", "001", "001", "010", "010", "010", "001", "001", "001", "000", "010", "110", "101", "101", "101", "101", "011", "100", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "011", "000", "001", "001", "001", "001", "001", "001", "001", "001", "000", "001", "101", "101", "101", "101", "101", "100", "100", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "001", "001", "001", "001", "001", "001", "001", "001", "001", "001", "010", "100", "101", "100", "101", "101", "100", "100", "100", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "010", "001", "001", "010", "010", "001", "010", "001", "001", "001", "100", "101", "101", "101", "101", "100", "100", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "100", "010", "000", "000", "001", "001", "001", "001", "001", "100", "101", "100", "100", "100", "100", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "011", "001", "001", "000", "001", "001", "010", "100", "101", "101", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "100", "010", "010", "011", "100", "100", "100", "100", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "011", "011", "011", "011", "011", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "101", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111"  );
----------------------------------------------------------------------------------------------------------
constant turtle_G : ball:=("111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "101", "101", "101", "110", "110", "101", "101", "101", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "101", "101", "101", "110", "111", "111", "111", "111", "111", "110", "101", "101", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "101", "110", "111", "111", "111", "111", "110", "101", "101", "101", "101", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "100", "101", "101", "110", "101", "110", "111", "111", "111", "110", "101", "101", "101", "111", "110", "110", "101", "101", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "110", "111", "110", "110", "110", "110", "111", "111", "111", "110", "100", "100", "100", "110", "111", "111", "110", "110", "101", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "111", "111", "111", "110", "110", "110", "111", "111", "111", "111", "100", "001", "001", "001", "101", "111", "111", "110", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "110", "110", "111", "110", "111", "110", "110", "111", "111", "111", "110", "101", "001", "000", "000", "000", "110", "111", "110", "110", "110", "101", "101", "111", "111", "111", "111", "111", "110", "101", "101", "101", "110", "110", "110", "111", "111", "111", "101", "110", "111", "111", "110", "110", "011", "000", "000", "010", "111", "111", "110", "110", "110", "101", "101", "110", "111", "111", "111", "111", "101", "101", "101", "110", "110", "111", "111", "111", "111", "111", "101", "110", "111", "111", "110", "101", "101", "011", "100", "110", "111", "110", "101", "110", "110", "101", "101", "101", "111", "111", "111", "111", "101", "101", "101", "110", "111", "111", "111", "111", "111", "111", "101", "011", "111", "111", "110", "100", "110", "110", "110", "110", "101", "101", "101", "111", "111", "110", "101", "101", "110", "111", "111", "110", "101", "110", "101", "101", "111", "111", "111", "110", "111", "111", "100", "010", "101", "111", "110", "101", "101", "101", "101", "101", "101", "101", "110", "110", "110", "110", "110", "101", "110", "111", "111", "101", "101", "110", "101", "100", "111", "111", "111", "111", "111", "101", "100", "110", "101", "111", "110", "101", "101", "101", "011", "011", "101", "110", "110", "110", "110", "110", "110", "101", "101", "111", "111", "101", "101", "110", "110", "101", "101", "110", "101", "101", "100", "010", "011", "110", "100", "110", "111", "101", "101", "110", "100", "000", "001", "100", "110", "110", "110", "111", "110", "101", "101", "111", "111", "101", "101", "110", "111", "101", "011", "100", "011", "100", "100", "100", "100", "011", "001", "100", "111", "110", "101", "101", "101", "001", "000", "001", "100", "110", "110", "110", "110", "101", "101", "110", "111", "101", "101", "110", "110", "101", "011", "101", "110", "111", "111", "110", "110", "101", "011", "011", "111", "110", "101", "100", "110", "010", "000", "000", "011", "110", "110", "110", "111", "110", "101", "110", "111", "101", "101", "110", "110", "101", "100", "110", "110", "110", "110", "110", "110", "101", "101", "010", "101", "111", "101", "101", "110", "100", "000", "000", "100", "110", "110", "110", "110", "110", "101", "110", "111", "101", "101", "110", "110", "110", "100", "101", "110", "110", "110", "110", "110", "101", "101", "011", "011", "111", "101", "101", "110", "101", "000", "001", "101", "101", "110", "110", "110", "110", "101", "110", "111", "101", "101", "101", "110", "110", "100", "101", "101", "101", "101", "101", "101", "101", "101", "100", "010", "110", "110", "101", "101", "110", "100", "101", "101", "101", "101", "110", "111", "110", "101", "111", "111", "101", "101", "101", "110", "101", "100", "100", "101", "101", "101", "101", "101", "101", "100", "100", "010", "100", "110", "101", "101", "101", "110", "101", "101", "101", "110", "110", "111", "110", "101", "111", "111", "110", "101", "101", "101", "100", "011", "011", "101", "101", "101", "101", "101", "101", "100", "100", "010", "011", "110", "101", "101", "101", "110", "101", "101", "110", "110", "111", "111", "101", "101", "111", "111", "110", "101", "101", "110", "101", "011", "010", "011", "011", "100", "101", "100", "100", "100", "100", "011", "010", "110", "101", "100", "101", "101", "101", "110", "110", "111", "111", "110", "101", "110", "111", "111", "111", "101", "101", "110", "110", "100", "011", "011", "011", "010", "011", "011", "100", "100", "011", "010", "010", "101", "101", "101", "101", "101", "101", "110", "111", "111", "111", "110", "110", "111", "111", "111", "111", "110", "101", "101", "110", "110", "101", "100", "100", "100", "011", "010", "010", "010", "001", "011", "010", "100", "101", "101", "101", "110", "110", "110", "110", "111", "111", "101", "110", "111", "111", "111", "111", "111", "101", "101", "110", "110", "110", "101", "100", "100", "101", "100", "100", "011", "011", "011", "010", "100", "101", "101", "101", "101", "110", "110", "111", "111", "110", "101", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "110", "110", "110", "101", "101", "101", "101", "101", "100", "010", "010", "100", "101", "101", "101", "110", "110", "111", "111", "110", "101", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "101", "101", "101", "110", "111", "110", "101", "101", "100", "100", "010", "010", "100", "101", "101", "101", "111", "111", "111", "110", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "101", "101", "101", "110", "111", "111", "101", "100", "100", "011", "011", "100", "100", "101", "110", "111", "111", "110", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "101", "110", "111", "101", "011", "100", "100", "100", "100", "101", "111", "111", "110", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "101", "101", "101", "110", "110", "101", "101", "101", "101", "101", "110", "110", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "101", "101", "101", "110", "101", "101", "101", "101", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "110", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111"  );
----------------------------------------------------------------------------------------------------------
constant turtle_R : ball:=("111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "100", "100", "100", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "011", "010", "010", "100", "101", "101", "100", "100", "010", "100", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "100", "011", "010", "010", "011", "100", "111", "111", "111", "111", "110", "100", "011", "010", "011", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "011", "010", "010", "011", "011", "101", "111", "111", "111", "111", "110", "101", "110", "100", "011", "011", "011", "011", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "011", "010", "011", "100", "100", "100", "101", "111", "111", "111", "110", "101", "101", "101", "111", "110", "100", "011", "010", "011", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "011", "011", "101", "111", "100", "011", "011", "100", "111", "111", "111", "110", "101", "100", "100", "110", "111", "111", "101", "011", "011", "011", "101", "111", "111", "111", "111", "111", "111", "111", "110", "011", "010", "100", "111", "111", "100", "001", "001", "100", "111", "111", "111", "111", "100", "001", "001", "001", "101", "111", "111", "101", "011", "011", "011", "110", "111", "111", "111", "111", "111", "111", "011", "010", "011", "100", "101", "011", "001", "001", "001", "011", "111", "111", "111", "111", "101", "001", "000", "000", "000", "110", "111", "110", "100", "011", "010", "011", "111", "111", "111", "111", "111", "101", "010", "011", "101", "100", "010", "001", "010", "011", "001", "010", "111", "111", "111", "110", "110", "100", "000", "000", "011", "111", "111", "110", "111", "101", "011", "010", "101", "111", "111", "111", "111", "011", "010", "100", "100", "011", "010", "001", "011", "011", "010", "001", "101", "111", "111", "110", "101", "101", "011", "101", "111", "111", "110", "110", "111", "110", "011", "010", "100", "111", "111", "111", "101", "010", "011", "100", "011", "001", "010", "010", "011", "010", "010", "001", "011", "111", "111", "110", "101", "110", "111", "111", "111", "110", "101", "110", "111", "111", "100", "011", "010", "110", "111", "111", "100", "010", "100", "100", "001", "001", "010", "001", "010", "001", "010", "001", "001", "110", "111", "110", "101", "110", "110", "101", "110", "101", "101", "110", "111", "111", "110", "100", "010", "100", "111", "111", "011", "011", "100", "011", "001", "010", "010", "010", "010", "001", "001", "001", "001", "011", "111", "110", "101", "101", "110", "100", "011", "101", "111", "111", "111", "111", "111", "100", "011", "011", "111", "110", "010", "011", "100", "011", "001", "010", "001", "010", "001", "001", "001", "001", "001", "010", "111", "111", "101", "101", "110", "100", "000", "010", "100", "111", "111", "111", "111", "101", "011", "011", "110", "110", "010", "100", "011", "010", "001", "001", "000", "001", "001", "001", "010", "010", "000", "000", "101", "111", "110", "101", "110", "101", "001", "000", "001", "101", "111", "111", "111", "110", "011", "011", "110", "110", "010", "011", "011", "001", "001", "001", "010", "001", "001", "010", "010", "001", "001", "001", "011", "111", "110", "101", "101", "110", "010", "000", "000", "100", "111", "111", "111", "110", "100", "011", "110", "101", "010", "100", "011", "001", "001", "001", "010", "001", "001", "001", "001", "001", "001", "001", "000", "101", "111", "101", "101", "110", "100", "000", "001", "100", "110", "111", "111", "110", "101", "011", "101", "110", "010", "011", "011", "001", "001", "001", "001", "001", "001", "001", "001", "001", "001", "001", "000", "011", "111", "110", "101", "110", "101", "001", "010", "101", "110", "111", "111", "110", "101", "011", "101", "110", "010", "011", "100", "010", "001", "001", "010", "001", "001", "010", "010", "001", "001", "001", "001", "010", "110", "110", "101", "101", "110", "100", "101", "101", "110", "111", "110", "110", "101", "011", "110", "111", "011", "011", "100", "010", "000", "001", "010", "001", "001", "001", "001", "001", "001", "010", "001", "001", "100", "110", "101", "101", "110", "110", "110", "101", "110", "110", "111", "111", "100", "100", "111", "111", "100", "011", "100", "011", "001", "001", "001", "010", "010", "001", "010", "001", "001", "001", "001", "001", "011", "110", "101", "101", "101", "110", "110", "110", "110", "111", "111", "110", "011", "100", "111", "111", "101", "010", "100", "011", "010", "001", "001", "001", "001", "010", "010", "010", "001", "001", "001", "001", "010", "110", "101", "101", "101", "110", "110", "110", "111", "111", "111", "101", "011", "101", "111", "111", "111", "011", "011", "100", "100", "010", "001", "001", "001", "001", "001", "001", "010", "001", "001", "001", "001", "101", "101", "101", "101", "110", "110", "111", "111", "111", "111", "100", "100", "111", "111", "111", "111", "101", "010", "011", "100", "100", "010", "001", "001", "001", "001", "001", "001", "001", "001", "010", "010", "100", "101", "100", "101", "110", "111", "111", "111", "111", "110", "100", "100", "111", "111", "111", "111", "111", "011", "010", "100", "100", "100", "010", "001", "001", "001", "001", "001", "001", "001", "001", "001", "100", "101", "101", "101", "110", "110", "110", "111", "111", "100", "100", "111", "111", "111", "111", "111", "111", "110", "011", "011", "100", "100", "100", "011", "010", "001", "000", "001", "001", "001", "001", "001", "100", "101", "101", "101", "110", "111", "111", "111", "101", "100", "110", "111", "111", "111", "111", "111", "111", "111", "101", "011", "011", "100", "101", "101", "100", "011", "010", "001", "001", "001", "001", "010", "100", "101", "101", "101", "111", "111", "111", "101", "100", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "011", "011", "100", "100", "101", "110", "110", "100", "010", "010", "010", "100", "101", "100", "101", "110", "111", "111", "100", "100", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "011", "010", "011", "100", "101", "110", "111", "101", "011", "011", "100", "101", "101", "101", "110", "101", "100", "100", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "100", "011", "010", "011", "011", "100", "101", "101", "101", "101", "101", "101", "101", "100", "100", "100", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "100", "011", "010", "010", "011", "011", "100", "100", "100", "100", "100", "100", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "100", "100", "100", "100", "101", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111"  );
----------------------------------------------------------------------
constant goomba_R : ball:=("111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "101", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "101", "101", "101", "110", "101", "101", "101", "101", "101", "101", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "101", "110", "101", "110", "110", "101", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "101", "101", "110", "101", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "111", "111", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "111", "111", "110", "110", "110", "110", "111", "101", "101", "101", "111", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "111", "111", "111", "111", "111", "111", "100", "101", "110", "101", "110", "110", "110", "110", "110", "101", "101", "101", "101", "101", "100", "111", "111", "111", "101", "100", "100", "011", "110", "101", "101", "101", "101", "111", "111", "111", "111", "101", "101", "101", "101", "110", "110", "110", "110", "110", "101", "101", "110", "101", "101", "101", "101", "011", "111", "110", "101", "100", "100", "100", "110", "101", "101", "101", "101", "111", "111", "111", "110", "101", "101", "101", "101", "110", "110", "110", "101", "110", "110", "101", "101", "111", "111", "110", "101", "100", "111", "110", "101", "100", "100", "100", "011", "101", "110", "101", "101", "100", "111", "111", "100", "101", "101", "010", "101", "110", "110", "101", "110", "101", "101", "110", "101", "100", "011", "110", "101", "100", "111", "111", "101", "101", "100", "011", "100", "100", "110", "101", "101", "101", "111", "111", "101", "101", "110", "010", "101", "101", "110", "101", "111", "111", "111", "110", "101", "101", "011", "110", "101", "100", "110", "111", "101", "101", "100", "100", "011", "011", "110", "110", "101", "101", "110", "111", "101", "101", "110", "101", "011", "100", "101", "111", "111", "111", "110", "110", "110", "101", "100", "110", "101", "100", "011", "100", "101", "100", "100", "100", "011", "110", "110", "110", "101", "101", "101", "101", "101", "101", "101", "110", "101", "101", "011", "110", "100", "011", "010", "111", "110", "101", "100", "110", "101", "100", "011", "100", "101", "101", "100", "101", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "101", "101", "110", "101", "101", "011", "110", "101", "101", "110", "110", "101", "101", "110", "101", "100", "011", "100", "100", "101", "100", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "101", "110", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "011", "110", "101", "100", "011", "011", "100", "101", "101", "011", "011", "110", "110", "111", "110", "101", "101", "101", "101", "101", "110", "101", "101", "101", "110", "101", "110", "111", "111", "101", "101", "100", "100", "110", "101", "100", "011", "100", "100", "101", "101", "011", "011", "011", "110", "110", "110", "110", "101", "101", "101", "101", "101", "101", "101", "101", "101", "010", "110", "110", "010", "111", "111", "100", "100", "110", "110", "100", "011", "100", "101", "101", "100", "011", "100", "101", "100", "111", "111", "110", "101", "101", "101", "101", "101", "101", "101", "101", "011", "100", "111", "111", "111", "111", "111", "100", "100", "101", "110", "101", "011", "100", "101", "101", "100", "100", "101", "101", "100", "111", "110", "110", "101", "111", "101", "101", "110", "101", "100", "010", "011", "110", "110", "110", "110", "110", "110", "100", "100", "100", "101", "101", "100", "111", "111", "111", "111", "101", "101", "101", "101", "111", "110", "101", "101", "111", "101", "101", "101", "110", "010", "011", "100", "101", "101", "110", "110", "101", "101", "101", "101", "111", "101", "101", "100", "111", "111", "111", "111", "110", "101", "101", "100", "111", "110", "101", "110", "111", "101", "101", "101", "101", "001", "100", "100", "101", "100", "100", "100", "101", "101", "100", "110", "110", "100", "101", "011", "111", "110", "111", "111", "110", "110", "100", "111", "111", "110", "101", "111", "111", "110", "101", "101", "011", "010", "110", "110", "100", "100", "101", "100", "101", "101", "100", "100", "100", "100", "101", "011", "111", "111", "111", "110", "110", "111", "111", "111", "111", "110", "101", "111", "111", "111", "101", "101", "101", "010", "110", "110", "110", "111", "100", "100", "100", "100", "100", "100", "100", "101", "100", "011", "111", "110", "110", "110", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "111", "101", "101", "110", "101", "110", "110", "110", "110", "111", "100", "100", "100", "100", "100", "100", "100", "111", "111", "110", "110", "111", "110", "111", "111", "111", "110", "101", "111", "111", "111", "111", "111", "100", "101", "101", "110", "110", "110", "110", "110", "110", "111", "111", "100", "100", "100", "100", "110", "110", "110", "110", "111", "111", "111", "111", "111", "110", "101", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "101", "110", "110", "110", "111", "110", "111", "111", "111", "110", "110", "110", "110", "111", "111", "111", "111", "111", "110", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "101", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "110", "110", "110", "110", "111", "111", "111", "111", "111", "110", "110", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "101", "101", "101", "101", "101", "110", "110", "110", "110", "101", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "101", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111" );  
  
constant goomba_G : ball:=("111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "011", "011", "011", "011", "011", "011", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "011", "011", "011", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "100", "011", "011", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "011", "011", "100", "100", "100", "100", "101", "100", "101", "101", "101", "101", "100", "101", "100", "100", "100", "100", "011", "011", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "011", "011", "111", "111", "101", "100", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "100", "100", "100", "100", "011", "011", "111", "111", "111", "111", "111", "111", "111", "011", "011", "011", "100", "111", "111", "101", "101", "101", "101", "101", "100", "011", "011", "101", "101", "101", "101", "101", "101", "100", "100", "100", "100", "011", "011", "111", "111", "111", "111", "111", "111", "011", "011", "100", "100", "100", "100", "101", "101", "101", "100", "100", "011", "100", "011", "011", "110", "101", "101", "011", "010", "011", "010", "100", "100", "011", "011", "011", "111", "111", "111", "111", "011", "011", "100", "100", "100", "101", "101", "101", "101", "100", "100", "100", "100", "100", "011", "011", "010", "110", "101", "011", "011", "011", "011", "101", "100", "100", "011", "011", "111", "111", "111", "110", "011", "011", "100", "100", "101", "101", "101", "011", "100", "100", "011", "011", "110", "110", "100", "011", "011", "110", "101", "100", "011", "011", "011", "011", "100", "100", "011", "011", "011", "111", "111", "011", "011", "011", "010", "101", "101", "100", "100", "011", "100", "011", "100", "011", "011", "011", "100", "011", "011", "110", "110", "011", "011", "011", "010", "011", "011", "100", "100", "100", "011", "111", "111", "011", "011", "100", "001", "101", "100", "100", "100", "111", "111", "111", "110", "101", "011", "011", "100", "011", "011", "101", "110", "011", "011", "011", "011", "010", "010", "101", "101", "100", "011", "101", "110", "011", "100", "100", "100", "010", "011", "100", "110", "111", "110", "110", "110", "101", "100", "011", "100", "100", "011", "010", "011", "100", "011", "011", "011", "011", "101", "101", "101", "100", "011", "011", "011", "011", "100", "100", "100", "011", "011", "001", "111", "100", "011", "010", "110", "100", "011", "011", "100", "011", "011", "010", "011", "100", "100", "011", "100", "101", "101", "101", "101", "100", "100", "011", "011", "011", "100", "100", "011", "011", "011", "100", "010", "100", "100", "100", "100", "011", "011", "011", "100", "100", "011", "010", "011", "011", "100", "100", "101", "110", "101", "101", "101", "101", "011", "011", "011", "011", "011", "100", "011", "011", "011", "100", "011", "011", "011", "011", "011", "011", "100", "011", "100", "100", "011", "011", "011", "011", "100", "100", "011", "010", "101", "101", "110", "101", "100", "011", "011", "011", "011", "100", "011", "100", "011", "011", "011", "101", "111", "111", "100", "011", "011", "011", "100", "100", "011", "011", "011", "011", "100", "100", "011", "010", "010", "101", "110", "101", "100", "011", "011", "011", "100", "100", "011", "011", "011", "100", "010", "110", "110", "010", "111", "110", "011", "011", "100", "100", "011", "010", "011", "100", "100", "100", "011", "011", "011", "011", "110", "110", "100", "011", "011", "011", "100", "100", "011", "011", "100", "001", "100", "110", "111", "111", "110", "110", "011", "011", "100", "100", "011", "011", "011", "100", "101", "100", "011", "011", "011", "011", "110", "110", "100", "011", "110", "011", "011", "100", "011", "011", "001", "010", "110", "110", "110", "110", "110", "101", "100", "011", "011", "100", "011", "011", "110", "111", "110", "110", "011", "100", "011", "011", "110", "110", "100", "011", "111", "011", "011", "100", "100", "001", "011", "011", "011", "100", "101", "101", "100", "011", "011", "100", "111", "100", "011", "011", "110", "110", "110", "110", "101", "100", "011", "011", "110", "110", "100", "101", "111", "011", "011", "100", "100", "001", "011", "011", "011", "011", "011", "011", "011", "011", "011", "110", "110", "011", "011", "010", "110", "110", "110", "110", "110", "101", "011", "110", "110", "101", "100", "111", "111", "101", "011", "011", "010", "010", "100", "101", "010", "011", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "110", "110", "110", "101", "101", "110", "110", "111", "110", "100", "011", "111", "111", "111", "011", "011", "100", "001", "100", "101", "101", "101", "011", "011", "011", "011", "011", "011", "011", "011", "011", "010", "110", "110", "101", "101", "110", "110", "111", "110", "101", "100", "111", "111", "111", "111", "111", "011", "011", "100", "100", "100", "101", "101", "101", "101", "011", "011", "011", "011", "011", "011", "011", "101", "110", "101", "101", "110", "110", "111", "111", "110", "100", "100", "111", "111", "111", "111", "111", "011", "011", "011", "100", "100", "101", "101", "110", "101", "101", "101", "011", "011", "011", "011", "101", "110", "101", "110", "110", "110", "111", "111", "110", "101", "100", "111", "111", "111", "111", "111", "111", "111", "011", "011", "011", "100", "100", "101", "101", "101", "110", "110", "110", "101", "110", "110", "110", "110", "110", "111", "110", "111", "111", "110", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "011", "011", "100", "100", "101", "101", "110", "110", "110", "110", "110", "110", "111", "110", "111", "111", "111", "111", "110", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "011", "011", "100", "100", "101", "101", "110", "110", "111", "111", "111", "111", "111", "111", "110", "110", "101", "100", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "011", "011", "011", "011", "100", "101", "101", "101", "110", "110", "110", "110", "110", "101", "101", "100", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "011", "011", "011", "011", "100", "100", "100", "100", "101", "100", "100", "100", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "011", "011", "011", "011", "011", "011", "011", "011", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111" );

constant goomba_B : ball:=("111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "101", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "100", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "101", "101", "101", "110", "101", "101", "101", "101", "101", "101", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "101", "110", "101", "110", "110", "101", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "101", "101", "110", "101", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "111", "111", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "111", "111", "110", "110", "110", "110", "111", "101", "101", "101", "111", "110", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "111", "111", "111", "111", "111", "111", "100", "101", "110", "101", "110", "110", "110", "110", "110", "101", "101", "101", "101", "101", "100", "111", "111", "111", "101", "100", "100", "011", "110", "101", "101", "101", "101", "111", "111", "111", "111", "101", "101", "101", "101", "110", "110", "110", "110", "110", "101", "101", "110", "101", "101", "101", "101", "011", "111", "110", "101", "100", "100", "100", "110", "101", "101", "101", "101", "111", "111", "111", "110", "101", "101", "101", "101", "110", "110", "110", "101", "110", "110", "101", "101", "111", "111", "110", "101", "100", "111", "110", "101", "100", "100", "100", "011", "101", "110", "101", "101", "100", "111", "111", "100", "101", "101", "010", "101", "110", "110", "101", "110", "101", "101", "110", "101", "100", "011", "110", "101", "100", "111", "111", "101", "101", "100", "011", "100", "100", "110", "101", "101", "101", "111", "111", "101", "101", "110", "010", "101", "101", "110", "101", "111", "111", "111", "110", "101", "101", "011", "110", "101", "100", "110", "111", "101", "101", "100", "100", "011", "011", "110", "110", "101", "101", "110", "111", "101", "101", "110", "101", "011", "100", "101", "111", "111", "111", "110", "110", "110", "101", "100", "110", "101", "100", "011", "100", "101", "100", "100", "100", "011", "110", "110", "110", "101", "101", "101", "101", "101", "101", "101", "110", "101", "101", "011", "110", "100", "011", "010", "111", "110", "101", "100", "110", "101", "100", "011", "100", "101", "101", "100", "101", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "101", "101", "110", "101", "101", "011", "110", "101", "101", "110", "110", "101", "101", "110", "101", "100", "011", "100", "100", "101", "100", "110", "110", "110", "110", "110", "110", "101", "101", "101", "101", "101", "110", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "101", "011", "110", "101", "100", "011", "011", "100", "101", "101", "011", "011", "110", "110", "111", "110", "101", "101", "101", "101", "101", "110", "101", "101", "101", "110", "101", "110", "111", "111", "101", "101", "100", "100", "110", "101", "100", "011", "100", "100", "101", "101", "011", "011", "011", "110", "110", "110", "110", "101", "101", "101", "101", "101", "101", "101", "101", "101", "010", "110", "110", "010", "111", "111", "100", "100", "110", "110", "100", "011", "100", "101", "101", "100", "011", "100", "101", "100", "111", "111", "110", "101", "101", "101", "101", "101", "101", "101", "101", "011", "100", "111", "111", "111", "111", "111", "100", "100", "101", "110", "101", "011", "100", "101", "101", "100", "100", "101", "101", "100", "111", "110", "110", "101", "111", "101", "101", "110", "101", "100", "010", "011", "110", "110", "110", "110", "110", "110", "100", "100", "100", "101", "101", "100", "111", "111", "111", "111", "101", "101", "101", "101", "111", "110", "101", "101", "111", "101", "101", "101", "110", "010", "011", "100", "101", "101", "110", "110", "101", "101", "101", "101", "111", "101", "101", "100", "111", "111", "111", "111", "110", "101", "101", "100", "111", "110", "101", "110", "111", "101", "101", "101", "101", "001", "100", "100", "101", "100", "100", "100", "101", "101", "100", "110", "110", "100", "101", "011", "111", "110", "111", "111", "110", "110", "100", "111", "111", "110", "101", "111", "111", "110", "101", "101", "011", "010", "110", "110", "100", "100", "101", "100", "101", "101", "100", "100", "100", "100", "101", "011", "111", "111", "111", "110", "110", "111", "111", "111", "111", "110", "101", "111", "111", "111", "101", "101", "101", "010", "110", "110", "110", "111", "100", "100", "100", "100", "100", "100", "100", "101", "100", "011", "111", "110", "110", "110", "111", "111", "111", "111", "110", "110", "111", "111", "111", "111", "111", "101", "101", "110", "101", "110", "110", "110", "110", "111", "100", "100", "100", "100", "100", "100", "100", "111", "111", "110", "110", "111", "110", "111", "111", "111", "110", "101", "111", "111", "111", "111", "111", "100", "101", "101", "110", "110", "110", "110", "110", "110", "111", "111", "100", "100", "100", "100", "110", "110", "110", "110", "111", "111", "111", "111", "111", "110", "101", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "101", "110", "110", "110", "111", "110", "111", "111", "111", "110", "110", "110", "110", "111", "111", "111", "111", "111", "110", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "110", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "101", "110", "110", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "110", "110", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "110", "110", "110", "110", "111", "111", "111", "111", "111", "110", "110", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "100", "101", "101", "101", "101", "101", "110", "110", "110", "110", "101", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "101", "101", "101", "101", "101", "101", "101", "101", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111", "111" );
---------------------------------------------------------------------------------------------------------------------------------------------------------------------------
constant tube_sprite : tube_type :=("0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","1","1","1","1","1","1","1","1","1","1","1","1","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0","0");


constant special_ball_B : ball :=("111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","101","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","100","100","101","100","100","100","100","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","101","101","101","101","101","101","101","101","101","101","100","100","100","100","110","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","101","101","101","101","101","101","101","101","101","101","101","101","101","101","100","100","101","111","111","111","111","111","111","111","111","111","111","101","100","101","101","101","101","101","101","101","110","101","101","110","101","101","101","101","101","101","101","101","100","101","111","111","111","111","111","111","111","111","101","100","100","110","111","110","101","101","110","101","110","110","110","110","110","110","110","101","101","101","101","101","100","100","101","111","111","111","111","111","111","101","100","100","101","101","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","101","100","100","110","111","111","111","111","111","100","100","100","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","101","100","100","111","111","111","111","101","100","101","101","101","101","101","110","110","101","110","101","101","110","101","110","110","101","110","110","110","101","101","101","101","101","100","100","101","111","111","111","100","100","100","101","101","101","101","100","011","011","010","010","010","010","011","010","010","010","011","100","101","011","010","010","011","101","101","100","100","111","111","110","100","100","101","101","101","011","010","100","100","100","100","011","010","010","010","010","010","010","010","010","010","010","010","010","011","101","101","101","100","110","111","100","100","101","101","100","010","001","010","101","110","101","101","100","100","011","010","010","010","010","010","010","010","010","010","010","010","101","101","101","100","101","111","100","100","101","011","010","001","001","010","110","110","110","101","100","101","101","100","011","010","010","010","010","010","010","010","010","001","110","110","101","100","100","110","100","100","100","010","010","010","010","010","110","111","110","110","101","101","110","101","100","010","010","010","010","010","010","010","010","010","110","110","101","101","100","101","100","100","010","010","010","010","010","010","100","101","111","110","011","011","101","111","101","011","010","010","010","010","011","010","010","010","110","110","110","101","100","101","100","100","010","010","011","100","011","010","010","010","011","011","010","011","100","110","100","011","010","010","010","010","011","010","010","010","110","110","110","101","100","101","100","100","011","011","101","111","111","011","010","010","010","010","010","011","100","100","011","010","010","010","010","010","011","010","010","010","110","110","110","101","100","110","100","101","100","011","011","100","111","110","010","010","011","010","011","010","011","011","010","010","011","011","010","010","011","010","010","010","110","110","110","101","101","110","100","100","101","011","100","100","101","101","010","011","011","011","011","011","011","011","011","011","011","011","011","011","100","011","011","011","110","111","110","101","101","111","101","100","101","101","011","100","100","100","100","110","110","110","110","110","110","110","110","101","101","101","101","101","101","100","100","100","110","110","110","101","101","111","101","100","100","101","101","100","011","100","101","110","110","110","110","110","110","110","110","101","101","110","100","011","101","100","100","100","111","111","110","100","110","111","111","100","100","100","101","110","101","100","011","011","011","011","011","011","011","011","011","011","011","011","100","100","011","010","011","100","111","111","101","101","111","111","111","101","100","101","101","101","101","110","110","110","110","111","110","110","111","111","110","110","110","110","110","110","110","110","110","111","111","110","101","101","111","111","111","110","100","100","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","111","111","111","101","101","111","111","111","111","111","101","100","101","100","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","111","111","111","110","101","110","111","111","111","111","111","111","101","100","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","111","111","111","111","111","101","101","111","111","111","111","111","111","111","111","100","100","100","101","101","101","110","110","110","110","110","110","110","110","110","111","111","111","111","111","110","101","101","111","111","111","111","111","111","111","111","111","111","100","100","100","101","101","101","110","110","111","111","111","111","111","111","111","111","111","111","110","101","101","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","101","101","110","110","110","110","111","111","111","111","110","110","101","100","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","100","100","101","101","101","101","110","110","110","110","101","101","101","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","100","100","100","101","101","101","101","110","111","111","111","111","111","111","111","111","111");
--
constant special_ball_G : ball :=("111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","101","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","100","100","101","100","100","100","100","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","101","101","101","101","101","101","101","101","101","101","100","100","100","100","110","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","101","101","101","101","101","101","101","101","101","101","101","101","101","101","100","100","101","111","111","111","111","111","111","111","111","111","111","101","100","101","101","101","101","101","101","101","110","101","101","110","101","101","101","101","101","101","101","101","100","101","111","111","111","111","111","111","111","111","101","100","100","110","111","110","101","101","110","101","110","110","110","110","110","110","110","101","101","101","101","101","100","100","101","111","111","111","111","111","111","101","100","100","101","101","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","101","100","100","110","111","111","111","111","111","100","100","100","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","101","101","100","100","111","111","111","111","101","100","101","101","101","101","110","110","110","110","110","110","101","110","101","110","110","101","110","110","110","101","101","101","101","101","100","100","101","111","111","111","100","100","100","101","101","101","101","100","011","011","010","010","010","010","011","010","010","010","011","100","101","011","010","010","011","101","101","100","100","111","111","110","100","100","101","101","100","011","010","100","100","100","100","011","010","010","010","010","010","010","010","010","010","010","010","010","010","101","101","101","100","110","111","100","100","101","101","011","010","001","010","101","101","101","101","100","011","011","010","010","010","010","010","010","010","010","010","010","010","101","101","101","100","101","111","100","100","101","011","010","001","001","010","110","110","110","101","100","100","100","100","011","010","010","010","010","010","010","010","010","001","110","110","101","100","100","110","100","100","100","010","010","010","010","010","110","111","110","110","101","101","110","101","100","010","001","010","010","010","010","010","010","010","110","110","101","101","100","101","100","100","010","010","010","010","010","010","100","101","111","110","011","010","100","111","101","011","010","010","010","010","011","010","010","010","110","110","110","101","100","101","100","100","010","010","011","011","011","010","010","010","011","011","010","011","100","110","100","011","010","010","010","010","011","010","010","010","110","110","110","101","100","101","100","100","011","011","101","111","111","011","010","010","010","010","010","011","100","100","011","010","010","010","010","010","011","010","010","010","110","110","110","101","100","110","100","101","100","011","011","100","111","110","010","010","010","010","011","010","011","011","010","010","010","011","010","010","011","010","010","010","110","110","110","101","101","110","100","100","101","011","100","100","101","101","010","011","011","011","011","011","011","011","011","011","011","011","011","011","100","011","011","011","110","111","110","101","101","111","101","100","101","101","011","100","100","100","100","110","110","110","110","110","110","110","101","101","101","101","101","101","101","100","100","100","110","110","110","101","101","111","101","100","100","101","101","100","011","100","100","110","110","110","110","110","110","101","110","101","101","110","100","011","100","100","100","100","111","111","110","100","110","111","111","100","100","100","101","110","101","100","011","011","011","011","011","011","011","011","011","011","011","011","011","100","011","010","011","100","111","111","101","101","111","111","111","101","100","100","101","101","110","101","110","110","110","110","110","110","111","110","110","110","110","110","110","110","110","110","110","111","111","110","101","101","111","111","111","110","100","100","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","111","111","111","101","101","111","111","111","111","111","101","100","101","100","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","111","111","111","110","101","110","111","111","111","111","111","111","101","100","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","111","111","111","111","111","101","101","111","111","111","111","111","111","111","111","100","100","100","101","101","101","110","110","110","110","110","110","110","110","110","111","111","111","111","111","110","101","101","111","111","111","111","111","111","111","111","111","111","100","100","100","101","101","101","110","110","111","111","111","111","111","111","111","111","111","111","110","101","101","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","101","101","110","110","110","110","111","111","111","111","110","110","101","100","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","100","100","101","101","101","101","110","110","110","110","101","101","101","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","100","100","100","101","101","101","101","110","111","111","111","111","111","111","111","111","111");
--
constant special_ball_R : ball :=("111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","101","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","101","100","100","100","100","100","100","100","101","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","100","100","101","100","100","100","100","100","100","100","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","101","101","101","101","101","101","101","101","101","101","100","100","100","100","110","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","101","101","101","101","101","101","101","101","101","101","101","101","101","101","100","100","101","111","111","111","111","111","111","111","111","111","111","101","100","101","101","101","101","101","101","101","110","101","101","110","101","101","101","101","101","101","101","101","100","101","111","111","111","111","111","111","111","111","101","100","100","110","111","110","101","101","110","101","110","110","110","110","110","110","110","101","101","101","101","101","100","100","101","111","111","111","111","111","111","101","100","100","101","101","110","110","101","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","101","100","100","110","111","111","111","111","111","100","100","100","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","101","101","101","101","100","100","111","111","111","111","101","100","101","101","101","101","101","110","110","101","110","101","101","110","101","110","110","101","101","110","110","101","101","101","101","101","100","100","101","111","111","111","100","100","100","101","101","101","101","100","011","011","010","010","010","010","011","010","010","010","011","100","100","011","010","010","011","101","101","100","100","111","111","110","100","100","101","101","100","011","010","011","100","100","011","011","010","001","010","010","010","010","010","010","010","010","010","010","010","101","101","101","100","110","111","100","100","101","101","011","010","001","001","101","101","101","100","100","011","011","010","010","010","010","010","010","010","010","010","010","010","101","101","101","100","101","111","100","100","101","011","010","001","001","010","101","110","101","101","100","100","100","100","011","010","010","010","001","010","010","001","001","001","110","110","101","100","100","110","100","100","100","010","001","010","010","010","110","111","110","110","101","100","101","101","100","010","001","010","010","010","010","010","010","001","110","110","101","101","100","101","100","100","010","010","010","010","010","010","011","101","110","110","011","010","100","111","101","011","010","010","010","010","010","010","010","010","110","110","110","101","100","101","100","100","010","010","011","011","011","010","010","010","011","010","010","011","100","110","100","011","010","010","010","010","010","010","010","010","110","110","110","101","100","101","100","100","011","010","100","111","111","011","010","010","010","010","010","011","100","100","011","010","010","010","010","010","011","010","010","010","110","110","110","101","100","110","100","101","100","011","011","100","111","101","010","010","010","010","010","010","010","011","010","010","010","010","010","010","011","010","010","010","110","110","110","101","101","110","100","100","101","011","011","100","101","101","010","011","011","011","011","011","011","011","011","011","011","011","011","011","100","011","011","011","110","111","110","101","101","111","101","100","101","101","011","011","100","100","100","110","110","110","110","110","110","110","101","101","101","101","101","100","101","100","100","100","110","110","110","101","101","111","101","100","100","101","101","100","011","011","100","110","110","110","110","110","110","101","110","101","101","110","100","011","100","100","100","100","111","111","110","100","110","111","111","100","100","100","101","110","101","100","011","011","011","011","011","011","011","011","011","011","011","011","011","100","011","010","010","100","111","111","101","101","111","111","111","101","100","101","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","111","111","110","101","101","111","111","111","110","100","100","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","111","111","111","101","101","111","111","111","111","111","101","100","101","100","101","101","110","110","110","110","110","110","110","110","110","110","110","110","110","110","110","111","111","111","110","101","110","111","111","111","111","111","111","101","100","101","101","101","101","110","110","110","110","110","110","110","110","110","110","110","110","111","111","111","111","111","101","101","111","111","111","111","111","111","111","111","100","100","100","101","101","101","110","110","110","110","110","110","110","110","110","111","111","111","111","111","110","101","101","111","111","111","111","111","111","111","111","111","111","100","100","100","101","101","101","110","110","111","111","111","111","111","111","111","111","111","111","110","101","101","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","101","101","110","110","110","110","111","111","111","111","110","110","101","100","110","111","111","111","111","111","111","111","111","111","111","111","111","111","111","110","101","100","100","101","101","101","101","110","110","110","110","101","101","101","101","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","111","101","100","100","100","100","100","100","101","101","101","101","110","111","111","111","111","111","111","111","111","111");

-------------------------------------------------------------------------------------------------------------------
constant bang_B : ball :=("001", "000", "000", "000", "000", "001", "000", "000", "000", "001", "000", "000", "000", "001", "001", "001", "000", "001", "001", "001", "000", "000", "001", "001", "001", "001", "001", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "001", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "001", "000", "000", "000", "000", "000", "000", "001", "001", "001", "001", "001", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "001", "000", "000", "000", "000", "000", "000", "000", "001", "000", "001", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "001", "001", "001", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "001", "000", "000", "000", "001", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "001", "000", "001", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "001", "011", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "001", "000", "000", "001", "000", "000", "000", "000", "000", "000", "001", "000", "000", "011", "010", "000", "011", "110", "000", "000", "001", "111", "010", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "110", "111", "010", "000", "000", "000", "000", "000", "000", "110", "010", "000", "000", "000", "000", "000", "001", "001", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "111", "111", "100", "000", "001", "001", "000", "000", "000", "000", "000", "000", "001", "001", "000", "001", "000", "001", "001", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "001", "000", "010", "111", "111", "110", "010", "010", "010", "000", "000", "000", "000", "000", "000", "001", "000", "000", "001", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "001", "111", "101", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "001", "001", "001", "001", "000", "000", "000", "000", "000", "000", "001", "111", "111", "101", "001", "000", "000", "001", "010", "000", "001", "111", "111", "100", "000", "001", "000", "001", "001", "000", "000", "000", "000", "000", "000", "001", "001", "000", "001", "000", "000", "000", "001", "110", "100", "110", "110", "001", "000", "000", "000", "000", "000", "110", "111", "101", "000", "000", "000", "000", "001", "001", "000", "000", "001", "001", "000", "000", "000", "001", "001", "001", "000", "000", "001", "111", "011", "000", "000", "000", "000", "000", "000", "000", "000", "000", "010", "010", "000", "001", "000", "000", "000", "000", "001", "000", "000", "001", "000", "001", "001", "000", "001", "001", "000", "000", "100", "111", "111", "100", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "001", "000", "000", "000", "000", "000", "010", "111", "111", "111", "101", "000", "000", "011", "111", "101", "100", "011", "100", "010", "000", "001", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "001", "000", "001", "000", "001", "001", "000", "000", "001", "010", "101", "010", "000", "000", "100", "111", "111", "111", "111", "010", "000", "001", "000", "000", "000", "000", "001", "001", "001", "000", "000", "000", "000", "000", "001", "000", "001", "001", "000", "000", "000", "000", "000", "001", "000", "000", "000", "001", "110", "111", "110", "001", "000", "000", "000", "000", "000", "001", "001", "000", "001", "001", "000", "000", "001", "000", "000", "000", "000", "000", "001", "010", "011", "000", "000", "000", "000", "000", "000", "000", "000", "101", "100", "000", "001", "000", "000", "001", "001", "000", "000", "000", "001", "001", "000", "000", "001", "001", "001", "000", "000", "000", "000", "111", "110", "000", "000", "010", "011", "000", "000", "000", "011", "101", "010", "000", "000", "000", "000", "000", "001", "001", "000", "000", "001", "000", "000", "001", "000", "000", "000", "000", "000", "001", "001", "001", "000", "000", "110", "111", "111", "101", "000", "000", "111", "111", "001", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "001", "000", "000", "001", "000", "000", "000", "001", "000", "001", "000", "000", "000", "011", "100", "010", "010", "001", "000", "000", "010", "000", "001", "000", "000", "000", "000", "001", "000", "000", "000", "001", "000", "001", "000", "000", "001", "000", "001", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "001", "000", "000", "000", "001", "001", "001", "001", "001", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "010", "001", "000", "000", "001", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "001", "000", "000", "010", "011", "001", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "001", "001", "000", "000", "000", "001", "000", "001", "001", "000", "000", "001", "000", "000", "000", "000", "001", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "001", "001", "001", "001", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "001", "000", "000", "001", "010", "001", "000", "000", "001", "001", "001", "001", "010", "000", "000", "001", "001", "001", "000", "000", "000", "001", "000", "000", "001", "000", "000", "001"   );
--
constant bang_G : ball :=("001", "000", "000", "000", "000", "001", "000", "000", "001", "000", "001", "000", "000", "000", "000", "001", "001", "001", "001", "000", "001", "000", "000", "001", "001", "000", "000", "000", "001", "001", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "010", "001", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "011", "011", "001", "110", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "110", "111", "111", "101", "000", "010", "100", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "010", "100", "111", "111", "111", "011", "000", "101", "111", "000", "000", "010", "111", "011", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "110", "111", "111", "111", "111", "010", "000", "000", "000", "000", "000", "001", "111", "011", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "011", "111", "111", "111", "111", "100", "000", "000", "001", "000", "000", "000", "000", "000", "000", "101", "100", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "100", "111", "111", "111", "111", "110", "010", "010", "010", "000", "000", "000", "000", "000", "010", "111", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "110", "111", "111", "011", "000", "000", "000", "000", "000", "010", "000", "000", "000", "000", "100", "111", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "100", "111", "111", "111", "111", "110", "001", "000", "000", "001", "011", "000", "000", "111", "111", "110", "111", "110", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "011", "111", "111", "111", "011", "101", "110", "010", "000", "000", "000", "000", "001", "111", "111", "111", "111", "011", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "110", "111", "111", "010", "000", "000", "000", "000", "000", "000", "000", "000", "000", "010", "111", "110", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "011", "111", "111", "111", "100", "000", "000", "000", "001", "000", "000", "000", "000", "000", "110", "111", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "100", "111", "111", "111", "111", "101", "000", "000", "011", "111", "110", "100", "011", "100", "111", "111", "011", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "011", "111", "101", "000", "001", "011", "110", "010", "000", "000", "011", "111", "111", "111", "111", "111", "111", "011", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "010", "111", "100", "000", "000", "000", "000", "000", "000", "000", "000", "001", "111", "111", "111", "111", "100", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "101", "110", "010", "010", "000", "000", "000", "000", "000", "000", "000", "000", "101", "111", "111", "010", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "001", "111", "111", "111", "101", "000", "000", "010", "010", "000", "000", "000", "010", "100", "111", "111", "010", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "101", "111", "111", "000", "000", "110", "111", "111", "101", "000", "000", "110", "111", "111", "111", "011", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "101", "101", "000", "100", "111", "111", "111", "111", "010", "000", "101", "111", "111", "110", "010", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "010", "000", "100", "111", "010", "001", "101", "010", "000", "101", "111", "101", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "011", "010", "000", "000", "000", "000", "000", "110", "100", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "010", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "000", "001", "000", "000", "000", "000", "001", "000", "001", "001", "000", "000", "000", "001", "001", "001", "001", "001", "000", "000", "000", "000", "001", "000", "000", "000", "000", "001", "001", "000", "000", "000", "001"  );
--
constant bang_R : ball :=("110", "110", "110", "110", "110", "110", "110", "110", "110", "110", "100", "110", "110", "110", "110", "100", "111", "101", "011", "100", "101", "110", "110", "011", "011", "110", "110", "110", "110", "110", "101", "110", "110", "110", "101", "110", "110", "110", "110", "110", "110", "101", "001", "100", "111", "111", "011", "000", "010", "011", "101", "100", "101", "111", "011", "001", "101", "110", "110", "101", "101", "110", "110", "110", "110", "110", "101", "110", "101", "101", "101", "110", "111", "100", "010", "011", "011", "011", "010", "010", "010", "110", "111", "101", "100", "011", "010", "100", "110", "110", "110", "110", "110", "110", "110", "101", "110", "110", "101", "101", "110", "110", "011", "011", "100", "100", "110", "110", "011", "011", "110", "111", "111", "110", "110", "110", "101", "100", "100", "100", "111", "110", "110", "110", "110", "110", "101", "110", "110", "110", "110", "110", "110", "110", "011", "011", "101", "101", "100", "111", "110", "100", "110", "101", "110", "100", "101", "110", "111", "111", "101", "100", "111", "110", "100", "100", "110", "110", "110", "110", "110", "101", "101", "110", "110", "110", "100", "101", "111", "110", "001", "100", "101", "010", "100", "100", "100", "010", "010", "100", "100", "100", "100", "010", "100", "100", "001", "100", "110", "110", "110", "110", "110", "101", "011", "101", "111", "110", "100", "100", "111", "101", "011", "100", "100", "100", "100", "111", "111", "111", "110", "101", "101", "101", "101", "100", "011", "101", "011", "110", "110", "101", "110", "110", "110", "111", "010", "010", "101", "100", "100", "110", "101", "010", "101", "111", "111", "110", "101", "110", "110", "111", "111", "111", "111", "111", "111", "111", "101", "101", "011", "110", "110", "110", "110", "101", "101", "110", "111", "011", "011", "101", "110", "101", "011", "101", "111", "111", "111", "101", "101", "101", "110", "111", "111", "101", "111", "101", "111", "101", "100", "111", "011", "100", "111", "110", "110", "110", "110", "101", "111", "100", "010", "111", "110", "100", "110", "111", "111", "111", "111", "011", "111", "111", "110", "111", "111", "101", "110", "101", "111", "011", "100", "101", "110", "100", "010", "100", "110", "110", "110", "110", "111", "011", "010", "110", "110", "100", "100", "111", "111", "111", "111", "101", "101", "111", "011", "110", "111", "111", "110", "111", "101", "100", "101", "100", "111", "100", "010", "101", "110", "110", "010", "101", "100", "010", "101", "110", "111", "101", "100", "111", "111", "111", "111", "101", "010", "010", "011", "101", "111", "111", "111", "101", "010", "101", "100", "111", "110", "011", "101", "110", "110", "110", "011", "001", "100", "110", "110", "101", "110", "011", "101", "111", "111", "011", "000", "100", "111", "110", "100", "011", "101", "110", "010", "000", "100", "111", "100", "101", "100", "100", "111", "110", "101", "110", "110", "100", "100", "101", "110", "110", "010", "011", "111", "111", "111", "111", "101", "100", "111", "111", "101", "010", "101", "100", "100", "111", "111", "111", "101", "011", "100", "101", "110", "110", "101", "110", "110", "111", "100", "100", "110", "110", "011", "100", "111", "111", "110", "101", "111", "101", "001", "010", "110", "110", "111", "011", "101", "111", "111", "111", "110", "110", "110", "100", "101", "110", "110", "110", "110", "100", "011", "101", "110", "101", "111", "100", "110", "111", "111", "011", "100", "111", "110", "110", "101", "111", "111", "111", "110", "100", "111", "110", "101", "110", "110", "101", "100", "010", "100", "110", "101", "001", "011", "110", "110", "101", "110", "101", "101", "111", "111", "111", "101", "110", "111", "101", "101", "101", "100", "100", "110", "001", "100", "111", "101", "111", "110", "110", "100", "011", "110", "110", "110", "101", "100", "011", "100", "111", "110", "101", "100", "111", "110", "111", "111", "101", "110", "101", "001", "110", "110", "100", "011", "100", "111", "111", "100", "010", "110", "101", "100", "101", "110", "110", "110", "110", "111", "101", "011", "101", "011", "100", "111", "101", "100", "101", "101", "100", "010", "110", "110", "100", "111", "111", "111", "111", "111", "111", "011", "010", "110", "110", "100", "100", "110", "110", "101", "110", "110", "110", "100", "101", "100", "011", "111", "101", "101", "111", "111", "111", "110", "110", "111", "110", "011", "110", "111", "111", "111", "100", "011", "111", "110", "110", "101", "011", "010", "011", "110", "101", "110", "110", "100", "101", "111", "100", "101", "110", "100", "100", "011", "110", "110", "110", "110", "111", "110", "010", "100", "111", "111", "011", "101", "110", "110", "101", "100", "101", "100", "010", "110", "110", "110", "010", "100", "111", "110", "011", "110", "111", "111", "100", "100", "100", "001", "010", "100", "110", "100", "011", "101", "111", "111", "011", "100", "110", "110", "100", "101", "111", "110", "110", "110", "110", "100", "000", "011", "110", "100", "011", "101", "111", "110", "101", "110", "101", "111", "111", "101", "111", "110", "101", "111", "111", "111", "011", "100", "110", "110", "101", "101", "110", "101", "111", "110", "110", "110", "110", "010", "010", "110", "110", "011", "101", "110", "101", "110", "111", "111", "111", "111", "110", "101", "101", "111", "111", "110", "010", "011", "110", "101", "010", "100", "111", "110", "101", "110", "101", "110", "110", "110", "010", "100", "110", "111", "100", "100", "101", "100", "111", "101", "011", "011", "100", "110", "100", "111", "101", "011", "101", "101", "100", "100", "100", "011", "100", "110", "110", "110", "110", "101", "110", "110", "011", "101", "111", "111", "100", "011", "110", "011", "011", "101", "100", "000", "101", "111", "011", "111", "100", "100", "111", "100", "101", "111", "111", "101", "100", "110", "110", "110", "110", "110", "111", "101", "010", "011", "010", "100", "111", "101", "011", "110", "100", "010", "111", "110", "111", "101", "101", "101", "010", "110", "111", "101", "101", "110", "110", "110", "110", "110", "110", "110", "101", "110", "101", "010", "010", "100", "011", "010", "100", "101", "100", "110", "101", "011", "100", "101", "101", "011", "110", "110", "011", "101", "101", "011", "100", "101", "110", "110", "110", "110", "110", "110", "110", "101", "100", "011", "111", "111", "110", "100", "101", "100", "101", "101", "011", "100", "011", "100", "011", "010", "010", "110", "101", "010", "100", "011", "100", "101", "110", "110", "101", "101", "110", "110", "110", "110", "110", "110", "110", "101", "111", "011", "011", "011", "001", "100", "101", "101", "110", "011", "001", "100", "011", "011", "011", "100", "110", "110", "110", "101", "101", "110", "110", "110", "110", "110", "110", "110", "110", "110", "101", "110", "111", "010", "001", "101", "011", "010", "111", "101", "011", "010", "101", "111", "111", "011", "010", "110", "110", "110", "110", "110", "110", "110", "110", "101", "110", "110", "101", "110", "110", "110", "110", "111", "100", "000", "101", "111", "111", "011", "011", "100", "011", "011", "111", "110", "110", "110", "110", "110", "110", "110", "110", "101", "110", "110", "110", "110", "110"    );
----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------


type address_type_x is array (0 to 179) of unsigned(9 downto 0);
type address_type_y is array (0 to 11) of unsigned(9 downto 0);
	  	 	 constant address_x : address_type_x :=("0000101110","0001001110","0001101110","0010001110","0010101110","0011001110","0011101110","0100001110","0100101110","0101001110","0101101110","0110001110","0110101110","0111001110","0111101110","1000001110","1000101110","1001001110","0000111110","0001011110","0001111110","0010011110","0010111110","0011011110","0011111110","0100011110","0100111110","0101011110","0101111110","0110011110","0110111110","0111011110","0111111110","1000011110","1000111110","1001011110","0000101110","0001001110","0001101110","0010001110","0010101110","0011001110","0011101110","0100001110","0100101110","0101001110","0101101110","0110001110","0110101110","0111001110","0111101110","1000001110","1000101110","1001001110","0000111110","0001011110","0001111110","0010011110","0010111110","0011011110","0011111110","0100011110","0100111110","0101011110","0101111110","0110011110","0110111110","0111011110","0111111110","1000011110","1000111110","1001011110","0000101110","0001001110","0001101110","0010001110","0010101110","0011001110","0011101110","0100001110","0100101110","0101001110","0101101110","0110001110","0110101110","0111001110","0111101110","1000001110","1000101110","1001001110","0000111110","0001011110","0001111110","0010011110","0010111110","0011011110","0011111110","0100011110","0100111110","0101011110","0101111110","0110011110","0110111110","0111011110","0111111110","1000011110","1000111110","1001011110","0000101110","0001001110","0001101110","0010001110","0010101110","0011001110","0011101110","0100001110","0100101110","0101001110","0101101110","0110001110","0110101110","0111001110","0111101110","1000001110","1000101110","1001001110","0000111110","0001011110","0001111110","0010011110","0010111110","0011011110","0011111110","0100011110","0100111110","0101011110","0101111110","0110011110","0110111110","0111011110","0111111110","1000011110","1000111110","1001011110","0000101110","0001001110","0001101110","0010001110","0010101110","0011001110","0011101110","0100001110","0100101110","0101001110","0101101110","0110001110","0110101110","0111001110","0111101110","1000001110","1000101110","1001001110","0000111110","0001011110","0001111110","0010011110","0010111110","0011011110","0011111110","0100011110","0100111110","0101011110","0101111110","0110011110","0110111110","0111011110","0111111110","1000011110","1000111110","1001011110");	 
			 constant address_y : address_type_y :=("0000101110","0001001011","0001101000","0010000101","0010100010","0010111111","0011011100","0011111001","0100010110","0100110011","0101010000","0101101101");
--	   
  
begin

  ram_address     <= unsigned(address(8 downto 0));
  ram_inf_address <= unsigned(address_inf(8 downto 0));
--  buffer_higher <= unsigned(RAM(to_integer(display_address+1))(8 downto 6));
--  buffer_mid    <= unsigned(RAM(to_integer(display_address+1))(5 downto 3));
--  buffer_lower  <= unsigned(RAM(to_integer(display_address+1))(2 downto 0));

  process (clk)
  begin
   if rising_edge(clk) then
		clk25 <= not clk25;
	end if;
  end process;


  position : process (clk)
  begin
    if rising_edge(clk) then
      if reset = '1' then
			--readdata <= (others => read_address'0');
			display_address <= (others => '0'); 
			counter <= (others => '1');
      else
        if chipselect = '1' then 
         if address(18) = '0' then      
            if read = '1' then
					--readdata <= RAM(to_integer(ram_address));
            elsif write = '1' then
					RAM(to_integer(ram_address)) <= writedata;
					RAM_inf(to_integer(ram_inf_address))<=write_inf;
            end if;
			end if;
        end if;
		   shoot_h <= unsigned(RAM_inf(to_integer(display_address)));
         shoot_v <= unsigned(RAM_inf(to_integer(display_address+1)));
			shoot_ball_type <= unsigned(RAM_inf(to_integer(display_address+2)));
			arrow <= unsigned(RAM_inf(to_integer(display_address+190)));
			arrow_first <= unsigned(RAM_inf(to_integer(display_address+193)));
			arrow_second <= unsigned(RAM_inf(to_integer(display_address+194)));
			shoot_h_2 <= unsigned(RAM_inf(to_integer(display_address+200)));
         shoot_v_2 <= unsigned(RAM_inf(to_integer(display_address+201)));
			shoot_ball_type_2 <= unsigned(RAM_inf(to_integer(display_address+202)));
			numberd0 <= unsigned(RAM_inf(to_integer(display_address+203)));
			numberd1 <= unsigned(RAM_inf(to_integer(display_address+204)));
			numberd2 <= unsigned(RAM_inf(to_integer(display_address+205)));
			launch <= unsigned(RAM_inf(to_integer(display_address+191)));
			option <= unsigned(RAM_inf(to_integer(display_address+192)));
		--	if flag = '1' then
		   for k in 0 to 180 loop
		   ball_type(k) <= unsigned(RAM_inf(to_integer(display_address+k+3))(7 downto 0));
			end loop;
		--	else
		--	for k in 91 to 180 loop
		--   ball_type(k) <= unsigned(RAM_inf(to_integer(display_address+k+3))(7 downto 0));
		--	end loop;
	  --    end if;
			
      end if;
    end if;
  end process position;
  
  
    shoot_cen_h <= to_integer(shoot_h);
    shoot_cen_v <= to_integer(shoot_v);
	 arrow_n <= to_integer(arrow);
	 arrow_n_first <= to_integer(arrow_first);
	 arrow_n_second <= to_integer(arrow_second);
	 
	 shoot_cen_h_2 <= to_integer(shoot_h_2);
    shoot_cen_v_2 <= to_integer(shoot_v_2);
	 arrow_n_2 <= to_integer(arrow);
	 
	 number0_type <= to_integer(numberd0);
    number1_type <= to_integer(numberd1);
	 number2_type <= to_integer(numberd2);
	 
    launch_n<= to_integer(launch);
	 
  process(clk25)
  begin
      if rising_edge(clk25) then
		      flag <= not flag;
		end if;
  end process;
  
  
   vga_split : process (clk25)
   begin
    if rising_edge(clk25) then      
         VGA_buffer <=unsigned(RAM(to_integer(display_address)));
         			
    end if;
   end process vga_split;

	
  process(clk)
  begin
      if rising_edge(clk) then 
        VGA_B_buffer <= std_logic_vector(VGA_buffer(15 downto 14));
        VGA_R_buffer <= std_logic_vector(VGA_buffer(13 downto 11));
        VGA_G_buffer <= std_logic_vector(VGA_buffer(10 downto 8));
        VGA_B_buffer_next <= std_logic_vector(VGA_buffer(7 downto 6));
        VGA_R_buffer_next <= std_logic_vector(VGA_buffer(5 downto 3));
        VGA_G_buffer_next <= std_logic_vector(VGA_buffer(2 downto 0));
		end if;
  end process;
  -- Horizontal and vertical counters

  address_count: process(clk25)
  begin
      if rising_edge(clk25) then 
		     if flag ='0' then
			    if tube_HV = '1' then
			        read_address <= to_unsigned(((to_integer(Hcount) - HSYNC - HBACK_PORCH - tube_HSTART) + (to_integer(Vcount) - VSYNC - VBACK_PORCH - tube_VSTART)*64 + 64*64*arrow_n+320000)/2,19);
			    elsif tube_first_HV = '1' then
				     read_address <= to_unsigned(((to_integer(Hcount) - HSYNC - HBACK_PORCH - tube_first_HSTART) + (to_integer(Vcount) - VSYNC - VBACK_PORCH - tube_first_VSTART)*64 + 64*64*arrow_n_first+320000)/2,19);
				 elsif tube_second_HV = '1' then
				     read_address <= to_unsigned(((to_integer(Hcount) - HSYNC - HBACK_PORCH - tube_second_HSTART) + (to_integer(Vcount) - VSYNC - VBACK_PORCH - tube_second_VSTART)*64 + 64*64*arrow_n_second+320000)/2,19);
				 elsif score_sprite1_HV = '1' then 
				     read_address <= to_unsigned(((to_integer(Hcount) - HSYNC - HBACK_PORCH - score_H1START) + (to_integer(Vcount) - VSYNC - VBACK_PORCH - score_VSTART)*32 + 32*40*number0_type+450000)/2,19);
             elsif score_sprite2_HV = '1' then 
				     read_address <= to_unsigned(((to_integer(Hcount) - HSYNC - HBACK_PORCH - score_H2START) + (to_integer(Vcount) - VSYNC - VBACK_PORCH - score_VSTART)*32 + 32*40*number1_type+450000)/2,19);
				 elsif score_sprite3_HV = '1' then 
				     read_address <= to_unsigned(((to_integer(Hcount) - HSYNC - HBACK_PORCH - score_H3START) + (to_integer(Vcount) - VSYNC - VBACK_PORCH - score_VSTART)*32 + 32*40*number2_type+450000)/2,19);
	 
				 else
		           read_address <= to_unsigned((to_integer(Hcount) - HSYNC - HBACK_PORCH - RECTANGLE_HSTART)/2 + (to_integer(Vcount) - VSYNC - VBACK_PORCH - RECTANGLE_VSTART)*320,19);
		       end if;
			  end if;
		end if;
  end process;
  
  readdata<=std_logic_vector(read_address);
  
  
  
 RectangleHGen : process (clk25)
  begin
    if rising_edge(clk25) then     
      if reset = '1' or Hcount = HSYNC + HBACK_PORCH + RECTANGLE_HSTART then
        rectangle_h <= '1';
      elsif Hcount = HSYNC + HBACK_PORCH + RECTANGLE_HEND then
        rectangle_h <= '0';
      end if;      
    end if;
  end process RectangleHGen;
  
    RectangleVGen : process (clk25)
  begin
    if rising_edge(clk25) then
      if reset = '1' then       
        rectangle_v <= '0';
      elsif EndOfLine = '1' then
        if Vcount = VSYNC + VBACK_PORCH - 1 + RECTANGLE_VSTART then
          rectangle_v <= '1';
        elsif Vcount = VSYNC + VBACK_PORCH - 1 + RECTANGLE_VEND then
          rectangle_v <= '0';
        end if;
      end if;      
    end if;
  end process RectangleVGen;
  -----------------------------------------------------------------------------------------
  score_spriteV: process (clk25)
  
   begin
	  if rising_edge(clk25) then
	    if launch = "0000000000000001" then
	     if Vcount = VSYNC + VBACK_PORCH + score_VSTART then
	           score_V <= '1';
	     elsif Vcount = VSYNC + VBACK_PORCH + score_VEND or reset = '1' then
	           score_V <= '0';
	     end if;
		 end if; 
	  end if;
  end process score_spriteV;
  
  score_spriteH1: process (clk25)
  
   begin
	  if rising_edge(clk25) then
	    if launch = "0000000000000001" then
	    if Hcount = HSYNC + HBACK_PORCH + score_H1START then
	           score_H1 <= '1';
	     elsif Hcount = HSYNC + HBACK_PORCH + score_H1END or reset = '1' then
	           score_H1 <= '0';
		 end if;
		end if;		  
	  end if;
  end process score_spriteH1;
  
  score_spriteH2: process (clk25)
  
   begin
	  if rising_edge(clk25) then
	    if launch = "0000000000000001" then
	   if Hcount = HSYNC + HBACK_PORCH + score_H2START then
	           score_H2 <= '1';
	     elsif Hcount = HSYNC + HBACK_PORCH + score_H2END or reset = '1' then
	           score_H2 <= '0';
	     end if;
		 end if; 
	  end if;
  end process score_spriteH2;
  
  score_spriteH3: process (clk25)
  
   begin
	  if rising_edge(clk25) then
	    if launch = "0000000000000001" then
	    if Hcount = HSYNC + HBACK_PORCH + score_H3START then
	           score_H3 <= '1';
	     elsif Hcount = HSYNC + HBACK_PORCH + score_H3END or reset = '1' then
	           score_H3 <= '0';
	     end if;
		 end if; 
	  end if;
  end process score_spriteH3;
  
  
  score_sprite1_HV <= score_H1 and score_V;
  score_sprite2_HV <= score_H2 and score_V;
  score_sprite3_HV <= score_H3 and score_V;
  
  
  tube_spriteV: process (clk25)
  begin
	  if rising_edge(clk25) then
	    if launch = "0000000000000001" then
	     if Vcount = VSYNC + VBACK_PORCH + tube_VSTART then
	           tube_V <= '1';
	     elsif Vcount = VSYNC + VBACK_PORCH + tube_VEND or reset = '1' then
	           tube_V <= '0';
	     end if;
		 end if; 
	  end if;
  end process tube_spriteV;
  
  tube_spriteH: process (clk25)
  begin
	  if rising_edge(clk25) then
	   if launch = "0000000000000001" then
	     if Hcount = HSYNC + HBACK_PORCH + tube_HSTART then
	           tube_H <= '1';
	     elsif Hcount = HSYNC + HBACK_PORCH + tube_HEND or reset = '1' then
	           tube_H <= '0';
	     end if;
		 end if; 
	  end if;
  end process tube_spriteH;
  
   
	--------------------------------two player--------------------------------------------------------------------
	  tube_first_spriteV: process (clk25)
  begin
	  if rising_edge(clk25) then
	    if launch = "0000000000000011" then
	     if Vcount = VSYNC + VBACK_PORCH + tube_first_VSTART then
	           tube_first_V <= '1';
	     elsif Vcount = VSYNC + VBACK_PORCH + tube_first_VEND or reset = '1' then
	           tube_first_V <= '0';
	     end if;
		 end if; 
	  end if;
  end process tube_first_spriteV;
  
  tube_first_spriteH: process (clk25)
  begin
	  if rising_edge(clk25) then
	   if launch = "0000000000000011" then
	     if Hcount = HSYNC + HBACK_PORCH + tube_first_HSTART then
	           tube_first_H <= '1';
	     elsif Hcount = HSYNC + HBACK_PORCH + tube_first_HEND or reset = '1' then
	           tube_first_H <= '0';
	     end if;
		 end if; 
	  end if;
  end process tube_first_spriteH;
  
  	  tube_second_spriteV: process (clk25)
  begin
	  if rising_edge(clk25) then
	    if launch = "0000000000000011" then
	     if Vcount = VSYNC + VBACK_PORCH + tube_second_VSTART then
	           tube_second_V <= '1';
	     elsif Vcount = VSYNC + VBACK_PORCH + tube_second_VEND or reset = '1' then
	           tube_second_V <= '0';
	     end if;
		 end if; 
	  end if;
  end process tube_second_spriteV;
  
  tube_second_spriteH: process (clk25)
  begin
	  if rising_edge(clk25) then
	   if launch = "0000000000000011" then
	     if Hcount = HSYNC + HBACK_PORCH + tube_second_HSTART then
	           tube_second_H <= '1';
	     elsif Hcount = HSYNC + HBACK_PORCH + tube_second_HEND or reset = '1' then
	           tube_second_H <= '0';
	     end if;
		 end if; 
	  end if;
  end process tube_second_spriteH;
	----------------------------------------------------------------------------------------------------
	
	
	
	
	tube_HV <= tube_H and tube_V;
	tube_first_HV <= tube_first_V and tube_first_H;
	tube_second_HV <= tube_second_V and tube_second_H;
   rectangle <= rectangle_h and rectangle_v;
  -------------------------------------------------------------------------------------------
  
--  tube_sprite_detect: process(clk25)
--  begin
--      if rising_edge(clk25) then
--		   if tube_HV = '1' then
--			   if tube_sprite(to_integer(Hcount) - HSYNC - HBACK_PORCH - tube_HSTART + (to_integer(Vcount) - VSYNC - VBACK_PORCH - tube_VSTART)*64) = "1" then
--		       tube_sprite_control <= '1';
--				else
--				 tube_sprite_control <= '0';
--				end if;
--			end if;
--		end if;
--  end process tube_sprite_detect;
  -------------------------------------------------------------------------------------------
  

  
  
  HCounter : process (clk25)
  begin
    if rising_edge(clk25) then      
      if reset = '1' then
        Hcount <= (others => '0');
      elsif EndOfLine = '1' then
        Hcount <= (others => '0');
      else
        Hcount <= Hcount + 1;
      end if;      
    end if;
  end process HCounter;

  EndOfLine <= '1' when Hcount = HTOTAL - 1 else '0';
  
  VCounter: process (clk25)
  begin
    if rising_edge(clk25) then      
      if reset = '1' then
        Vcount <= (others => '0');
      elsif EndOfLine = '1' then
        if EndOfField = '1' then
          Vcount <= (others => '0');
        else
          Vcount <= Vcount + 1;
        end if;
      end if;
    end if;
  end process VCounter;

  EndOfField <= '1' when Vcount = VTOTAL - 1 else '0';

  -- State machines to generate HSYNC, VSYNC, HBLANK, and VBLANK

  HSyncGen : process (clk25)
  begin
    if rising_edge(clk25) then     
      if reset = '1' or EndOfLine = '1' then
        vga_hsync <= '1';
      elsif Hcount = HSYNC - 1 then
        vga_hsync <= '0';
      end if;
    end if;
  end process HSyncGen;
  
  HBlankGen : process (clk25)
  begin
    if rising_edge(clk25) then 
      if reset = '1' then
        vga_hblank <= '1';
      elsif Hcount = HSYNC + HBACK_PORCH then
        vga_hblank <= '0';
      elsif Hcount = HSYNC + HBACK_PORCH + HACTIVE then
        vga_hblank <= '1';
      end if;      
    end if;
  end process HBlankGen;

  VSyncGen : process (clk25)
  begin
    if rising_edge(clk25) then
      if reset = '1' then
        vga_vsync <= '1';
      elsif EndOfLine ='1' then
        if EndOfField = '1' then
          vga_vsync <= '1';
        elsif Vcount = VSYNC - 1 then
          vga_vsync <= '0';
        end if;
      end if;      
    end if;
  end process VSyncGen;

  VBlankGen : process (clk25)
  begin
    if rising_edge(clk25) then    
      if reset = '1' then
        vga_vblank <= '1';
      elsif EndOfLine = '1' then
        if Vcount = VSYNC + VBACK_PORCH - 1 then
          vga_vblank <= '0';
        elsif Vcount = VSYNC + VBACK_PORCH + VACTIVE - 1 then
          vga_vblank <= '1';
        end if;
      end if;
    end if;
  end process VBlankGen;

  -- Circle generator
  
    shoot_ball: process(clk25)
   begin
	  if rising_edge(clk25) then
	     if (((to_integer(Vcount)-VSYNC-VBACK_PORCH-shoot_cen_v)*(to_integer(Vcount)-VSYNC-VBACK_PORCH-shoot_cen_v)+(to_integer(Hcount)-HSYNC-HBACK_PORCH-shoot_cen_h)*(to_integer(Hcount)-HSYNC-HBACK_PORCH-shoot_cen_h))<16*15) then
		      sprite_shoot_HV <= '1';
		  elsif(((to_integer(Vcount)-VSYNC-VBACK_PORCH-shoot_cen_v)*(to_integer(Vcount)-VSYNC-VBACK_PORCH-shoot_cen_v)+(to_integer(Hcount)-HSYNC-HBACK_PORCH-shoot_cen_h)*(to_integer(Hcount)-HSYNC-HBACK_PORCH-shoot_cen_h))>=16*15) then
		      sprite_shoot_HV <= '0';
		  end if;
	  end if;
  end process shoot_ball;
  --------------------------------------------------------------------------------------------------------------
  choose: process(clk25)
   begin
	  if rising_edge(clk25) then
	     if (((to_integer(Vcount)-VSYNC-VBACK_PORCH-choose_cen_v)*(to_integer(Vcount)-VSYNC-VBACK_PORCH-choose_cen_v)+(to_integer(Hcount)-HSYNC-HBACK_PORCH-choose_cen_h)*(to_integer(Hcount)-HSYNC-HBACK_PORCH-choose_cen_h-option*47))<8*8) then
		      sprite_choose_HV <= '1';
		  elsif(((to_integer(Vcount)-VSYNC-VBACK_PORCH-choose_cen_v)*(to_integer(Vcount)-VSYNC-VBACK_PORCH-choose_cen_v)+(to_integer(Hcount)-HSYNC-HBACK_PORCH-choose_cen_h)*(to_integer(Hcount)-HSYNC-HBACK_PORCH-choose_cen_h))>=8*8) then
		      sprite_choose_HV <= '0';
		  end if;
	  end if;
  end process choose;
 ---------------------------------------------------------------------------------------------------------------
 
    shoot_ball_2: process(clk25)
   begin
	  if rising_edge(clk25) then
	     if (((to_integer(Vcount)-VSYNC-VBACK_PORCH-shoot_cen_v_2)*(to_integer(Vcount)-VSYNC-VBACK_PORCH-shoot_cen_v_2)+(to_integer(Hcount)-HSYNC-HBACK_PORCH-shoot_cen_h_2)*(to_integer(Hcount)-HSYNC-HBACK_PORCH-shoot_cen_h_2))<16*15) then
		      sprite_shoot_HV_2 <= '1';
		  elsif(((to_integer(Vcount)-VSYNC-VBACK_PORCH-shoot_cen_v_2)*(to_integer(Vcount)-VSYNC-VBACK_PORCH-shoot_cen_v_2)+(to_integer(Hcount)-HSYNC-HBACK_PORCH-shoot_cen_h_2)*(to_integer(Hcount)-HSYNC-HBACK_PORCH-shoot_cen_h_2))>=16*15) then
		      sprite_shoot_HV_2 <= '0';
		  end if;
	  end if;
  end process shoot_ball_2; 
 ------------------------------------------------------------------------------------------------------
  
-------------------------------------------------------------------------------------------------------
  ball_V: process (clk25)
  variable yy           : integer :=0;
  begin
	  if rising_edge(clk25) then
-------------------------------------------ball 1	
yy :=0;
L1: for y in 0 to 9 loop
     L2: for x in 0 to 17 loop  
	     if ((to_integer(Vcount)-VSYNC-VBACK_PORCH-to_integer(address_y(y)))*(to_integer(Vcount)-VSYNC-VBACK_PORCH-to_integer(address_y(y)))+(to_integer(Hcount)-HSYNC-HBACK_PORCH-to_integer(address_x(x+18*y)))*(to_integer(Hcount)-HSYNC-HBACK_PORCH-to_integer(address_x(x+18*y)))<16*15) then
		      sprite_E_HV <= '1';
				ball_select <= (x+18*y);
				yy := 1;
					
        else 				
			 sprite_E_HV <= '0';	
			 ball_select <= 0;
		  end if;
		  exit L1 when yy = 1;
		  end loop;	
		 end loop;
	  end if;
  end process ball_V;
  
  


  VideoOut: process (clk25, reset)
  begin
    if reset = '1' then
      VGA_R <= "0000000000";
      VGA_G <= "0000000000";
      VGA_B <= "0000000000";
    elsif clk25'event and clk25 = '1' then
	  if sprite_shoot_HV = '1' then
	     ball_select_n <= to_integer(unsigned((Hcount-HSYNC-HBACK_PORCH-shoot_cen_h-16)*32+(Vcount-VSYNC-VBACK_PORCH-shoot_cen_v-16)));
		
         if shoot_ball_type = "00000001" then
			      VGA_R <= ball_R(ball_select_n)& "0000000";
               VGA_G <= ball_G(ball_select_n)& "0000000"; 
					VGA_B <= ball_B(ball_select_n)& "0000000";
					
			elsif  shoot_ball_type= "00000010" then 
			      VGA_R <= turtle_R(ball_select_n)& "0000000";               
					VGA_G <= turtle_G(ball_select_n)& "0000000"; 
					VGA_B <= turtle_B(ball_select_n)& "0000000";
			elsif  shoot_ball_type= "00000011" then 
			      VGA_R <= goomba_R(ball_select_n)& "0000000";
					VGA_G <= goomba_G(ball_select_n)& "0000000";
					VGA_B <= goomba_B(ball_select_n)& "0000000";
			elsif  shoot_ball_type= "00000100" then 
			      VGA_R <= star_R(ball_select_n)& "0000000";
					VGA_G <= star_G(ball_select_n)& "0000000";             
					VGA_B <= star_B(ball_select_n)& "0000000";
			elsif  shoot_ball_type= "00000101" then 
			      VGA_R <= special_ball_R(ball_select_n)& "0000000";
					VGA_G <= special_ball_G(ball_select_n)& "0000000";             
					VGA_B <= special_ball_B(ball_select_n)& "0000000";	
				
			elsif  shoot_ball_type= "00000110" then 
			      VGA_R <= bang_R(ball_select_n)& "0000000";
					VGA_G <= bang_G(ball_select_n)& "0000000";             
					VGA_B <= bang_B(ball_select_n)& "0000000";		
			else
		     if flag = '1' then
		     VGA_R <= VGA_R_buffer&"0000000";
           VGA_G <= VGA_G_buffer&"0000000";
           VGA_B <= VGA_B_buffer&"00000000";
		     elsif flag = '0' then
		     VGA_R <= VGA_R_buffer_next&"0000000";
           VGA_G <= VGA_G_buffer_next&"0000000";
           VGA_B <= VGA_B_buffer_next&"00000000";
			  end if;
		   end if;
   --------------------------------------------------------------------------------------------------------------
	  elsif sprite_shoot_HV_2 = '1' then
	     ball_select_n_2 <= to_integer(unsigned((Hcount-HSYNC-HBACK_PORCH-shoot_cen_h_2-16)*32+(Vcount-VSYNC-VBACK_PORCH-shoot_cen_v_2-16)));
		
         if shoot_ball_type_2 = "00000001" then
			      VGA_R <= ball_R(ball_select_n_2)& "0000000";
               VGA_G <= ball_G(ball_select_n_2)& "0000000"; 
					VGA_B <= ball_B(ball_select_n_2)& "0000000";
					
			elsif  shoot_ball_type_2= "00000010" then 
			      VGA_R <= turtle_R(ball_select_n_2)& "0000000";               
					VGA_G <= turtle_G(ball_select_n_2)& "0000000"; 
					VGA_B <= turtle_B(ball_select_n_2)& "0000000";
			elsif  shoot_ball_type_2= "00000011" then 
			      VGA_R <= goomba_R(ball_select_n_2)& "0000000";
					VGA_G <= goomba_G(ball_select_n_2)& "0000000";
					VGA_B <= goomba_B(ball_select_n_2)& "0000000";
			elsif  shoot_ball_type_2= "00000100" then 
			      VGA_R <= star_R(ball_select_n_2)& "0000000";
					VGA_G <= star_G(ball_select_n_2)& "0000000";             
					VGA_B <= star_B(ball_select_n_2)& "0000000";
			elsif ball_type(ball_select) = "00000101" then	
	            VGA_R <= special_ball_R(ball_select_n_2)& "0000000";
					VGA_G <= special_ball_G(ball_select_n_2)& "0000000";
               VGA_B <= special_ball_B(ball_select_n_2)& "0000000";	
			elsif ball_type(ball_select)= "00000110" then 
			      VGA_R <= bang_R(ball_select_n_2)& "0000000";
					VGA_G <= bang_G(ball_select_n_2)& "0000000";             
					VGA_B <= bang_B(ball_select_n_2)& "0000000";			
					
			else
		     if flag = '1' then
		     VGA_R <= VGA_R_buffer&"0000000";
           VGA_G <= VGA_G_buffer&"0000000";
           VGA_B <= VGA_B_buffer&"00000000";
		     elsif flag = '0' then
		     VGA_R <= VGA_R_buffer_next&"0000000";
           VGA_G <= VGA_G_buffer_next&"0000000";
           VGA_B <= VGA_B_buffer_next&"00000000";
			  end if;
		   end if;
			
	--------------------------------------------------------------------------------------------------------------	  
		 elsif sprite_choose_HV = '1' and launch = "0000000000000010" then
		     VGA_R <= "1111111111";
           VGA_G <= "1111111111";
           VGA_B <= "1111111111";
       elsif tube_HV = '1'  then
        if flag = '1' then
		     VGA_R <= VGA_R_buffer&"0000000";
           VGA_G <= VGA_G_buffer&"0000000";
           VGA_B <= VGA_B_buffer&"00000000";
		  elsif flag = '0' then
		     VGA_R <= VGA_R_buffer_next&"0000000";
           VGA_G <= VGA_G_buffer_next&"0000000";
           VGA_B <= VGA_B_buffer_next&"00000000";
		  end if;
		  
		 elsif tube_first_HV = '1'  then
        if flag = '1' then
		     VGA_R <= VGA_R_buffer&"0000000";
           VGA_G <= VGA_G_buffer&"0000000";
           VGA_B <= VGA_B_buffer&"00000000";
		  elsif flag = '0' then
		     VGA_R <= VGA_R_buffer_next&"0000000";
           VGA_G <= VGA_G_buffer_next&"0000000";
           VGA_B <= VGA_B_buffer_next&"00000000";
		  end if;
		 elsif tube_second_HV = '1'  then
        if flag = '1' then
		     VGA_R <= VGA_R_buffer&"0000000";
           VGA_G <= VGA_G_buffer&"0000000";
           VGA_B <= VGA_B_buffer&"00000000";
		  elsif flag = '0' then
		     VGA_R <= VGA_R_buffer_next&"0000000";
           VGA_G <= VGA_G_buffer_next&"0000000";
           VGA_B <= VGA_B_buffer_next&"00000000";
		  end if;
----------------------------------------------------------------------------------------------------------
	elsif sprite_E_HV = '1' then	
   for y in 0 to 9 loop
	for x in 0 to 17 loop		 	 
	-- ball_type_n <= (x+12*y);
	 
     if ball_select = (x+18*y) then
	   ball_select_a <= to_integer(unsigned((Hcount-HSYNC-HBACK_PORCH-address_x(ball_select)-16)*32+(Vcount-VSYNC-VBACK_PORCH-address_y(y)-16)));
	
		   if ball_type(ball_select) = "00000001" then
			      VGA_R <= ball_R(ball_select_a)& "0000000";
					VGA_G <= ball_G(ball_select_a)& "0000000";
					VGA_B <= ball_B(ball_select_a)& "0000000";	
			elsif ball_type(ball_select) = "00000010" then 
			      VGA_R <= turtle_R(ball_select_a)& "0000000";
					VGA_G <= turtle_G(ball_select_a)& "0000000";
					VGA_B <= turtle_B(ball_select_a)& "0000000";			
			elsif ball_type(ball_select) = "00000011" then 
			      VGA_R <= goomba_R(ball_select_a)& "0000000";
					VGA_G <= goomba_G(ball_select_a)& "0000000";
					VGA_B <= goomba_B(ball_select_a)& "0000000";
			elsif ball_type(ball_select) = "00000100" then 
			      VGA_R <= star_R(ball_select_a)& "0000000";
					VGA_G <= star_G(ball_select_a)& "0000000";
               VGA_B <= star_B(ball_select_a)& "0000000";
		   elsif ball_type(ball_select) = "00000101" then	
	            VGA_R <= special_ball_R(ball_select_a)& "0000000";
					VGA_G <= special_ball_G(ball_select_a)& "0000000";
               VGA_B <= special_ball_B(ball_select_a)& "0000000";		
			elsif ball_type(ball_select)= "00000110" then 
			      VGA_R <= bang_R(ball_select_a)& "0000000";
					VGA_G <= bang_G(ball_select_a)& "0000000";             
					VGA_B <= bang_B(ball_select_a)& "0000000";	
			else
		     if flag = '1' then
		     VGA_R <= VGA_R_buffer&"0000000";
           VGA_G <= VGA_G_buffer&"0000000";
           VGA_B <= VGA_B_buffer&"00000000";
		     elsif flag = '0' then
		     VGA_R <= VGA_R_buffer_next&"0000000";
           VGA_G <= VGA_G_buffer_next&"0000000";
           VGA_B <= VGA_B_buffer_next&"00000000";
			  			  			  			  
			 end if;	
			end if;
		end if;
	end loop;	
end loop;	  
		  
		   elsif score_sprite1_HV ='1' and launch = "0000000000000001" then
			        if flag = '1' then
		              VGA_R <= VGA_R_buffer&"0000000";
                    VGA_G <= VGA_G_buffer&"0000000";
                    VGA_B <= VGA_B_buffer&"00000000";
		           elsif flag = '0' then
		              VGA_R <= VGA_R_buffer_next&"0000000";
                    VGA_G <= VGA_G_buffer_next&"0000000";
                    VGA_B <= VGA_B_buffer_next&"00000000";
					  end if;
			elsif score_sprite2_HV ='1' and launch = "0000000000000001" then
			        if flag = '1' then
		              VGA_R <= VGA_R_buffer&"0000000";
                    VGA_G <= VGA_G_buffer&"0000000";
                    VGA_B <= VGA_B_buffer&"00000000";
		           elsif flag = '0' then
		              VGA_R <= VGA_R_buffer_next&"0000000";
                    VGA_G <= VGA_G_buffer_next&"0000000";
                    VGA_B <= VGA_B_buffer_next&"00000000";
					  end if;
			elsif score_sprite3_HV ='1' and launch = "0000000000000001" then
			        if flag = '1' then
		              VGA_R <= VGA_R_buffer&"0000000";
                    VGA_G <= VGA_G_buffer&"0000000";
                    VGA_B <= VGA_B_buffer&"00000000";
		           elsif flag = '0' then
		              VGA_R <= VGA_R_buffer_next&"0000000";
                    VGA_G <= VGA_G_buffer_next&"0000000";
                    VGA_B <= VGA_B_buffer_next&"00000000";
			        end if;
--	 constant score_VSTART   : integer := 387;elsif  shoot_ball_type= "00000101" then 
			     
--  constant score_VEND     : integer := 427;
--  constant score_H1START  : integer := 526;
--  constant score_H1END    : integer := 558;
--  constant score_H2START  : integer := 558;
--  constant score_H2END    : integer := 590;
--  constant score_H3START  : integer := 590;
--  constant score_H3START  : integer := 622;
  
--			number0_select<=(to_integer((unsigned((Hcount))-HSYNC-HBACK_PORCH-score_H1START)*40 +(Vcount-VSYNC-VBACK_PORCH-score_VSTART)));
--	         C1:case numberd0 is
--				    when "0000000000000000" => 
--					   VGA_R <= n0_R(number0_select)& "0000000";
--                  VGA_G <= n0_G(number0_select)& "0000000";
--                  VGA_B <= n0_B(number0_select)& "0000000";	
--					 when "0000000000000001" =>
--					   VGA_R <= n1_R(number0_select)& "0000000";
--                  VGA_G <= n1_G(number0_select)& "0000000";
--                  VGA_B <= n1_B(number0_select)& "0000000";
--					 when "0000000000000010" =>
--					   VGA_R <= n2_R(number0_select)& "0000000";
--                  VGA_G <= n2_G(number0_select)& "0000000";
--                  VGA_B <= n2_B(number0_select)& "0000000"0;
--					 when "0000000000000011" =>
--					   VGA_R <= n3_R(number0_select)& "0000000";
--                  VGA_G <= n3_G(number0_select)& "0000000";
--                  VGA_B <= n3_B(number0_select)& "0000000";	
--					 when "0000000000000100" =>
--					   VGA_R <= n4_R(number0_select)& "0000000";
--                  VGA_G <= n4_G(number0_select)& "0000000";
--                  VGA_B <= n4_B(number0_select)& "0000000";
--					 when "0000000000000101" =>
--					   VGA_R <= n5_R(number0_select)& "0000000";
--                  VGA_G <= n5_G(number0_select)& "0000000";
--                  VGA_B <= n5_B(number0_select)& "0000000";
--					 when "0000000000000110" =>
--					     VGA_R <= n6_R(number0_select)& "0000000";
--                  VGA_G <= n6_G(number0_select)& "0000000";
--                  VGA_B <= n6_B(number0_select)& "0000000";
--					 when "0000000000000111" =>
--                  VGA_R <= n7_R(number0_select)& "0000000";
--                  VGA_G <= n7_G(number0_select)& "0000000";
--                  VGA_B <= n7_B(number0_select)& "0000000";		
--			       when "0000000000001000" =>
--			         VGA_R <= n8_R(number0_select)& "0000000";
--                  VGA_G <= n8_G(number0_select)& "0000000";
--                  VGA_B <= n8_B(number0_select)& "0000000";
--					when "0000000000001001" =>
--					   VGA_R <= n9_R(number0_select)& "0000000";
--                  VGA_G <= n9_G(number0_select)& "0000000";
--                  VGA_B <= n9_B(number0_select)& "0000000";
--					when others => 
--					   VGA_R <= "0000000000";
--                  VGA_G <= "0000000000";
--                  VGA_B <= "0000000000";
--					end case C1;
--				if numberd0= "0000000000000000" then			
--	           VGA_R <= n0_R(number0_select)& "0000000";
--              VGA_G <= n0_G(number0_select)& "0000000";
--              VGA_B <= n0_B(number0_select)& "0000000";	
--				  
--				  
--			   elsif numberd0= "0000000000000001" then
--			    
--				  VGA_R <= n1_R(number0_select)& "0000000";
--              VGA_G <= n1_G(number0_select)& "0000000";
--              VGA_B <= n1_B(number0_select)& "0000000";	
--			
--			    elsif numberd0= "0000000000000010" then
--			    
--				  VGA_R <= n2_R(number0_select)& "0000000";
--              VGA_G <= n2_G(number0_select)& "0000000";
--              VGA_B <= n2_B(number0_select)& "0000000";	
--			 
--			    elsif numberd0= "0000000000000011" then
--			    
--				  VGA_R <= n3_R(number0_select)& "0000000";
--              VGA_G <= n3_G(number0_select)& "0000000";
--              VGA_B <= n3_B(number0_select)& "0000000";	
--			 
--			  elsif numberd0= "0000000000000100" thenelsif  shoot_ball_type= "00000101" then 
			   
--				  VGA_R <= n4_R(number0_select)& "0000000";
--              VGA_G <= n4_G(number0_select)& "0000000";
--              VGA_B <= n4_B(number0_select)& "0000000";	
--			
--			 elsif numberd0= "0000000000000101" then
--			    
--				  VGA_R <= n5_R(number0_select)& "0000000";
--              VGA_G <= n5_G(number0_select)& "0000000";
--              VGA_B <= n5_B(number0_select)& "0000000";	
--			
--			 elsif numberd0= "0000000000000110" then
--			    
--				  VGA_R <= n6_R(number0_select)& "0000000";
--              VGA_G <= n6_G(number0_select)& "0000000";
--              VGA_B <= n6_B(number0_select)& "0000000";	
--			
--			 elsif numberd0= "0000000000000111" then
--			    
--				  VGA_R <= n7_R(number0_select)& "0000000";
--              VGA_G <= n7_G(number0_select)& "0000000";
--              VGA_B <= n7_B(number0_select)& "0000000";
--				  
--			 elsif numberd0= "0000000000001000" then
--			    elsif  shoot_ball_type= "00000101" then 
		
--				  VGA_R <= n8_R(number0_select)& "0000000";
--              VGA_G <= n8_G(number0_select)& "0000000";
--              VGA_B <= n8_B(number0_select)& "0000000";	
--			
--			 elsif numberd0= "0000000000001001" then
--			    
--				  VGA_R <= n9_R(number0_select)& "0000000";
--              VGA_G <= n9_G(number0_select)& "0000000";
--              VGA_B <= n9_B(number0_select)& "0000000";	
--			

			
--		   end if; 
--		   elsif score_sprite2_HV ='1' and launch = "0000000000000001" then
--			
--			number1_select<=(to_integer((unsigned((Hcount))-HSYNC-HBACK_PORCH-score_H2START)*40 +(Vcount-VSYNC-VBACK_PORCH-score_VSTART)));
--	       
--            if numberd1= "0000000000000000" then			
--	           VGA_R <= n0_R(number1_select)& "0000000";
--              VGA_G <= n0_G(number1_select)& "0000000";
--              VGA_B <= n0_B(number1_select)& "0000000";	
--				  
--				  
--			   elsif numberd1= "0000000000000001" then
--			    
--				    VGA_R <= n1_R(number1_select)& "0000000";
--              VGA_G <= n1_G(number1_select)& "0000000";
--              VGA_B <= n1_B(number1_select)& "0000000";	
			
--			    elsif numberd1= "0000000000000010" then
--			    
--				  VGA_R <= n2_R(number1_select)& "0000000";
--              VGA_G <= n2_G(number1_select)& "0000000";
--              VGA_B <= n2_B(number1_select)& "0000000";	
--			 
--			    elsif numberd1= "0000000000000011" then
--			    
--				  VGA_R <= n3_R(number1_select)& "0000000";
--              VGA_G <= n3_G(number1_select)& "0000000";
--              VGA_B <= n3_B(number1_select)& "0000000";	
--			 
--			  elsif numberd1= "0000000000000100" thenelsif  shoot_ball_type= "00000101" then 
			
--				  VGA_R <= n4_R(number1_select)& "0000000";
--              VGA_G <= n4_G(number1_select)& "0000000";
--              VGA_B <= n4_B(number1_select)& "0000000";	
--			
--			 elsif numberd1= "0000000000000101" then
--			    
--				  VGA_R <= n5_R(number1_select)& "0000000";
--              VGA_G <= n5_G(number1_select)& "0000000";
--              VGA_B <= n5_B(number1_select)& "0000000";	
--			
--			 elsif numberd1= "0000000000000110" then
--			    
--				  VGA_R <= n6_R(number1_select)& "0000000";
--              VGA_G <= n6_G(number1_select)& "0000000";
--              VGA_B <= n6_B(number1_select)& "0000000";	
--			
--			 elsif numberd1= "0000000000000111" then
--			    
--				  VGA_R <= n7_R(number1_select)& "0000000";
--              VGA_G <= n7_G(number1_select)& "0000000";
--              VGA_B <= n7_B(number1_select)& "0000000";
--				  
--			 elsif numberd1= "0000000000001000" then
--			    
--				  VGA_R <= n8_R(number1_select)& "0000000";
--              VGA_G <= n8_G(nend if;umber1_select)& "0000000";
--              VGA_B <= n8_B(number1_select)& "0000000";	
--			
--			 elsif numberd1= "0000000000001001" then
--			    
--				  VGA_R <= n9_R(number1_select)& "0000000";
--              VGA_G <= n9_G(number1_select)& "0000000";
--              VGA_B <= n9_B(number1_select)& "0000000";	
--			
--		     end if;

--         elsif score_sprite3_HV ='1' and launch = "0000000000000001" then
--			 number2_select<=(to_integer((unsigned((Hcount))-HSYNC-HBACK_PORCH-score_H3START)*40 +(Vcount-VSYNC-VBACK_PORCH-score_VSTART)));
--	      
--        	
--	        if numberd2= "0000000000000000" then			
--	           VGA_R <= n0_R(number2_select)& "0000000";
--              VGA_G <= n0_G(number2_select)& "0000000";
--              VGA_B <= n0_B(number2_select)& "0000000";	
--				  
--				  
--			   elsif numberd2= "0000000000000001" then
--			    
--				  VGA_R <= n1_R(number2_select)& "0000000";
--              VGA_G <= n1_G(number2_select)& "0000000";
--              VGA_B <= n1_B(number2_select)& "0000000";	
--			
--			    elsif numberd2= "0000000000000010" then
--			    
--				  VGA_R <= n2_R(number2_select)& "0000000";
--              VGA_G <= n2_G(number2_select)& "0000000";
--              VGA_B <= n2_B(number2_select)& "0000000";	
--			 
--			    elsif numberd2= "0000000000000011" then
--			    
--				  VGA_R <= n3_R(number2_select)& "0000000";
--              VGA_G <= n3_G(number2_select)& "0000000";
--              VGA_B <= n3_B(number2_select)& "0000000";	
--			 
--			  elsif numberd2= "000end if;0000000000100" then
--			    
--				  VGA_R <= n4_R(number2_select)& "0000000";
--              VGA_G <= n4_G(number2_select)& "0000000";
--              VGA_B <= n4_B(number2_select)& "0000000";	
--			
--			 elsif numberd2= "0000000000000101" then
--			    
--				  VGA_R <= n5_R(number2_select)& "0000000";
--              VGA_G <= n5_G(number2_select)& "0000000";
--              VGA_B <= n5_B(number2_select)& "0000000";	
--			
--			 elsif numberd2= "0000000000000110" then
--			    
--				  VGA_R <= n6_R(number2_select)& "0000000";
--              VGA_G <= n6_G(number2_select)& "0000000";
--              VGA_B <= n6_B(number2_select)& "0000000";	
--			
--			 elsif numberd2= "0000000000000111" then
--			    
--				  VGA_R <= n7_R(number2_select)& "0000000";
--              VGA_G <= n7_G(number2_select)& "0000000";
--              VGA_B <= n7_B(number2_select)& "0000000";
--				  
--			 elsif numberd2= "0000000000001000" then
--			    
--				  VGA_R <= n8_R(number2_select)& "0000000";
--              VGA_G <= n8_G(number2_select)& "0000000";
--              VGA_B <= n8_B(number2_select)& "0000000";	
--			
--			 elsif numberd2= "0000000000001001" then
--			    
--				  VGA_R <= n9_R(number2_select)& "0000000";
--              VGA_G <= n9_G(number2_select)& "0000000";
--              VGA_B <= n9_B(number2_select)& "0000000";	
			
			
--		      end if;
			
		
		  
	   elsif rectangle = '1' then
		 if chipselect = '1' and write = '1' then
		  if flag = '1' then
		     VGA_R <= VGA_R_buffer&"0000000";
           VGA_G <= VGA_G_buffer&"0000000";
           VGA_B <= VGA_B_buffer&"00000000";
		  elsif flag = '0' then
		     VGA_R <= VGA_R_buffer_next&"0000000";
           VGA_G <= VGA_G_buffer_next&"0000000";
           VGA_B <= VGA_B_buffer_next&"00000000";
			 end if;
		  end if;
      elsif vga_hblank = '0' and vga_vblank ='0' then
        VGA_R <= "1111111111";
        VGA_G <= "1111111111";
        VGA_B <= "1111111111";
      else
        VGA_R <= "0000000000";
        VGA_G <= "0000000000";
        VGA_B <= "0000000000";    
      end if;
    end if;
  end process VideoOut;

  VGA_CLK <= clk25;
  VGA_HS <= not vga_hsync;
  VGA_VS <= not vga_vsync;
  VGA_SYNC <= '0';
  VGA_BLANK <= not (vga_hsync or vga_vsync);

end rtl;
